@@ -2,7 +2,7 @@
  *
  * $Id: classdef.h,v 1.39 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,7 +23,7 @@
 #include <qdict.h>
 #include <qstrlist.h>
 
-#include "entry.h"
+#include "util.h"
 #include "memberlist.h"
 #include "definition.h"
 #include "sortdict.h"
@@ -45,6 +45,7 @@ class PackageDef;
 class GroupDef;
 class StringDict;
 struct IncludeInfo;
+class ClassDefImpl;
 
 /*! \brief This class contains all information about a compound.
  *
@@ -54,269 +55,15 @@ struct IncludeInfo;
 class ClassDef : public Definition
 {
   public:
-    /*! \name Public API
-     *  \{
-     */
-
     /*! The various compound types */
-    enum CompoundType { Class=Entry::CLASS_SEC, 
-                        Struct=Entry::STRUCT_SEC, 
-                        Union=Entry::UNION_SEC,
-                        Interface=Entry::INTERFACE_SEC,
-                        Protocol=Entry::PROTOCOL_SEC,
-                        Category=Entry::CATEGORY_SEC,
-                        Exception=Entry::EXCEPTION_SEC
+    enum CompoundType { Class, //=Entry::CLASS_SEC, 
+                        Struct, //=Entry::STRUCT_SEC, 
+                        Union, //=Entry::UNION_SEC,
+                        Interface, //=Entry::INTERFACE_SEC,
+                        Protocol, //=Entry::PROTOCOL_SEC,
+                        Category, //=Entry::CATEGORY_SEC,
+                        Exception //=Entry::EXCEPTION_SEC
                       };
-    DefType definitionType() const { return TypeClass; }
-    QCString getOutputFileBase() const; 
-    QCString getInstanceOutputFileBase() const; 
-    QCString getFileBase() const;
-    QCString getSourceFileBase() const; 
-    QCString getReference() const;
-    bool isReference() const;
-    bool isLocal() const { return m_isLocal; }
-    bool isArtificial() const { return m_artificial; }
-
-    bool hasDocumentation() const;
-
-    /*! Returns the name as it is appears in the documentation */
-    QCString displayName() const;
-
-    /*! Returns the type of compound this is */
-    CompoundType compoundType() const { return m_compType; } 
-
-    /*! Returns the type of compound as a string */
-    QCString compoundTypeString() const;
-
-    /*! Returns the list of base classes from which this class directly
-     *  inherits.
-     */
-    BaseClassList *baseClasses() { return m_inherits; }
-    
-    /*! Returns the list of sub classes that directly inherit from this class
-     */
-    BaseClassList *subClasses() { return m_inheritedBy; }
-
-    /*! Returns a dictionary of all members. This includes any inherited 
-     *  members. Members are sorted alphabetically.
-     */ 
-    MemberNameInfoSDict *memberNameInfoSDict() { return m_allMemberNameInfoSDict; }
-
-    void writeDocumentation(OutputList &ol);
-    void writeDocumentationForInnerClasses(OutputList &ol);
-    void writeMemberDocumentation(OutputList &ol);
-    void writeMemberPages(OutputList &ol);
-    void writeMemberList(OutputList &ol);
-    void writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup);
-    void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag);
-    void writeQuickMemberLinks(OutputList &ol,MemberDef *md) const;
-
-    /*! Return the protection level (Public,Protected,Private) in which 
-     *  this compound was found.
-     */
-    Protection protection() const { return m_prot; }
-
-    /*! returns TRUE iff a link is possible to an item within this project.
-     */
-    bool isLinkableInProject() const;
-
-    /*! return TRUE iff a link to this class is possible (either within 
-     *  this project, or as a cross-reference to another project).
-     */
-    bool isLinkable() const;
-
-    /*! the class is visible in a class diagram, or class hierarchy */
-    bool isVisibleInHierarchy();
-    
-    /*! Returns the template arguments of this class 
-     *  Will return 0 if not applicable.
-     */
-    ArgumentList *templateArguments() const { return m_tempArgs; }
-
-    /*! Returns the namespace this compound is in, or 0 if it has a global
-     *  scope.
-     */
-    NamespaceDef *getNamespaceDef() { return m_nspace; }
-
-    /*! Returns the file in which this compound's definition can be found.
-     *  Should not return 0 (but it might be a good idea to check anyway).
-     */
-    FileDef      *getFileDef() const { return m_fileDef; }
-
-    /*! Returns the Java package this class is in or 0 if not applicable. 
-     */ 
-    //PackageDef   *packageDef() const;
-
-    MemberDef    *getMemberByName(const QCString &);
-    
-    /*! Returns TRUE iff \a bcd is a direct or indirect base class of this
-     *  class. This function will recusively traverse all branches of the
-     *  inheritance tree.
-     */
-    bool isBaseClass(ClassDef *bcd,bool followInstances,int level=0);
-
-    /*! Returns a sorted dictionary with all template instances found for
-     *  this template class. Returns 0 if not a template or no instances.
-     */
-    QDict<ClassDef> *getTemplateInstances() const { return m_templateInstances; }
-    /*! Returns the template master of which this class is an instance.
-     *  Returns 0 if not applicable.
-     */
-    ClassDef *templateMaster() const { return m_templateMaster; } 
-
-    bool isTemplate() const { return m_tempArgs!=0; }
-
-    IncludeInfo *includeInfo() const { return m_incInfo; }
-    
-    UsesClassDict *usedImplementationClasses() const 
-    { 
-      return m_usesImplClassDict; 
-    }
-
-    UsesClassDict *usedByImplementationClasses() const 
-    { 
-      return m_usedByImplClassDict; 
-    }
-
-    UsesClassDict *usedInterfaceClasses() const
-    {
-      return m_usesIntfClassDict;
-    }
-
-    /** Marks this class as a template argument of some another class */
-    void makeTemplateArgument(bool b=TRUE)
-    {
-      m_isTemplArg = b;
-    }
-
-    bool isTemplateArgument() const
-    {
-      return m_isTemplArg;
-    }
-
-    /*! Returns the definition of a nested compound if
-     *  available, or 0 otherwise.
-     *  @param name The name of the nested compound
-     */
-    virtual Definition *findInnerCompound(const char *name);
-
-    /*! Returns the template parameter lists that form the template
-     *  declaration of this class.
-     *  
-     *  Example: <code>template<class T> class TC {};</code>
-     *  will return a list with one ArgumentList containing one argument
-     *  with type="class" and name="T".
-     */
-    void getTemplateParameterLists(QList<ArgumentList> &lists) const;
-    QCString qualifiedNameWithTemplateParameters(
-        QList<ArgumentList> *actualParams=0) const;
-
-    /*! Returns TRUE if there is at least one pure virtual member in this
-     *  class.
-     */
-    bool isAbstract() const { return m_isAbstract; }
-
-    /*! Returns TRUE if this class is implemented in Objective-C */
-    bool isObjectiveC() const { return m_isObjC; }
-
-    ClassDef *categoryOf() const { return m_categoryOf; }
-
-    /*! returns the name of the class including outer classes, but not
-     *  including namespaces.
-     */
-    QCString className() const;
-
-    /* member lists by protection */
-    MemberList pubMethods;
-    MemberList proMethods;
-    MemberList pacMethods;
-    MemberList priMethods;
-    MemberList pubStaticMethods;
-    MemberList proStaticMethods;
-    MemberList pacStaticMethods;
-    MemberList priStaticMethods;
-    MemberList pubSlots;
-    MemberList proSlots;
-    MemberList priSlots;
-    MemberList pubAttribs;
-    MemberList proAttribs;
-    MemberList pacAttribs;
-    MemberList priAttribs;
-    MemberList pubStaticAttribs;
-    MemberList proStaticAttribs;
-    MemberList pacStaticAttribs;
-    MemberList priStaticAttribs;
-    MemberList pubTypes;
-    MemberList proTypes;
-    MemberList pacTypes;
-    MemberList priTypes;
-    MemberList related;
-    MemberList signals;
-    MemberList friends;
-    MemberList dcopMethods;
-    MemberList properties;
-    MemberList events;
-    
-    /* member list by types */
-    MemberList constructors;
-    MemberList typedefMembers;
-    MemberList enumMembers;
-    MemberList enumValMembers;
-    MemberList functionMembers;
-    MemberList relatedMembers;
-    MemberList variableMembers;
-    MemberList propertyMembers;
-    MemberList eventMembers;
-
-    /* user defined member groups */
-    MemberGroupSDict *memberGroupSDict;
-
-    /*! \} Public API */
-
-    /*! \name Doxygen internal API
-     *  \{
-     */
-    void insertBaseClass(ClassDef *,const char *name,Protection p,Specifier s,const char *t=0);
-    void insertSubClass(ClassDef *,Protection p,Specifier s,const char *t=0);
-    void setIncludeFile(FileDef *fd,const char *incName,bool local,bool force); 
-    void insertMember(MemberDef *);
-    void insertUsedFile(const char *);
-    void computeAnchors();
-    //void computeMemberGroups();
-    //void setAnchor(MemberDef *);
-    //void dumpMembers();
-    bool addExample(const char *anchor,const char *name, const char *file);
-    void addMembersToMemberGroup();
-    void distributeMemberGroupDocumentation();
-    void findSectionsInDocumentation();
-    void setNamespace(NamespaceDef *nd) { m_nspace = nd; }
-    void setTemplateArguments(ArgumentList *al);
-    void mergeMembers();
-    void mergeCategory(ClassDef *category);
-    void setFileDef(FileDef *fd) { m_fileDef=fd; }
-    //void determineImplUsageRelation();
-    //void determineIntfUsageRelation();
-    void setSubGrouping(bool enabled) { m_subGrouping = enabled; }
-    void setProtection(Protection p) { m_prot=p; }
-    void setGroupDefForAllMembers(GroupDef *g,Grouping::GroupPri_t pri,const QCString &fileName,int startLine,bool hasDocs);
-    void addInnerCompound(Definition *d);
-    void addUsedClass(ClassDef *cd,const char *accessName);
-    void addUsedByClass(ClassDef *cd,const char *accessName);
-    //void initTemplateMapping();
-    //void setTemplateArgumentMapping(const char *formal,const char *actual);
-    //QCString getTemplateArgumentMapping(const char *formal) const;
-    ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,
-                                const QCString &templSpec,bool &freshInstance);
-    ClassDef *getVariableInstance(const char *templSpec);
-    void setTemplateBaseClassNames(QDict<int> *templateNames);
-    QDict<int> *getTemplateBaseClassNames() const;
-    void setTemplateMaster(ClassDef *tm) { m_templateMaster=tm; }
-    void addMembersToTemplateInstance(ClassDef *cd,const char *templSpec);
-    void setClassIsArtificial() { m_artificial = TRUE; }
-    void setIsStatic(bool b) { m_isStatic=b; }
-    void setIsObjectiveC(bool b) { m_isObjC=b; }
-    void addListReferences();
-    void setCompoundType(CompoundType t) { m_compType = t; } 
 
     /*! Creates a new compound definition.
      *  \param fileName  full path and file name in which this compound was
@@ -340,7 +87,251 @@ class ClassDef : public Definition
     /*! Destroys a compound definition. */
    ~ClassDef();
 
-    ClassSDict *getInnerClasses() { return m_innerClasses; }
+    //-----------------------------------------------------------------------------------
+    // --- getters 
+    //-----------------------------------------------------------------------------------
+
+    /*! Used for RTTI, this is a class */
+    DefType definitionType() const { return TypeClass; }
+
+    /*! Returns the unique base name (without extension) of the class's file on disk */
+    QCString getOutputFileBase() const; 
+    QCString getXmlOutputFileBase() const;
+    QCString getInstanceOutputFileBase() const; 
+    QCString getFileBase() const;
+
+    /*! Returns the base name for the source code file */
+    QCString getSourceFileBase() const; 
+
+    /*! If this class originated from a tagfile, this will return the tag file reference */
+    QCString getReference() const;
+
+    /*! Returns TRUE if this class is imported via a tag file */
+    bool isReference() const;
+
+    /*! Returns TRUE if this is a local class definition, see EXTRACT_LOCAL_CLASSES */
+    bool isLocal() const;
+
+    /*! returns the classes nested into this class */
+    ClassSDict *getInnerClasses();
+
+    /*! returns TRUE if this class has documentation */
+    bool hasDocumentation() const;
+
+    /*! Returns the name as it is appears in the documentation */
+    QCString displayName() const;
+
+    /*! Returns the type of compound this is, i.e. class/struct/union/.. */
+    CompoundType compoundType() const;
+
+    /*! Returns the type of compound as a string */
+    QCString compoundTypeString() const;
+
+    /*! Returns the list of base classes from which this class directly
+     *  inherits.
+     */
+    BaseClassList *baseClasses() const;
+    
+    /*! Returns the list of sub classes that directly derive from this class
+     */
+    BaseClassList *subClasses() const;
+
+    /*! Returns a dictionary of all members. This includes any inherited 
+     *  members. Members are sorted alphabetically.
+     */ 
+    MemberNameInfoSDict *memberNameInfoSDict() const;
+
+    /*! Return the protection level (Public,Protected,Private) in which 
+     *  this compound was found.
+     */
+    Protection protection() const;
+
+    /*! returns TRUE iff a link is possible to this item within this project.
+     */
+    bool isLinkableInProject() const;
+
+    /*! return TRUE iff a link to this class is possible (either within 
+     *  this project, or as a cross-reference to another project).
+     */
+    bool isLinkable() const;
+
+    /*! the class is visible in a class diagram, or class hierarchy */
+    bool isVisibleInHierarchy();
+    
+    /*! Returns the template arguments of this class 
+     *  Will return 0 if not applicable.
+     */
+    ArgumentList *templateArguments() const;
+
+    /*! Returns the namespace this compound is in, or 0 if it has a global
+     *  scope.
+     */
+    NamespaceDef *getNamespaceDef() const;
+
+    /*! Returns the file in which this compound's definition can be found.
+     *  Should not return 0 (but it might be a good idea to check anyway).
+     */
+    FileDef      *getFileDef() const;
+
+    /*! Returns the Java package this class is in or 0 if not applicable. 
+     */ 
+
+    MemberDef    *getMemberByName(const QCString &) const;
+    
+    /*! Returns TRUE iff \a bcd is a direct or indirect base class of this
+     *  class. This function will recusively traverse all branches of the
+     *  inheritance tree.
+     */
+    bool isBaseClass(ClassDef *bcd,bool followInstances,int level=0);
+
+    /*! returns TRUE iff \a md is a member of this class or of the
+     *  the public/protected members of a base class 
+     */
+    bool isAccessibleMember(MemberDef *md);
+
+    /*! Returns a sorted dictionary with all template instances found for
+     *  this template class. Returns 0 if not a template or no instances.
+     */
+    QDict<ClassDef> *getTemplateInstances() const;
+
+    /*! Returns the template master of which this class is an instance.
+     *  Returns 0 if not applicable.
+     */
+    ClassDef *templateMaster() const;
+
+    /*! Returns TRUE if this class is a template */
+    bool isTemplate() const;
+
+    IncludeInfo *includeInfo() const;
+    
+    UsesClassDict *usedImplementationClasses() const;
+
+    UsesClassDict *usedByImplementationClasses() const;
+
+    UsesClassDict *usedInterfaceClasses() const;
+
+    bool isTemplateArgument() const;
+
+    /*! Returns the definition of a nested compound if
+     *  available, or 0 otherwise.
+     *  @param name The name of the nested compound
+     */
+    virtual Definition *findInnerCompound(const char *name);
+
+    /*! Returns the template parameter lists that form the template
+     *  declaration of this class.
+     *  
+     *  Example: <code>template<class T> class TC {};</code>
+     *  will return a list with one ArgumentList containing one argument
+     *  with type="class" and name="T".
+     */
+    void getTemplateParameterLists(QList<ArgumentList> &lists) const;
+
+    QCString qualifiedNameWithTemplateParameters(
+        QList<ArgumentList> *actualParams=0) const;
+
+    /*! Returns TRUE if there is at least one pure virtual member in this
+     *  class.
+     */
+    bool isAbstract() const;
+
+    /*! Returns TRUE if this class is implemented in Objective-C */
+    bool isObjectiveC() const;
+
+    /*! Returns TRUE if this class is implemented in C# */
+    bool isCSharp() const;
+
+    /*! Returns the class of which this is a category (Objective-C only) */
+    ClassDef *categoryOf() const;
+
+    /*! Returns the name of the class including outer classes, but not
+     *  including namespaces.
+     */
+    QCString className() const;
+
+    /*! Returns the members in the list identified by \a lt */
+    MemberList *getMemberList(MemberList::ListType lt);
+
+    /*! Returns the list containing the list of members sorted per type */
+    const QList<MemberList> &getMemberLists() const;
+
+    /*! Returns the member groups defined for this class */
+    MemberGroupSDict *getMemberGroupSDict() const;
+
+    QDict<int> *getTemplateBaseClassNames() const;
+
+    ClassDef *getVariableInstance(const char *templSpec);
+
+    bool isUsedOnly() const;
+
+    QCString anchor() const;
+    bool isEmbeddedInOuterScope() const;
+
+    bool isSimple() const;
+
+    const ClassList *taggedInnerClasses() const;
+    ClassDef *tagLessReference() const;
+
+    //-----------------------------------------------------------------------------------
+    // --- setters ----
+    //-----------------------------------------------------------------------------------
+
+    void insertBaseClass(ClassDef *,const char *name,Protection p,Specifier s,const char *t=0);
+    void insertSubClass(ClassDef *,Protection p,Specifier s,const char *t=0);
+    void setIncludeFile(FileDef *fd,const char *incName,bool local,bool force); 
+    void insertMember(MemberDef *);
+    void insertUsedFile(const char *);
+    bool addExample(const char *anchor,const char *name, const char *file);
+    void mergeCategory(ClassDef *category);
+    void setNamespace(NamespaceDef *nd);
+    void setFileDef(FileDef *fd);
+    void setSubGrouping(bool enabled);
+    void setProtection(Protection p);
+    void setGroupDefForAllMembers(GroupDef *g,Grouping::GroupPri_t pri,const QCString &fileName,int startLine,bool hasDocs);
+    void addInnerCompound(Definition *d);
+    ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,
+                                const QCString &templSpec,bool &freshInstance);
+    void addUsedClass(ClassDef *cd,const char *accessName,Protection prot);
+    void addUsedByClass(ClassDef *cd,const char *accessName,Protection prot);
+    void setIsStatic(bool b);
+    void setCompoundType(CompoundType t);
+    void setClassName(const char *name);
+
+    void setTemplateArguments(ArgumentList *al);
+    void setTemplateBaseClassNames(QDict<int> *templateNames);
+    void setTemplateMaster(ClassDef *tm);
+    void setTypeConstraints(ArgumentList *al);
+    void addMembersToTemplateInstance(ClassDef *cd,const char *templSpec);
+    void makeTemplateArgument(bool b=TRUE);
+    void setCategoryOf(ClassDef *cd);
+    void setUsedOnly(bool b);
+
+    void addTaggedInnerClass(ClassDef *cd);
+    void setTagLessReference(ClassDef *cd);
+
+    //-----------------------------------------------------------------------------------
+    // --- actions ----
+    //-----------------------------------------------------------------------------------
+
+    void findSectionsInDocumentation();
+    void addMembersToMemberGroup();
+    void addListReferences();
+    void computeAnchors();
+    void mergeMembers();
+    void sortMemberLists();
+    void distributeMemberGroupDocumentation();
+    void writeDocumentation(OutputList &ol);
+    void writeDocumentationForInnerClasses(OutputList &ol);
+    void writeMemberPages(OutputList &ol);
+    void writeMemberList(OutputList &ol);
+    void writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup);
+    void writeQuickMemberLinks(OutputList &ol,MemberDef *md) const;
+    void writeSummaryLinks(OutputList &ol);
+    void reclassifyMember(MemberDef *md,MemberDef::MemberType t);
+    void writeInlineDocumentation(OutputList &ol);
+    void writeDeclarationLink(OutputList &ol,bool &found,
+                              const char *header,bool localNames);
+    void removeMemberFromLists(MemberDef *md);
     
     bool visited;
 
@@ -350,134 +341,38 @@ class ClassDef : public Definition
     bool hasNonReferenceSuperClass();
     void showUsedFiles(OutputList &ol);
 
-    /*! \} Interal API */
-
   private: 
+    void writeTagFileMarker(OutputList &ol);
+    void writeDocumentationContents(OutputList &ol,const QCString &pageTitle);
     void internalInsertMember(MemberDef *md,Protection prot,bool addToAllList);
+    QCString getMemberListFileName() const;
+    void addMemberToList(MemberList::ListType lt,MemberDef *md,bool isBrief);
+    MemberList *createMemberList(MemberList::ListType lt);
+    void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title,
+                                 const char *subTitle=0,bool showInline=FALSE);
+    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title,bool showInline=FALSE);
+    void writeSimpleMemberDocumentation(OutputList &ol,MemberList::ListType lt);
+    void writePlainMemberDeclaration(OutputList &ol,MemberList::ListType lt,bool inGroup);
+    void writeBriefDescription(OutputList &ol,bool exampleFlag);
+    void writeDetailedDescription(OutputList &ol,const QCString &pageType,bool exampleFlag,
+                                  const QCString &title,const QCString &anchor=QCString());
+    void writeIncludeFiles(OutputList &ol);
+    void writeAllMembersLink(OutputList &ol);
+    void writeInheritanceGraph(OutputList &ol);
+    void writeCollaborationGraph(OutputList &ol);
+    void writeMemberGroups(OutputList &ol,bool showInline=FALSE);
+    void writeNestedClasses(OutputList &ol,const QCString &title);
+    void writeInlineClasses(OutputList &ol);
+    void startMemberDeclarations(OutputList &ol);
+    void endMemberDeclarations(OutputList &ol);
+    void startMemberDocumentation(OutputList &ol);
+    void endMemberDocumentation(OutputList &ol);
+    void writeAuthorSection(OutputList &ol);
+    void writeMoreLink(OutputList &ol,const QCString &anchor);
+    void writeDetailedDocumentationBody(OutputList &ol);
     
-    /*! file name that forms the base for the output file containing the
-     *  class documentation. For compatibility with Qt (e.g. links via tag 
-     *  files) this name cannot be derived from the class name directly.
-     */
-    QCString m_fileName;                   
+    ClassDefImpl *m_impl;
 
-    /*! Include information about the header file should be included
-     *  in the documentation. 0 by default, set by setIncludeFile().
-     */
-    IncludeInfo *m_incInfo;                
-
-    /*! file name that forms the base for the "list of members" for this
-     *  class.
-     */
-    QCString m_memListFileName;            
-
-    /*! Bare name of the class without any scoping prefixes 
-     *  (like for nested classes and classes inside namespaces)
-     */ 
-    //QCString m_scopelessName;              
-
-    /*! List of base class (or super-classes) from which this class derives
-     *  directly. 
-     */
-    BaseClassList *m_inherits;
-
-    /*! List of sub-classes that directly derive from this class 
-     */
-    BaseClassList *m_inheritedBy;
-
-    /*! Namespace this class is part of 
-     *  (this is the inner most namespace in case of nested namespaces)
-     */
-    NamespaceDef  *m_nspace;              
-
-    /*! File this class is defined in */
-    FileDef *m_fileDef;
-
-    /*! List of all members (including inherited members) */
-    MemberNameInfoSDict *m_allMemberNameInfoSDict;
-
-    /*! Template arguments of this class */
-    ArgumentList *m_tempArgs;
-
-    /*! Files that were used for generating the class documentation. */
-    QStrList m_files;
-
-    /*! Examples that use this class */
-    ExampleSDict *m_exampleSDict;
-
-    /*! Holds the kind of "class" this is. */
-    CompoundType m_compType;
-
-    /*! The protection level in which this class was found. 
-     *  Typically Public, but for nested classes this can also be Protected
-     *  or Private.
-     */ 
-    Protection m_prot;
-
-    /*! Does this class group its user-grouped members
-     *  as a sub-section of the normal (public/protected/..) 
-     *  groups?
-     */
-    bool m_subGrouping; 
-
-    /*! The inner classes contained in this class. Will be 0 if there are
-     *  no inner classes.
-     */
-    ClassSDict *m_innerClasses;
-
-
-    /* classes for the collaboration diagram */
-    UsesClassDict *m_usesImplClassDict;
-    UsesClassDict *m_usedByImplClassDict;
-    UsesClassDict *m_usesIntfClassDict;
-
-    /*! Template instances that exists of this class, the key in the
-     *  dictionary is the template argument list.
-     */ 
-    QDict<ClassDef> *m_templateInstances;
-
-    /*! Template instances that exists of this class, as defined by variables.
-     *  We do NOT want to document these individually. The key in the
-     *  dictionary is the template argument list.
-     */ 
-    QDict<ClassDef> *m_variableInstances;
-
-    QDict<int> *m_templBaseClassNames;
-
-    /*! The class this class is an instance of. */
-    ClassDef *m_templateMaster;
-
-    /*! Indicated whether this class exists because it is used by
-     *  some other class only (TRUE) or if some class inherits from
-     *  it (FALSE). This is need to remove used-only classes from
-     *  the inheritance tree.
-     */
-    bool m_artificial;
-
-    /*! Is this an abstact class? */
-    bool m_isAbstract;
-
-    /*! Is the class part of an unnamed namespace? */
-    bool m_isStatic;
-
-    /*! Is the class part implemented in Objective C? */
-    bool m_isObjC;
-
-    /*! TRUE if classes members are merged with those of the base classes. */
-    bool m_membersMerged;
-
-    /*! TRUE if the class is defined in a source file rather than a header file. */
-    bool m_isLocal;
-
-    /*! class name with outer class scope, but without namespace scope. */
-    QCString m_className;
-
-    /*! If this class is a Objective-C category, then this points to the
-     *  class which is extended.
-     */
-    ClassDef *m_categoryOf;
-
-    bool m_isTemplArg;
 };
 
 /*! \brief Class that contains information about a usage relation. 
