@@ -2,7 +2,7 @@
  *
  * $Id: classlist.h,v 1.8 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,6 +24,8 @@
 #include "classdef.h"
 #include "sortdict.h"
 
+class Definition;
+
 class ClassList : public QList<ClassDef>
 { 
   public:
@@ -53,7 +55,9 @@ class ClassSDict : public SDict<ClassDef>
    ~ClassSDict() {}
    int compareItems(GCI item1,GCI item2);
    void writeDeclaration(OutputList &ol,const ClassDef::CompoundType *filter=0,
-                         const char *header=0);
+                         const char *header=0,bool localNames=FALSE);
+   void writeDocumentation(OutputList &ol,Definition *container=0);
+   bool declVisible(const ClassDef::CompoundType *filter=0) const;
 };
 
 #endif
