@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,7 @@
 #include "qtbc.h"
 #include <ctype.h>
 #include <qregexp.h>
-#include <md5.h>
+#include "md5.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
@@ -78,6 +78,8 @@ class DefinitionImpl
     QCString defFileName;
     int      defLine;
     QCString defFileExt;
+
+    SrcLangExt lang;
 };
 
 DefinitionImpl::DefinitionImpl() 
@@ -135,6 +137,7 @@ void DefinitionImpl::init(const char *df,int dl,
   xrefListItems   = 0;
   hidden          = FALSE;
   isArtificial    = FALSE;
+  lang            = SrcLangExt_Unknown;
 }
 
 //-----------------------------------------------------------------------------------------
@@ -540,13 +543,13 @@ void Definition::setInbodyDocumentation(const char *d,const char *inbodyFile,int
 static bool readCodeFragment(const char *fileName,
                       int &startLine,int &endLine,QCString &result)
 {
-  static bool vhdlOpt           = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString filter = getFileFilter(fileName);
+  QCString filter = getFileFilter(fileName,TRUE);
   FILE *f=0;
   bool usePipe = !filter.isEmpty() && filterSourceFiles;
+  SrcLangExt lang = getLanguageFromFileName(fileName);
   if (!usePipe) // no filter given or wanted
   {
     f = portable_fopen(fileName,"r");
@@ -557,7 +560,11 @@ static bool readCodeFragment(const char *fileName,
     Debug::print(Debug::ExtCmd,0,"Executing popen(`%s`)\n",cmd.data());
     f = portable_popen(cmd,"r");
   }
-  bool found=vhdlOpt;  // for VHDL no bracket search is possible
+  bool found = lang==SrcLangExt_VHDL   || 
+               lang==SrcLangExt_Tcl    || 
+               lang==SrcLangExt_Python || 
+               lang==SrcLangExt_Fortran;  
+               // for VHDL, TCL, Python, and Fortran no bracket search is possible
   if (f)
   {
     int c=0;
@@ -575,6 +582,7 @@ static bool readCodeFragment(const char *fileName,
       char cn=0;
       while (lineNr<=endLine && !feof(f) && !found)
       {
+        int pc=0;
         while ((c=fgetc(f))!='{' && c!=':' && c!=EOF) 
         {
           //printf("parsing char `%c'\n",c);
@@ -586,10 +594,24 @@ static bool readCodeFragment(const char *fileName,
           {
             col+=Config_getInt("TAB_SIZE") - (col%Config_getInt("TAB_SIZE"));
           }
+          else if (pc=='/' && c=='/') // skip single line comment
+          {
+            while ((c=fgetc(f))!='\n' && c!=EOF) pc=c;
+            if (c=='\n') lineNr++,col=0;
+          }
+          else if (pc=='/' && c=='*') // skip C style comment
+          {
+            while (((c=fgetc(f))!='/' || pc!='*') && c!=EOF) 
+            {
+              if (c=='\n') lineNr++,col=0;
+              pc=c;
+            }
+          }
           else
           {
             col++;
           }
+          pc = c;
         }
         if (c==':')
         {
@@ -898,14 +920,7 @@ void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
         //printf("class=%p scope=%s scopeName=%s\n",md->getClassDef(),scope.data(),scopeName);
         if (!scope.isEmpty() && scope!=scopeName)
         {
-          if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
-          {
-            name.prepend(scope+".");
-          }
-          else
-          {
-            name.prepend(scope+"::");
-          }
+          name.prepend(scope+getLanguageSpecificSeparator(m_impl->lang));
         }
         if (!md->isObjCMethod() &&
             (md->isFunction() || md->isSlot() || 
@@ -1054,7 +1069,7 @@ void Definition::addSourceReferencedBy(MemberDef *md)
     }
     if (m_impl->sourceRefByDict->find(name)==0)
     {
-      m_impl->sourceRefByDict->inSort(name,md);
+      m_impl->sourceRefByDict->append(name,md);
     }
   }
 }
@@ -1078,7 +1093,7 @@ void Definition::addSourceReferences(MemberDef *md)
     }
     if (m_impl->sourceRefsDict->find(name)==0)
     {
-      m_impl->sourceRefsDict->inSort(name,md);
+      m_impl->sourceRefsDict->append(name,md);
     }
   }
 }
@@ -1291,7 +1306,7 @@ void Definition::writePathFragment(OutputList &ol) const
   {
     m_impl->outerScope->writePathFragment(ol);
   }
-  ol.writeString("      <li>");
+  ol.writeString("      <li class=\"navelem\">");
   if (isLinkable())
   {
     if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
@@ -1327,14 +1342,24 @@ void Definition::writePathFragment(OutputList &ol) const
 
 void Definition::writeNavigationPath(OutputList &ol) const
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
+
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
-  ol.writeString("  <div class=\"navpath\">\n");
+  if (generateTreeView)
+  {
+    ol.writeString("</div>\n");
+  }
+
+  ol.writeString("  <div id=\"nav-path\" class=\"navpath\">\n");
   ol.writeString("    <ul>\n");
   writePathFragment(ol);
-  ol.writeString("    </ul>\n");
-  ol.writeString("  </div>\n");
+  if (!generateTreeView)
+  {
+    ol.writeString("    </ul>\n");
+    ol.writeString("  </div>\n");
+  }
 
   ol.popGeneratorState();
 }
@@ -1532,6 +1557,11 @@ void Definition::setReference(const char *r)
   m_impl->ref=r; 
 }
 
+SrcLangExt Definition::getLanguage() const
+{
+  return m_impl->lang;
+}
+
 void Definition::_setSymbolName(const QCString &name) 
 { 
   m_symbolName=name; 
@@ -1559,6 +1589,10 @@ void Definition::makeResident() const
 {
 }
 
+void Definition::setLanguage(SrcLangExt lang) 
+{ 
+  m_impl->lang=lang; 
+}
 
 void Definition::flushToDisk() const
 {
@@ -1585,6 +1619,7 @@ void Definition::flushToDisk() const
   marshalQCString     (Doxygen::symbolStorage,m_impl->defFileName);
   marshalInt          (Doxygen::symbolStorage,m_impl->defLine);
   marshalQCString     (Doxygen::symbolStorage,m_impl->defFileExt);
+  marshalInt          (Doxygen::symbolStorage,(int)m_impl->lang);
   marshalUInt(Doxygen::symbolStorage,END_MARKER);
   delete that->m_impl;
   that->m_impl = 0;
@@ -1617,6 +1652,7 @@ void Definition::loadFromDisk() const
   m_impl->defFileName     = unmarshalQCString     (Doxygen::symbolStorage);
   m_impl->defLine         = unmarshalInt          (Doxygen::symbolStorage);
   m_impl->defFileExt      = unmarshalQCString     (Doxygen::symbolStorage);
+  m_impl->lang            = (SrcLangExt)unmarshalInt(Doxygen::symbolStorage);
   marker = unmarshalUInt(Doxygen::symbolStorage);
   assert(marker==END_MARKER);
 }
