@@ -2,7 +2,7 @@
  *
  * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,6 +24,7 @@
 #include <sys/types.h>
 
 #include "lockingptr.h"
+#include "util.h"
 
 class FileDef;
 class OutputList;
@@ -120,7 +121,7 @@ class Definition : public DefinitionIntf, public LockableObj
 
     /*! Returns the fully qualified name of this definition
      */
-    virtual QCString qualifiedName();
+    virtual QCString qualifiedName() const;
 
     /*! Returns the name of this definition as it appears in the symbol map.
      */
@@ -156,6 +157,16 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! Returns the line number at which the brief description was found. */
     int briefLine() const;
 
+    /*! Returns the documentation found inside the body of a member */
+    QCString inbodyDocumentation() const;
+
+    /*! Returns the file in which the in body documentation was found */
+    QCString inbodyFile() const;
+
+    /*! Returns the line at which the first in body documentation 
+        part was found */
+    int inbodyLine() const;
+
     /*! Returns the file in which the brief description was found. 
      *  This can differ from getDefFileName().
      */
@@ -200,6 +211,11 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! Returns TRUE iff this item is supposed to be hidden from the output. */
     bool isHidden() const;
 
+    /*! returns TRUE if this entity was artificially introduced, for 
+     *  instance because it is used to show a template instantiation relation. 
+     */
+    bool isArtificial() const;
+
     /*! If this definition was imported via a tag file, this function
      *  returns the tagfile for the external project. This can be
      *  translated into an external link target via 
@@ -225,6 +241,9 @@ class Definition : public DefinitionIntf, public LockableObj
      */
     FileDef *getBodyDef();
 
+    /** Returns the programming language this definition was written in. */
+    SrcLangExt getLanguage() const;
+
     LockingPtr<GroupList> partOfGroups() const;
 
     LockingPtr< QList<ListItemInfo> > xrefListItems() const;
@@ -235,20 +254,27 @@ class Definition : public DefinitionIntf, public LockableObj
     LockingPtr<MemberSDict> getReferencesMembers() const;
     LockingPtr<MemberSDict> getReferencedByMembers() const;
 
+
     //-----------------------------------------------------------------------------------
     // ----  setters -----
     //-----------------------------------------------------------------------------------
 
     /*! Sets a new \a name for the definition */
-    void setName(const char *name) { m_name = name; }
+    void setName(const char *name);
 
     /*! Sets the documentation of this definition to \a d. */
-    void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
+    virtual void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
 
     /*! Sets the brief description of this definition to \a b.
      *  A dot is added to the sentence if not available.
      */
-    void setBriefDescription(const char *b,const char *briefFile,int briefLine);
+    virtual void setBriefDescription(const char *b,const char *briefFile,int briefLine);
+
+    /*! Set the documentation that was found inside the body of an item.
+     *  If there was already some documentation set, the new documentation
+     *  will be appended.
+     */
+    virtual void setInbodyDocumentation(const char *d,const char *docFile,int docLine);
 
     /*! Sets the tag file id via which this definition was imported. */
     void setReference(const char *r);
@@ -269,7 +295,10 @@ class Definition : public DefinitionIntf, public LockableObj
     virtual void addInnerCompound(Definition *d);
     virtual void setOuterScope(Definition *d);
 
-    void setHidden(bool b);
+    virtual void setHidden(bool b);
+
+    void setArtificial(bool b);
+    void setLanguage(SrcLangExt lang);
 
     //-----------------------------------------------------------------------------------
     // --- actions ----
@@ -284,6 +313,8 @@ class Definition : public DefinitionIntf, public LockableObj
     void writePathFragment(OutputList &ol) const;
     void writeNavigationPath(OutputList &ol) const;
     virtual void writeQuickMemberLinks(OutputList &,MemberDef *) const {}
+    virtual void writeSummaryLinks(OutputList &) {}
+    QCString pathFragment() const;
 
     /*! Writes the documentation anchors of the definition to 
      *  the Doxygen::tagFile stream.
@@ -311,7 +342,8 @@ class Definition : public DefinitionIntf, public LockableObj
                        const QCString &text,MemberSDict *members,bool);
     void _setBriefDescription(const char *b,const char *briefFile,int briefLine);
     void _setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace,bool atTop);
-    bool _docsAlreadyAdded(const QString &doc);
+    void _setInbodyDocumentation(const char *d,const char *docFile,int docLine);
+    bool _docsAlreadyAdded(const QCString &doc);
     DefinitionImpl *m_impl; // internal structure holding all private data
     QCString m_name;
     bool m_isSymbol;
