@@ -1,4 +1,4 @@
-#include <md5.h>
+#include "md5.h"
 
 #include "dirdef.h"
 #include "filename.h"
@@ -117,7 +117,7 @@ void DirDef::writeDetailedDescription(OutputList &ol,const QCString &title)
     ol.writeRuler();
     ol.pushGeneratorState();
     ol.disableAllBut(OutputGenerator::Html);
-      ol.writeAnchor(0,"_details");
+      ol.writeAnchor(0,"details");
     ol.popGeneratorState();
     ol.startGroupHeader();
     ol.parseText(title);
@@ -152,7 +152,7 @@ void DirDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 
 void DirDef::writeBriefDescription(OutputList &ol)
 {
-  if (!briefDescription().isEmpty()) 
+  if (!briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
   {
     ol.startParagraph();
     ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
@@ -166,7 +166,7 @@ void DirDef::writeBriefDescription(OutputList &ol)
        )
     {
       ol.disableAllBut(OutputGenerator::Html);
-      ol.startTextLink(0,"_details");
+      ol.startTextLink(0,"details");
       ol.parseText(theTranslator->trMore());
       ol.endTextLink();
     }
@@ -191,12 +191,11 @@ void DirDef::writeDirectoryGraph(OutputList &ol)
     {
       msg("Generating dependency graph for directory %s\n",displayName().data());
       ol.disable(OutputGenerator::Man);
-      ol.startParagraph();
+      //ol.startParagraph();
       ol.startDirDepGraph();
-      //TODO: ol.parseText(theTranslator->trDirDepGraph());
-      ol.parseText((QCString)"Directory dependency graph for "+displayName()+":");
+      ol.parseText(theTranslator->trDirDepGraph(displayName()));
       ol.endDirDepGraph(dirDep);
-      ol.endParagraph();
+      //ol.endParagraph();
       ol.enableAll();
     }
   }
@@ -225,7 +224,6 @@ void DirDef::writeSubDirList(OutputList &ol)
       }
       if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startParagraph();
         ol.startMemberDescription();
         ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),
             FALSE, // indexWords
@@ -235,7 +233,6 @@ void DirDef::writeSubDirList(OutputList &ol)
             TRUE   // link from index
            );
         ol.endMemberDescription();
-        ol.endParagraph();
       }
       dd=m_subdirs.next();
     }
@@ -288,7 +285,6 @@ void DirDef::writeFileList(OutputList &ol)
       ol.endMemberItem();
       if (!fd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startParagraph();
         ol.startMemberDescription();
         ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),
             FALSE, // indexWords
@@ -298,7 +294,6 @@ void DirDef::writeFileList(OutputList &ol)
             TRUE   // link from index
            );
         ol.endMemberDescription();
-        ol.endParagraph();
       }
       fd=m_fileList->next();
     }
@@ -318,16 +313,19 @@ void DirDef::endMemberDeclarations(OutputList &ol)
 
 void DirDef::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   
   QCString shortTitle=theTranslator->trDirReference(m_shortName);
   QCString title=theTranslator->trDirReference(m_dispName);
-  startFile(ol,getOutputFileBase(),name(),title,HLI_None,TRUE);
+  startFile(ol,getOutputFileBase(),name(),title,HLI_None,!generateTreeView);
 
-  // write navigation path
-  writeNavigationPath(ol);
-
-  ol.endQuickIndices();
+  if (!generateTreeView)
+  {
+    // write navigation path
+    writeNavigationPath(ol);
+    ol.endQuickIndices();
+  }
 
   startTitle(ol,getOutputFileBase());
   ol.pushGeneratorState();
@@ -382,6 +380,7 @@ void DirDef::writeDocumentation(OutputList &ol)
         }
         break;
       case LayoutDocEntry::ClassIncludes:
+      case LayoutDocEntry::ClassInlineClasses:
       case LayoutDocEntry::ClassInheritanceGraph:
       case LayoutDocEntry::ClassNestedClasses:
       case LayoutDocEntry::ClassCollaborationGraph:
@@ -389,13 +388,16 @@ void DirDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::ClassUsedFiles:
       case LayoutDocEntry::NamespaceNestedNamespaces:
       case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::NamespaceInlineClasses:
       case LayoutDocEntry::FileClasses:
       case LayoutDocEntry::FileNamespaces:
       case LayoutDocEntry::FileIncludes:
       case LayoutDocEntry::FileIncludeGraph:
       case LayoutDocEntry::FileIncludedByGraph: 
       case LayoutDocEntry::FileSourceLink:
+      case LayoutDocEntry::FileInlineClasses:
       case LayoutDocEntry::GroupClasses: 
+      case LayoutDocEntry::GroupInlineClasses: 
       case LayoutDocEntry::GroupNamespaces:
       case LayoutDocEntry::GroupDirs: 
       case LayoutDocEntry::GroupNestedGroups: 
@@ -422,35 +424,18 @@ void DirDef::writeDocumentation(OutputList &ol)
     Doxygen::tagFile << "  </compound>" << endl;
   }
 
-  endFile(ol); 
-  ol.popGeneratorState();
+  ol.endContents();
 
-
-}
-
-#if 0
-void DirDef::writePathFragment(OutputList &ol) const
-{
-  if (m_parent)
+  if (generateTreeView)
   {
-    m_parent->writePathFragment(ol);
-    ol.writeString("&#160;/&#160;");
+    writeNavigationPath(ol);
   }
-  ol.writeObjectLink(getReference(),getOutputFileBase(),0,shortName());
-}
-
-void DirDef::writeNavigationPath(OutputList &ol)
-{
-  ol.pushGeneratorState();
-  ol.disableAllBut(OutputGenerator::Html);
-
-  ol.writeString("<div class=\"nav\">\n");
-  writePathFragment(ol);
-  ol.writeString("</div>\n");
 
+  endFile(ol,TRUE); 
   ol.popGeneratorState();
+
+
 }
-#endif
 
 void DirDef::setLevel()
 {
@@ -701,6 +686,7 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
 
 void DirRelation::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
@@ -710,28 +696,24 @@ void DirRelation::writeDocumentation(OutputList &ol)
   QCString title=theTranslator->trDirRelation(
                  m_src->displayName()+" -> "+
                  m_dst->dir()->shortName());
-  startFile(ol,getOutputFileBase(),getOutputFileBase(),title);
+  startFile(ol,getOutputFileBase(),getOutputFileBase(),
+            title,HLI_None,!generateTreeView,m_src->getOutputFileBase());
 
-  // write navigation path
-  m_src->writeNavigationPath(ol);
+  if (!generateTreeView)
+  {
+    // write navigation path
+    m_src->writeNavigationPath(ol);
+    ol.endQuickIndices();
+  }
   ol.startContents();
 
-  //startTitle(ol,getOutputFileBase());
-  //  ol.parseText(shortTitle);
-  //endTitle(ol,getOutputFileBase(),title);
   ol.writeString("<h3>"+shortTitle+"</h3>");
-  
   ol.writeString("<table class=\"dirtab\">");
   ol.writeString("<tr class=\"dirtab\">");
-  // TODO: translate me! "File in %s"
   ol.writeString("<th class=\"dirtab\">");
   ol.parseText(theTranslator->trFileIn(m_src->pathFragment()));
-  //m_src->writePathFragment(ol);
   ol.writeString("</th>");
-  // TODO: translate me! "Includes file in %s"
   ol.writeString("<th class=\"dirtab\">");
-  //ol.writeString("Includes file in ");
-  //m_dst->dir()->writePathFragment(ol);
   ol.parseText(theTranslator->trIncludesFileIn(m_dst->dir()->pathFragment()));
   ol.writeString("</th>");
   ol.writeString("</tr>");
@@ -750,8 +732,15 @@ void DirRelation::writeDocumentation(OutputList &ol)
     ol.writeString("</tr>");
   }
   ol.writeString("</table>");
+
+  ol.endContents();
   
-  endFile(ol); 
+  if (generateTreeView)
+  {
+    m_src->writeNavigationPath(ol);
+  }
+
+  endFile(ol,TRUE); 
   ol.popGeneratorState();
 }
 
