@@ -3,7 +3,7 @@
  * $Id: doxygen.h,v 1.39 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,9 +20,9 @@
 #define DOXYGEN_H
 
 #include "qtbc.h"
-#include <qtextstream.h>
 #include <qdatetime.h>
 #include <qcache.h>
+#include "ftextstream.h"
 #include "groupdef.h"
 #include "filedef.h"
 #include "classdef.h"
@@ -37,17 +37,18 @@
 #include "reflist.h"
 #include "dirdef.h"
 #include "index.h"
+#include "docsets.h"
 
 class PageSList;
 class PageSDict;
 class PageDef;
 class SearchIndex;
-class DirDef;
 class ParserManager;
 class ObjCache;
 class Store;
 class QFileInfo;
 class BufStr;
+class CiteDict;
 
 typedef QList<QCString>    StringList;
 typedef QDict<FileDef>     FileDict;
@@ -71,7 +72,7 @@ struct LookupInfo
   QCString   resolvedType;
 };
 
-extern QCString spaces;
+extern QCString g_spaces;
 
 /*! \brief This class serves as a namespace for global variables used by doxygen.
  *
@@ -92,10 +93,11 @@ class Doxygen
     static FileNameList             *inputNameList;
     static FileNameDict             *imageNameDict;
     static FileNameDict             *dotFileNameDict;
+    static FileNameDict             *mscFileNameDict;
     static QStrList                  tagfileList;
     static MemberNameSDict          *memberNameSDict;
     static MemberNameSDict          *functionNameSDict;
-    static QTextStream               tagFile;
+    static FTextStream               tagFile;
     static SectionDict               sectionDict;
     static StringDict                namespaceAliasDict;
     static GroupSDict               *groupSDict;
@@ -111,7 +113,6 @@ class Doxygen
     static QDict<RefList>           *xrefLists; // array of xref lists: todo, test, bug, deprecated ...
     static QCString                  htmlFileExtension;
     static bool                      parseSourcesNeeded;
-    static double                    sysElapsedTime;
     static QTime                     runningTime;
     static SearchIndex              *searchIndex;
     static QDict<DefinitionIntf>    *symbolMap;
@@ -126,14 +127,19 @@ class Doxygen
     static Store                    *symbolStorage;
     static QCString                  objDBFileName;
     static QCString                  entryDBFileName;
+    static CiteDict                 *citeDict;
     static bool                      gatherDefines;
     static bool                      userComments;
     static IndexList                 indexList;
+    static int                       subpageNestingLevel;
+    static QCString                  spaces;
 };
 
 void initDoxygen();
 void readConfiguration(int argc, char **argv);
 void checkConfiguration();
+void adjustConfiguration();
+void searchInputFiles(StringList &inputFiles);
 void parseInput();
 void generateOutput();
 void readAliases();
