@@ -2,7 +2,7 @@
  *
  * $Id: entry.h,v 1.36 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -22,6 +22,7 @@
 #include <qlist.h>
 
 #include <qgstring.h>
+#include "util.h"
 
 struct SectionInfo;
 class QFile;
@@ -33,6 +34,8 @@ class StorageIntf;
 enum Protection { Public, Protected, Private, Package } ;
 enum Specifier { Normal, Virtual, Pure } ;
 enum MethodTypes { Method, Signal, Slot, DCOP, Property, Event };
+enum RelatesType { Simple, Duplicate, MemberOf };
+enum Relationship { Member, Related, Foreign };
 
 struct ListItemInfo
 {
@@ -189,17 +192,8 @@ class Entry
     /*! Kind of entries that are supported */
     enum Sections { 
       CLASS_SEC        = 0x00000001, 
-      //STRUCT_SEC       = 0x00000002,
-      //UNION_SEC        = 0x00000004, 
-      //EXCEPTION_SEC    = 0x00000008,
       NAMESPACE_SEC    = 0x00000010,
-      //INTERFACE_SEC    = 0x00000020,
-      //PROTOCOL_SEC     = 0x00000040,
-      //CATEGORY_SEC     = 0x00000080,
-      COMPOUND_MASK    = CLASS_SEC //| STRUCT_SEC | UNION_SEC | 
-                         //INTERFACE_SEC | EXCEPTION_SEC | 
-                         //PROTOCOL_SEC | CATEGORY_SEC
-                         ,
+      COMPOUND_MASK    = CLASS_SEC,
       SCOPE_MASK       = COMPOUND_MASK | NAMESPACE_SEC,
       
       CLASSDOC_SEC     = 0x00000800, 
@@ -241,26 +235,35 @@ class Entry
       PACKAGE_SEC      = 0x15000000,
       PACKAGEDOC_SEC   = 0x16000000,
       OBJCIMPL_SEC     = 0x17000000,
-      DIRDOC_SEC       = 0x18000000,
+      DIRDOC_SEC       = 0x18000000
     };
     enum MemberSpecifier
     {
-      Inline    = 0x0001,
-      Explicit  = 0x0002,
-      Mutable   = 0x0004,
-      Settable  = 0x0008,
-      Gettable  = 0x0010,
-      Readable  = 0x0020,
-      Writable  = 0x0040,
-      Final     = 0x0080,
-      Abstract  = 0x0100,
-      Addable   = 0x0200,
-      Removable = 0x0400,
-      Raisable  = 0x0800,
-      Override  = 0x1000,
-      New       = 0x2000,
-      Sealed    = 0x4000,
-      Initonly  = 0x8000
+      Inline      = 0x00000001,
+      Explicit    = 0x00000002,
+      Mutable     = 0x00000004,
+      Settable    = 0x00000008,
+      Gettable    = 0x00000010,
+      Readable    = 0x00000020,
+      Writable    = 0x00000040,
+      Final       = 0x00000080,
+      Abstract    = 0x00000100,
+      Addable     = 0x00000200,
+      Removable   = 0x00000400,
+      Raisable    = 0x00000800,
+      Override    = 0x00001000,
+      New         = 0x00002000,
+      Sealed      = 0x00004000,
+      Initonly    = 0x00008000,
+      Optional    = 0x00010000,
+      Required    = 0x00020000,
+      NonAtomic   = 0x00040000,
+      Copy        = 0x00080000,
+      Retain      = 0x00100000,
+      Assign      = 0x00200000,
+      Composition = 0x00400000,
+      Aggregation = 0x00800000,
+      Association = 0x01000000
     };
     enum ClassSpecifier
     {
@@ -284,26 +287,45 @@ class Entry
       GROUPDOC_WEAK           //!< weakgroup
     };                        //!< kind of group
 
-
     Entry();
     Entry(const Entry &);
-    ~Entry();
+   ~Entry();
+
+    /*! Returns the static size of the Entry (so excluding any dynamic memory) */
     int getSize();
+
     void addSpecialListItem(const char *listName,int index);
     void createNavigationIndex(EntryNav *rootNav,FileStorage *storage,FileDef *fd);
 
     // while parsing a file these function can be used to navigate/build the tree
     void setParent(Entry *parent) { m_parent = parent; }
+
+    /*! Returns the parent for this Entry or 0 if this entry has no parent. */
     Entry *parent() const { return m_parent; }
+
+    /*! Returns the list of children for this Entry 
+     *  @see addSubEntry() and removeSubEntry()
+     */
     const QList<Entry> *children() const { return m_sublist; }
 
-    /*! Adds entry \e as a child to this entry */
-    void	addSubEntry (Entry* e) ;
+    /*! Adds entry \a e as a child to this entry */
+    void addSubEntry (Entry* e) ;
+
+    /*! Removes entry \a e from the list of children. 
+     *  Returns a pointer to the entry or 0 if the entry was not a child. 
+     *  Note the entry will not be deleted.
+     */ 
+    Entry *removeSubEntry(Entry *e);
+
     /*! Restore the state of this Entry to the default value it has
      *  at construction time. 
      */
     void reset();
+
+    /*! Serialize this entry to a persistent storage stream. */
     void marshall(StorageIntf *);
+
+    /*! Reinitialize this entry from a persistent storage stream. */
     void unmarshall(StorageIntf *);
 
   public:
@@ -344,7 +366,7 @@ class Entry
     int          inbodyLine;  //!< line number at which the body doc was found
     QCString     inbodyFile;  //!< file in which the body doc was found
     QCString     relates;     //!< related class (doc block)
-    bool         relatesDup;  //!< keep duplicate doc in original file also
+    RelatesType  relatesType; //!< how relates is handled
     QCString     read;        //!< property read accessor
     QCString     write;       //!< property write accessor
     QCString     inside;      //!< name of the class in which documents are found
@@ -359,10 +381,12 @@ class Entry
     QCString	fileName;     //!< file this entry was extracted from
     int		startLine;    //!< start line of entry in the source
     QList<ListItemInfo> *sli; //!< special lists (test/todo/bug/deprecated/..) this entry is in
-    bool        objc;         //!< Objective-C construct
+    SrcLangExt  lang;         //!< programming language in which this entry was found
     bool        hidden;       //!< does this represent an entity that is hidden from the output
+    bool        artificial;   //!< Artificially introduced item
     GroupDocType groupDocType;
 
+
     static int  num;          //!< counts the total number of entries
 
     /// return the command name used to define GROUPDOC_SEC
@@ -413,6 +437,7 @@ class EntryNav
 
     Entry *entry() const { return m_info; }
     int section() const { return m_section; }
+    SrcLangExt lang() const { return m_lang; }
     const QCString &type() const { return m_type; }
     const QCString &name() const { return m_name; }
     TagInfo *tagInfo() const { return m_tagInfo; }
@@ -432,6 +457,7 @@ class EntryNav
     QCString	 m_name;        //!< member name
     TagInfo     *m_tagInfo;      //!< tag file info
     FileDef     *m_fileDef;
+    SrcLangExt   m_lang;         //!< programming language in which this entry was found
 
     Entry       *m_info;
     int64        m_offset;
