@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -61,7 +61,7 @@ class DevNullCodeDocInterface : public CodeOutputInterface
 //---------------------------------------------------------------------------
 
 /*! create a new file definition, where \a p is the file path, 
-    \a nm the file name, and \a ref is an HTML anchor name if the
+    \a nm the file name, and \a lref is an HTML anchor name if the
     file was read from a tag file or 0 otherwise
 */
 FileDef::FileDef(const char *p,const char *nm,
@@ -92,7 +92,10 @@ FileDef::FileDef(const char *p,const char *nm,
   {
     docname.prepend(stripFromPath(path.copy()));
   }
-  m_isJava          = name().right(5)==".java";
+  SrcLangExt lang = getLanguageFromFileName(name());
+  setLanguage(lang);
+  //m_isJava          = lang==SrcLangExt_Java;
+  //m_isCSharp        = lang==SrcLangExt_CSharp;
   memberGroupSDict = 0;
   acquireFileVersion();
   m_subGrouping=Config_getBool("SUBGROUPING");
@@ -168,8 +171,8 @@ void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
   {
     ol.writeRuler();
     ol.pushGeneratorState();
-    ol.disable(OutputGenerator::Html);
-      ol.writeAnchor(0,"_details"); 
+    ol.disableAllBut(OutputGenerator::Html);
+      ol.writeAnchor(0,"details"); 
     ol.popGeneratorState();
     ol.startGroupHeader();
     ol.parseText(title);
@@ -186,7 +189,7 @@ void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
       ol.pushGeneratorState();
         ol.disable(OutputGenerator::Man);
         ol.disable(OutputGenerator::RTF);
-        ol.newParagraph();
+        // ol.newParagraph(); // FIXME:PARA
         ol.enableAll();
         ol.disableAllBut(OutputGenerator::Man);
         ol.writeString("\n\n");
@@ -218,9 +221,11 @@ void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 
 void FileDef::writeBriefDescription(OutputList &ol)
 {
-  if (!briefDescription().isEmpty()) 
+  if (!briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
   {
-    ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
+    ol.startParagraph();
+    ol.parseDoc(briefFile(),briefLine(),this,0,
+                briefDescription(),TRUE,FALSE,0,TRUE,FALSE);
     ol.pushGeneratorState();
     ol.disable(OutputGenerator::RTF);
     ol.writeString(" \n");
@@ -231,16 +236,17 @@ void FileDef::writeBriefDescription(OutputList &ol)
        )
     {
       ol.disableAllBut(OutputGenerator::Html);
-      ol.startTextLink(0,"_details");
+      ol.startTextLink(0,"details");
       ol.parseText(theTranslator->trMore());
       ol.endTextLink();
     }
     ol.popGeneratorState();
+    ol.endParagraph();
 
-    ol.pushGeneratorState();
-    ol.disable(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.popGeneratorState();
+    //ol.pushGeneratorState();
+    //ol.disable(OutputGenerator::RTF);
+    //ol.newParagraph();
+    //ol.popGeneratorState();
   }
   ol.writeSynopsis();
 }
@@ -259,10 +265,8 @@ void FileDef::writeIncludeFiles(OutputList &ol)
       bool isIDLorJava = FALSE;
       if (fd)
       {
-        isIDLorJava = fd->name().right(4)==".idl" ||   // M$ or Corba IDL
-                      fd->name().right(5)==".pidl" ||
-                      fd->name().right(5)==".java" ||  // Sun's Java
-                      fd->name().right(4)==".jsl";     // M$ J#
+        SrcLangExt lang   = fd->getLanguage();
+        isIDLorJava = lang==SrcLangExt_IDL || lang==SrcLangExt_Java;
       }
       ol.startTypewriter();
       if (isIDLorJava) // IDL/Java include
@@ -337,7 +341,6 @@ void FileDef::writeIncludeGraph(OutputList &ol)
     {
       ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
-      ol.newParagraph();
       ol.startInclDepGraph();
       ol.parseText(theTranslator->trInclDepGraph(name()));
       ol.endInclDepGraph(incDepGraph);
@@ -358,7 +361,6 @@ void FileDef::writeIncludedByGraph(OutputList &ol)
     {
       ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
-      ol.newParagraph();
       ol.startInclDepGraph();
       ol.parseText(theTranslator->trInclByDepGraph());
       ol.endInclDepGraph(incDepGraph);
@@ -376,10 +378,11 @@ void FileDef::writeSourceLink(OutputList &ol)
   if (generateSourceFile())
   {
     ol.disableAllBut(OutputGenerator::Html);
-    ol.newParagraph();
+    ol.startParagraph();
     ol.startTextLink(includeName(),0);
     ol.parseText(theTranslator->trGotoSourceCode());
     ol.endTextLink();
+    ol.endParagraph();
     ol.enableAll();
   }
 }
@@ -396,6 +399,11 @@ void FileDef::writeClassDeclarations(OutputList &ol,const QCString &title)
   if (classSDict) classSDict->writeDeclaration(ol,0,title,FALSE);
 }
 
+void FileDef::writeInlineClasses(OutputList &ol)
+{
+  if (classSDict) classSDict->writeDocumentation(ol,this);
+}
+
 void FileDef::startMemberDeclarations(OutputList &ol)
 {
   ol.startMemberSections();
@@ -429,6 +437,7 @@ void FileDef::writeMemberGroups(OutputList &ol)
   /* write user defined member groups */
   if (memberGroupSDict)
   {
+    memberGroupSDict->sort();
     MemberGroupSDict::Iterator mgli(*memberGroupSDict);
     MemberGroup *mg;
     for (;(mg=mgli.current());++mgli)
@@ -454,11 +463,47 @@ void FileDef::writeAuthorSection(OutputList &ol)
   ol.popGeneratorState();
 }
 
+void FileDef::writeSummaryLinks(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::File));
+  LayoutDocEntry *lde;
+  bool first=TRUE;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    if ((lde->kind()==LayoutDocEntry::FileClasses && classSDict && classSDict->declVisible()) || 
+        (lde->kind()==LayoutDocEntry::FileNamespaces && namespaceSDict && namespaceSDict->declVisible())
+       )
+    {
+      LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+      QCString label = lde->kind()==LayoutDocEntry::FileClasses ? "nested-classes" : "namespaces";
+      writeSummaryLink(ol,label,ls->title,first);
+    }
+    else if (lde->kind()==LayoutDocEntry::MemberDecl)
+    {
+      LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+      MemberList * ml = getMemberList(lmd->type);
+      if (ml && ml->declVisible())
+      {
+        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+      }
+    }
+  }
+  if (!first)
+  {
+    ol.writeString("  </div>\n");
+  }
+  ol.popGeneratorState();
+}
+
 /*! Write the documentation page for this file to the file of output
     generators \a ol. 
 */
 void FileDef::writeDocumentation(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   //funcList->countDecMembers();
   
   //QCString fn = name();
@@ -479,12 +524,14 @@ void FileDef::writeDocumentation(OutputList &ol)
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
-    startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible,TRUE);
-    getDirDef()->writeNavigationPath(ol);
-    ol.endQuickIndices();
-    ol.startContents();
+    startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible,!generateTreeView);
+    if (!generateTreeView)
+    {
+      getDirDef()->writeNavigationPath(ol);
+      ol.endQuickIndices();
+    }
     QCString pageTitleShort=theTranslator->trFileReference(name());
-    startTitle(ol,getOutputFileBase());
+    startTitle(ol,getOutputFileBase(),this);
     ol.pushGeneratorState();
       ol.disableAllBut(OutputGenerator::Html);
       ol.parseText(pageTitleShort); // Html only
@@ -497,12 +544,19 @@ void FileDef::writeDocumentation(OutputList &ol)
   }
   else
   {
-    startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible);
-    startTitle(ol,getOutputFileBase());
+    startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible,!generateTreeView);
+    if (!generateTreeView)
+    {
+      ol.endQuickIndices();
+    }
+    startTitle(ol,getOutputFileBase(),this);
     ol.parseText(pageTitle);
     addGroupListToTitle(ol,this);
     endTitle(ol,getOutputFileBase(),title);
   }
+
+  ol.startContents();
+
   if (!fileVersion.isEmpty())
   {
     ol.disableAllBut(OutputGenerator::Html);
@@ -512,7 +566,7 @@ void FileDef::writeDocumentation(OutputList &ol)
     ol.enableAll();
   }
   
-  if (Config_getBool("SEARCHENGINE"))
+  if (Doxygen::searchIndex)
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
     Doxygen::searchIndex->addWord(localName(),TRUE);
@@ -588,6 +642,9 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::MemberDefStart: 
         startMemberDocumentation(ol);
         break; 
+      case LayoutDocEntry::FileInlineClasses:
+        writeInlineClasses(ol);
+        break;
       case LayoutDocEntry::MemberDef: 
         {
           LayoutDocEntryMemberDef *lmd = (LayoutDocEntryMemberDef*)lde;
@@ -606,9 +663,12 @@ void FileDef::writeDocumentation(OutputList &ol)
       case LayoutDocEntry::ClassCollaborationGraph:
       case LayoutDocEntry::ClassAllMembersLink:
       case LayoutDocEntry::ClassUsedFiles:
+      case LayoutDocEntry::ClassInlineClasses:
       case LayoutDocEntry::NamespaceNestedNamespaces:
       case LayoutDocEntry::NamespaceClasses:
+      case LayoutDocEntry::NamespaceInlineClasses:
       case LayoutDocEntry::GroupClasses: 
+      case LayoutDocEntry::GroupInlineClasses: 
       case LayoutDocEntry::GroupNamespaces:
       case LayoutDocEntry::GroupDirs: 
       case LayoutDocEntry::GroupNestedGroups: 
@@ -632,7 +692,14 @@ void FileDef::writeDocumentation(OutputList &ol)
     Doxygen::tagFile << "  </compound>" << endl;
   }
 
-  endFile(ol);
+  ol.endContents();
+
+  if (generateTreeView)
+  {
+    writeNavigationPath(ol);
+  }
+
+  endFile(ol,TRUE);
 
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
@@ -706,6 +773,7 @@ void FileDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
 /*! Write a source listing of this file to the output */
 void FileDef::writeSource(OutputList &ol)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
   static bool latexSourceCode   = Config_getBool("LATEX_SOURCE_CODE");
   QCString title = docname;
@@ -720,22 +788,28 @@ void FileDef::writeSource(OutputList &ol)
 
   if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
   {
-    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,TRUE);
-    getDirDef()->writeNavigationPath(ol);
-    ol.endQuickIndices();
-    ol.startContents();
+    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,
+        !generateTreeView,getOutputFileBase());
+    if (!generateTreeView)
+    {
+      getDirDef()->writeNavigationPath(ol);
+      ol.endQuickIndices();
+    }
     startTitle(ol,getOutputFileBase());
     ol.parseText(name());
     endTitle(ol,getOutputFileBase(),title);
   }
   else
   {
-    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,TRUE);
+    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,
+        !generateTreeView,getOutputFileBase());
     startTitle(ol,getSourceFileBase());
     ol.parseText(title);
     endTitle(ol,getSourceFileBase(),0);
   }
 
+  ol.startContents();
+
   if (isLinkable())
   {
     if (latexSourceCode) ol.disable(OutputGenerator::Latex);
@@ -749,11 +823,20 @@ void FileDef::writeSource(OutputList &ol)
   pIntf->resetCodeParserState();
   ol.startCodeFragment();
   pIntf->parseCode(ol,0,
-            fileToString(absFilePath(),filterSourceFiles),
+            fileToString(absFilePath(),filterSourceFiles,TRUE),
             FALSE,0,this
            );
   ol.endCodeFragment();
-  endFile(ol);
+  ol.endContents();
+  if (generateTreeView)
+  {
+    writeNavigationPath(ol);
+    endFile(ol,TRUE);
+  }
+  else
+  {
+    endFile(ol);
+  }
   ol.enableAll();
 }
 
@@ -765,7 +848,7 @@ void FileDef::parseSource()
   pIntf->resetCodeParserState();
   pIntf->parseCode(
             devNullIntf,0,
-            fileToString(absFilePath(),filterSourceFiles),
+            fileToString(absFilePath(),filterSourceFiles,TRUE),
             FALSE,0,this
            );
 }
@@ -1092,8 +1175,10 @@ void FileDef::addListReferences()
   {
     LockingPtr< QList<ListItemInfo> > xrefItems = xrefListItems();
     addRefItem(xrefItems.pointer(),
+               getOutputFileBase(),
                theTranslator->trFile(TRUE,TRUE),
-               getOutputFileBase(),name()
+               getOutputFileBase(),name(),
+               0
               );
   }
   if (memberGroupSDict)
@@ -1413,7 +1498,7 @@ bool FileDef::isDocumentationFile() const
 void FileDef::acquireFileVersion()
 {
   QCString vercmd = Config_getString("FILE_VERSION_FILTER");
-  if (!vercmd.isEmpty()) 
+  if (!vercmd.isEmpty() && filepath!="generated") 
   {
     msg("Version of %s : ",filepath.data());
     QCString cmd = vercmd+" \""+filepath+"\"";
@@ -1421,7 +1506,7 @@ void FileDef::acquireFileVersion()
     FILE *f=portable_popen(cmd,"r");
     if (!f)
     {
-      err("Error: could not execute %s\n",vercmd.data());
+      err("error: could not execute %s\n",vercmd.data());
       return;
     }
     const int bufSize=1024;
@@ -1489,12 +1574,16 @@ void FileDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   MemberList *ml = createMemberList(lt);
-  if (((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
-      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs)
-     )
+  ml->setNeedsSorting(
+       ((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
+       ((ml->listType()&MemberList::documentationLists) && sortMemberDocs));
+  ml->append(md);
+#if 0
+  if (ml->needsSorting())
     ml->inSort(md);
   else
     ml->append(md);
+#endif
   if (lt&MemberList::documentationLists)
   {
     ml->setInFile(TRUE);
@@ -1502,6 +1591,16 @@ void FileDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   if (ml->listType()&MemberList::declarationLists) md->setSectionList(this,ml);
 }
 
+void FileDef::sortMemberLists()
+{
+  MemberList *ml = m_memberLists.first();
+  while (ml)
+  {
+    if (ml->needsSorting()) { ml->sort(); ml->setNeedsSorting(FALSE); }
+    ml = m_memberLists.next();
+  }
+}
+
 MemberList *FileDef::getMemberList(MemberList::ListType lt) const
 {
   FileDef *that = (FileDef*)this;
@@ -1546,3 +1645,23 @@ bool FileDef::isLinkableInProject() const
   return hasDocumentation() && !isReference() && showFiles;
 }
 
+bool FileDef::includes(FileDef *incFile,QDict<FileDef> *includedFiles) const
+{
+  if (incFile==this) return TRUE;
+  //printf("%s::includes(%s)\n",name().data(),incFile->name().data());
+  includedFiles->insert(absFilePath(),this);
+  if (includeList)
+  {
+    QListIterator<IncludeInfo> ili(*includeList);
+    IncludeInfo *ii;
+    for (;(ii=ili.current());++ili)
+    {
+      if (ii->fileDef && 
+          includedFiles->find(ii->fileDef->absFilePath())==0 &&
+          ii->fileDef->includes(incFile,includedFiles)) return TRUE;
+    }
+  }
+  return FALSE;
+}
+
+
