@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,6 +27,7 @@
 #include "parserintf.h"
 #include "msc.h"
 #include "htmlattrib.h"
+#include "cite.h"
 
 static QCString escapeLabelName(const char *s)
 {
@@ -100,7 +101,8 @@ LatexDocVisitor::LatexDocVisitor(FTextStream &t,CodeOutputInterface &ci,
                                  const char *langExt,bool insideTabbing) 
   : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), 
     m_insideItem(FALSE), m_hide(FALSE), m_insideTabbing(insideTabbing),
-    m_langExt(langExt), m_currentColumn(0), m_inRowspan(FALSE)
+    m_langExt(langExt), m_currentColumn(0), 
+    m_inRowspan(FALSE)
 {
 }
 
@@ -148,6 +150,7 @@ void LatexDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "\\&"; break;
     case DocSymbol::Dollar:  m_t << "\\$"; break;
     case DocSymbol::Hash:    m_t << "\\#"; break;
+    case DocSymbol::DoubleColon:  m_t << "::"; break;
     case DocSymbol::Percent: m_t << "\\%"; break;
     case DocSymbol::Copy:    m_t << "\\copyright"; break;
     case DocSymbol::Tm:      m_t << "\\texttrademark"; break;
@@ -369,11 +372,11 @@ void LatexDocVisitor::visit(DocVerbatim *s)
 void LatexDocVisitor::visit(DocAnchor *anc)
 {
   if (m_hide) return;
-  m_t << "\\label{" << anc->file() << "_" << anc->anchor() << "}" << endl;
+  m_t << "\\label{" << anc->file() << "_" << anc->anchor() << "}%" << endl;
   if (!anc->file().isEmpty() && Config_getBool("PDF_HYPERLINKS")) 
   {
     m_t << "\\hypertarget{" << anc->file() << "_" << anc->anchor() 
-      << "}{}" << endl;
+      << "}{}%" << endl;
   }    
 }
 
@@ -412,6 +415,19 @@ void LatexDocVisitor::visit(DocInclude *inc)
       m_t << inc->text();
       m_t << "\\end{DoxyVerbInclude}\n";
       break;
+    case DocInclude::Snippet:
+      {
+         m_t << "\n\\begin{DoxyCodeInclude}\n";
+         Doxygen::parserManager->getParser(inc->extension())
+                               ->parseCode(m_ci,
+                                           inc->context(),
+                                           extractBlock(inc->text(),inc->blockId()),
+                                           inc->isExample(),
+                                           inc->exampleFile()
+                                          );
+         m_t << "\\end{DoxyCodeInclude}" << endl;
+      }
+      break;
   }
 }
 
@@ -466,6 +482,24 @@ void LatexDocVisitor::visit(DocSimpleSectSep *)
 {
 }
 
+void LatexDocVisitor::visit(DocCite *cite)
+{
+  if (m_hide) return;
+  if (!cite->file().isEmpty()) 
+  {
+    //startLink(cite->ref(),cite->file(),cite->anchor());
+    QCString anchor = cite->anchor();
+    anchor = anchor.mid(CiteConsts::anchorPrefix.length()); // strip prefix
+    m_t << "\\cite{" << anchor << "}";
+  }
+  else
+  {
+    m_t << "{\\bfseries [";
+    filter(cite->text());
+    m_t << "]}";
+  }
+}
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -577,6 +611,10 @@ void LatexDocVisitor::visitPre(DocSimpleSect *s)
       m_t << "\\begin{DoxyPostcond}{";
       filter(theTranslator->trPostcondition());
       break;
+    case DocSimpleSect::Copyright:
+      m_t << "\\begin{DoxyCopyright}{";
+      filter(theTranslator->trCopyright());
+      break;
     case DocSimpleSect::Invar:
       m_t << "\\begin{DoxyInvariant}{";
       filter(theTranslator->trInvariant());
@@ -647,6 +685,9 @@ void LatexDocVisitor::visitPost(DocSimpleSect *s)
     case DocSimpleSect::Post:
       m_t << "\n\\end{DoxyPostcond}\n";
       break;
+    case DocSimpleSect::Copyright:
+      m_t << "\n\\end{DoxyCopyright}\n";
+      break;
     case DocSimpleSect::Invar:
       m_t << "\n\\end{DoxyInvariant}\n";
       break;
@@ -756,16 +797,32 @@ void LatexDocVisitor::visitPost(DocHtmlListItem *)
 //  m_t << "\\end{alltt}\\normalsize " << endl;
 //}
 
-void LatexDocVisitor::visitPre(DocHtmlDescList *)
+void LatexDocVisitor::visitPre(DocHtmlDescList *dl)
 {
   if (m_hide) return;
-  m_t << "\n\\begin{DoxyDescription}";
+  QCString val = dl->attribs().find("class");
+  if (val=="reflist")
+  {
+    m_t << "\n\\begin{DoxyRefList}";
+  }
+  else
+  {
+    m_t << "\n\\begin{DoxyDescription}";
+  }
 }
 
-void LatexDocVisitor::visitPost(DocHtmlDescList *) 
+void LatexDocVisitor::visitPost(DocHtmlDescList *dl) 
 {
   if (m_hide) return;
-  m_t << "\n\\end{DoxyDescription}";
+  QCString val = dl->attribs().find("class");
+  if (val=="reflist")
+  {
+    m_t << "\n\\end{DoxyRefList}";
+  }
+  else
+  {
+    m_t << "\n\\end{DoxyDescription}";
+  }
 }
 
 void LatexDocVisitor::visitPre(DocHtmlDescTitle *)
@@ -893,15 +950,15 @@ void LatexDocVisitor::visitPost(DocHtmlCell *c)
 void LatexDocVisitor::visitPre(DocInternal *)
 {
   if (m_hide) return;
-  m_t << "\\begin{DoxyInternal}{";
-  filter(theTranslator->trForInternalUseOnly());
-  m_t << "}\n";
+  //m_t << "\\begin{DoxyInternal}{";
+  //filter(theTranslator->trForInternalUseOnly());
+  //m_t << "}\n";
 }
 
 void LatexDocVisitor::visitPost(DocInternal *) 
 {
   if (m_hide) return;
-  m_t << "\\end{DoxyInternal}" << endl;
+  //m_t << "\\end{DoxyInternal}" << endl;
 }
 
 void LatexDocVisitor::visitPre(DocHRef *href)
@@ -1257,7 +1314,9 @@ void LatexDocVisitor::visitPost(DocParamList *pl)
 void LatexDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
-  m_t << "\\begin{Desc}" << endl;
+  m_t << "\\begin{DoxyRefDesc}{";
+  filter(x->title());
+  m_t << "}" << endl;
   bool anonymousEnum = x->file()=="@";
   m_t << "\\item[";
   if (Config_getBool("PDF_HYPERLINKS") && !anonymousEnum)
@@ -1277,7 +1336,7 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
 void LatexDocVisitor::visitPost(DocXRefItem *)
 {
   if (m_hide) return;
-  m_t << "\\end{Desc}" << endl;
+  m_t << "\\end{DoxyRefDesc}" << endl;
 }
 
 void LatexDocVisitor::visitPre(DocInternalRef *ref)
@@ -1382,14 +1441,11 @@ void LatexDocVisitor::startDotFile(const QCString &fileName,
   {
     baseName=baseName.right(baseName.length()-i-1);
   } 
-  if (baseName.right(4)==".eps" || baseName.right(4)==".pdf")
+  if ((i=baseName.find('.'))!=-1)
   {
-    baseName=baseName.left(baseName.length()-4);
-  }
-  if (baseName.right(4)==".dot")
-  {
-    baseName=baseName.left(baseName.length()-4);
+    baseName=baseName.left(i);
   }
+  baseName.prepend("dot_");
   QCString outDir = Config_getString("LATEX_OUTPUT");
   QCString name = fileName;
   writeDotGraphFromFile(name,outDir,baseName,EPS);
@@ -1449,14 +1505,12 @@ void LatexDocVisitor::startMscFile(const QCString &fileName,
   {
     baseName=baseName.right(baseName.length()-i-1);
   } 
-  if (baseName.right(4)==".eps" || baseName.right(4)==".pdf")
+  if ((i=baseName.find('.'))!=-1)
   {
-    baseName=baseName.left(baseName.length()-4);
-  }
-  if (baseName.right(4)==".dot")
-  {
-    baseName=baseName.left(baseName.length()-4);
+    baseName=baseName.left(i);
   }
+  baseName.prepend("msc_");
+
   QCString outDir = Config_getString("LATEX_OUTPUT");
   QCString name = fileName;
   writeMscGraphFromFile(name,outDir,baseName,MSC_EPS); 
@@ -1514,7 +1568,7 @@ void LatexDocVisitor::writeMscFile(const QCString &baseName)
     shortName=shortName.right(shortName.length()-i-1);
   } 
   QCString outDir = Config_getString("LATEX_OUTPUT");
-  writeMscGraphFromFile(baseName,outDir,baseName,MSC_EPS);
+  writeMscGraphFromFile(baseName,outDir,shortName,MSC_EPS);
   m_t << "\n\\begin{DoxyImageNoCaption}"
          "  \\mbox{\\includegraphics";
   m_t << "{" << shortName << "}";
