@@ -2,7 +2,7 @@
  *
  * $Id: latexgen.h,v 1.50 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -30,6 +30,7 @@ class LatexGenerator : public OutputGenerator
     static void init();
     static void writeStyleSheetFile(QFile &f);
     static void writeHeaderFile(QFile &f);
+    static void writeFooterFile(QFile &f);
 
     //OutputGenerator *copy();
     //OutputGenerator *clone() { return new LatexGenerator(*this); }
@@ -37,9 +38,9 @@ class LatexGenerator : public OutputGenerator
     void enable() 
     { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
-    void enableIf(OutputType o)  { if (o==Latex) active=TRUE;  }
-    void disableIf(OutputType o) { if (o==Latex) active=FALSE; }
-    void disableIfNot(OutputType o) { if (o!=Latex) active=FALSE; }
+    void enableIf(OutputType o)  { if (o==Latex) enable();  }
+    void disableIf(OutputType o) { if (o==Latex) disable(); }
+    void disableIfNot(OutputType o) { if (o!=Latex) disable(); }
     bool isEnabled(OutputType o) { return (o==Latex && active); } 
     OutputGenerator *get(OutputType o) { return (o==Latex) ? this : 0; }
 
@@ -65,14 +66,16 @@ class LatexGenerator : public OutputGenerator
     void startParagraph();
     void endParagraph();
     void writeString(const char *text);
-    void startIndexList() { t << "\\begin{CompactList}"    << endl; }
-    void endIndexList()   { t << "\\end{CompactList}"      << endl; }
+    void startIndexListItem() {}
+    void endIndexListItem() {}
+    void startIndexList() { t << "\\begin{DoxyCompactList}"    << endl; }
+    void endIndexList()   { t << "\\end{DoxyCompactList}"      << endl; }
     void startIndexKey();
     void endIndexKey();
     void startIndexValue(bool);
     void endIndexValue(const char *,bool);
-    void startItemList()  { t << "\\begin{CompactItemize}" << endl; }
-    void endItemList()    { t << "\\end{CompactItemize}"   << endl; }
+    void startItemList()  { t << "\\begin{DoxyCompactItemize}" << endl; }
+    void endItemList()    { t << "\\end{DoxyCompactItemize}"   << endl; }
     void startIndexItem(const char *ref,const char *file);
     void endIndexItem(const char *ref,const char *file);
     void docify(const char *text);
@@ -86,15 +89,18 @@ class LatexGenerator : public OutputGenerator
     void endTextLink();
     void startHtmlLink(const char *url);
     void endHtmlLink();
-    void startTypewriter() { t << "{\\tt "; }
+    void startTypewriter() { t << "{\\ttfamily "; }
     void endTypewriter()   { t << "}";      }
-    void startGroupHeader();
-    void endGroupHeader();
-    void writeListItem() { t << "\\item " << endl; }
+    void startGroupHeader(int);
+    void endGroupHeader(int);
+    void startItemListItem() { t << "\\item " << endl; }
+    void endItemListItem()   {}
 
     void startMemberSections() {}
     void endMemberSections() {} 
-    void startMemberHeader();
+    void startHeaderSection() {}
+    void endHeaderSection() {}
+    void startMemberHeader(const char *);
     void endMemberHeader();
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
@@ -102,6 +108,8 @@ class LatexGenerator : public OutputGenerator
     void endMemberDocList() {}
     void startMemberList();
     void endMemberList();
+    void startInlineHeader();
+    void endInlineHeader();
     void startAnonTypeScope(int);
     void endAnonTypeScope(int);
     void startMemberItem(int);
@@ -127,14 +135,14 @@ class LatexGenerator : public OutputGenerator
     void endCodeLine();
     void startEmphasis() { t << "{\\em ";  }
     void endEmphasis()   { t << "}"; }
-    void startBold()     { t << "\\textbf{"; }
+    void startBold()     { t << "{\\bfseries "; }
     void endBold()       { t << "}"; }
     void startDescription();
     void endDescription();
     void startDescItem();
     void endDescItem();
-    void lineBreak(const char *style=0) { (void)style; t << "\\par\n"; }
-    void startMemberDoc(const char *,const char *,const char *,const char *);
+    void lineBreak(const char *style=0);
+    void startMemberDoc(const char *,const char *,const char *,const char *,bool);
     void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *);
@@ -161,7 +169,8 @@ class LatexGenerator : public OutputGenerator
     void endSimpleSect();
     void startParamList(ParamListTypes,const char *title);
     void endParamList();
-    void writeDescItem()     { t << "\\par" << endl; }
+    void startDescForItem()     { t << "\\par" << endl; }
+    void endDescForItem()       {}
     void startSection(const char *,const char *,SectionInfo::SectionType);
     void endSection(const char *,SectionInfo::SectionType);
     void addIndexItem(const char *,const char *);
@@ -174,6 +183,8 @@ class LatexGenerator : public OutputGenerator
     void endPageRef(const char *,const char *);
     void startQuickIndices() {}
     void endQuickIndices() {}
+    void writeSplitBar(const char *) {}
+    void writeLogo() {}
     void writeQuickLinks(bool,HighlightedItem) {}
     void startContents() {}
     void endContents() {}
@@ -211,11 +222,11 @@ class LatexGenerator : public OutputGenerator
     void startMemberDocName(bool) {}
     void endMemberDocName() {}
     void startParameterType(bool,const char *);
-    void endParameterType() {}
-    void startParameterName(bool) {}
-    void endParameterName(bool,bool,bool) {}
-    void startParameterList(bool) {}
-    void endParameterList() {}
+    void endParameterType();
+    void startParameterName(bool);
+    void endParameterName(bool,bool,bool);
+    void startParameterList(bool);
+    void endParameterList();
 
     void startConstraintList(const char *);
     void startConstraintParam();
@@ -226,6 +237,15 @@ class LatexGenerator : public OutputGenerator
     void endConstraintDocs();
     void endConstraintList();
 
+    void startMemberDocSimple();
+    void endMemberDocSimple();
+    void startInlineMemberType();
+    void endInlineMemberType();
+    void startInlineMemberName();
+    void endInlineMemberName();
+    void startInlineMemberDoc();
+    void endInlineMemberDoc();
+
     void startFontClass(const char *); // {}
     void endFontClass(); // {}
 
