@@ -3,7 +3,7 @@
  * $Id: layout.cpp,v 1.2 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -46,7 +46,7 @@ static bool elemIsVisible(const QXmlAttributes &attrib,bool defVal=TRUE)
     }
     else if (!opt)
     {
-      err("Warning: found unsupported value %s for visible attribute in layout file\n",
+      err("error: found unsupported value %s for visible attribute in layout file\n",
           visible.data());
     }
   }
@@ -348,6 +348,11 @@ class LayoutParser : public QXmlDefaultHandler
           new EndElementHandler(this,&LayoutParser::endMemberDecl));
       m_sHandler.insert("class/memberdef", 
           new StartElementHandler(this,&LayoutParser::startMemberDef));
+      m_sHandler.insert("class/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::ClassInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("class/memberdef/typedefs", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::typedefMembers,theTranslator->trMemberTypedefDocumentation()));
@@ -426,6 +431,11 @@ class LayoutParser : public QXmlDefaultHandler
           new EndElementHandler(this,&LayoutParser::endMemberDecl));
       m_sHandler.insert("namespace/memberdef", 
           new StartElementHandler(this,&LayoutParser::startMemberDef));
+      m_sHandler.insert("namespace/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::NamespaceInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("namespace/memberdef/typedefs", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation()));
@@ -464,6 +474,8 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandlerKind(this,LayoutDocEntry::FileIncludedByGraph,&LayoutParser::startSimpleEntry));
       m_sHandler.insert("file/sourcelink", 
           new StartElementHandlerKind(this,LayoutDocEntry::FileSourceLink,&LayoutParser::startSimpleEntry));
+      m_sHandler.insert("file/memberdecl/membergroups", 
+          new StartElementHandlerKind(this,LayoutDocEntry::MemberGroups,&LayoutParser::startSimpleEntry));
       m_sHandler.insert("file/memberdecl", 
           new StartElementHandler(this,&LayoutParser::startMemberDecl));
       m_sHandler.insert("file/memberdecl/classes", 
@@ -501,6 +513,11 @@ class LayoutParser : public QXmlDefaultHandler
           new EndElementHandler(this,&LayoutParser::endMemberDecl));
       m_sHandler.insert("file/memberdef", 
           new StartElementHandler(this,&LayoutParser::startMemberDef));
+      m_sHandler.insert("file/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::FileInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("file/memberdef/defines", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docDefineMembers,theTranslator->trDefineDocumentation()));
@@ -509,10 +526,12 @@ class LayoutParser : public QXmlDefaultHandler
                                         MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation()));
       m_sHandler.insert("file/memberdef/enums", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
-                                        MemberList::docEnumMembers,theTranslator->trEnumerationTypeDocumentation()));
+                                        MemberList::docEnumMembers,
+                                        theTranslator->trEnumerationTypeDocumentation()));
       m_sHandler.insert("file/memberdef/functions", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
-                                        MemberList::docFuncMembers,theTranslator->trFunctionDocumentation()));
+                                        MemberList::docFuncMembers,
+                                        fortranOpt ? theTranslator->trSubprogramDocumentation() : theTranslator->trFunctionDocumentation()));
       m_sHandler.insert("file/memberdef/variables", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docVarMembers,theTranslator->trVariableDocumentation()));
@@ -533,6 +552,8 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandlerKind(this,LayoutDocEntry::AuthorSection,&LayoutParser::startSimpleEntry));
       m_sHandler.insert("group/groupgraph", 
           new StartElementHandlerKind(this,LayoutDocEntry::GroupGraph,&LayoutParser::startSimpleEntry));
+      m_sHandler.insert("group/memberdecl/membergroups", 
+          new StartElementHandlerKind(this,LayoutDocEntry::MemberGroups,&LayoutParser::startSimpleEntry));
       m_sHandler.insert("group/memberdecl", 
           new StartElementHandler(this,&LayoutParser::startMemberDecl));
       m_sHandler.insert("group/memberdecl/classes", 
@@ -608,6 +629,11 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandler(this,&LayoutParser::startMemberDef));
       m_sHandler.insert("group/memberdef/pagedocs", 
           new StartElementHandlerKind(this,LayoutDocEntry::GroupPageDocs,&LayoutParser::startSimpleEntry));
+      m_sHandler.insert("group/memberdef/inlineclasses", 
+          new StartElementHandlerSection(this,LayoutDocEntry::GroupInlineClasses,&LayoutParser::startSectionEntry,
+                                         fortranOpt ? theTranslator->trTypeDocumentation() :
+                                         theTranslator->trClassDocumentation() 
+                                         ));
       m_sHandler.insert("group/memberdef/defines", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberList::docDefineMembers,theTranslator->trDefineDocumentation()));
@@ -754,55 +780,128 @@ class LayoutParser : public QXmlDefaultHandler
       if (!m_rootNav->find(LayoutNavEntry::MainPage))
       {
         // no MainPage node... add one the first item of the root node...
-        new LayoutNavEntry(m_rootNav,LayoutNavEntry::MainPage, TRUE, usingTreeIndex() ? "main" : "index",theTranslator->trMainPage(),TRUE);
+        new LayoutNavEntry(m_rootNav,LayoutNavEntry::MainPage, TRUE, 
+            /*Config_getBool("GENERATE_TREEVIEW") ? "main" :*/ "index",
+            theTranslator->trMainPage(),TRUE);
       }
     }
 
     void startNavEntry(const QXmlAttributes &attrib)
     {
-      bool javaOpt    = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
-      bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
-      bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");  
+      static bool javaOpt    = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+      static bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+      static bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");  
+      static bool hasGraphicalHierarchy = Config_getBool("HAVE_DOT") &&
+                                          Config_getBool("GRAPHICAL_HIERARCHY");
+      static bool extractAll = Config_getBool("EXTRACT_ALL");
       static struct NavEntryMap
       {
         const char *typeStr;       // type attribute name in the XML file
         LayoutNavEntry::Kind kind; // corresponding enum name
         QCString mainName;         // default title for an item if it has children
         QCString subName;          // optional name for an item if it is rendered as a child
+        QCString intro;            // introduction text to be put on the index page
         QCString baseFile;         // base name of the file containing the index page
       } mapping[] =
       {
-        { "mainpage",         LayoutNavEntry::MainPage,         theTranslator->trMainPage(),     QCString(), usingTreeIndex() ? "main" : "index" },
-        { "pages",            LayoutNavEntry::Pages,            theTranslator->trRelatedPages(), QCString(), "pages"  },
-        { "modules",          LayoutNavEntry::Modules,          theTranslator->trModules(),      QCString(), "modules" },
-        { "namespaces",       LayoutNavEntry::Namespaces,       javaOpt    ? theTranslator->trPackages() : 
-                                                                fortranOpt ? theTranslator->trModules() : 
-                                                                theTranslator->trNamespaces(),        
-                                                                javaOpt    ? theTranslator->trPackages() :
-                                                                fortranOpt ? theTranslator->trModulesList() :
-                                                                theTranslator->trNamespaceList(), "namespaces" },
-        { "namespacemembers", LayoutNavEntry::NamespaceMembers, javaOpt    ? theTranslator->trPackageMembers() :
-                                                                fortranOpt ? theTranslator->trModulesMembers() :
-                                                                theTranslator->trNamespaceMembers(), QCString(), "namespacemembers" },
-        { "classindex",       LayoutNavEntry::Classes,          fortranOpt ? theTranslator->trDataTypes() :
-                                                                vhdlOpt    ? VhdlDocGen::trDesignUnits() :
-                                                                theTranslator->trCompoundIndex(),
-                                                                QCString(), "classes" },
-        { "classes",          LayoutNavEntry::ClassAnnotated,   fortranOpt ? theTranslator->trCompoundListFortran() :
-                                                                vhdlOpt    ? VhdlDocGen::trDesignUnitList() :
-                                                                theTranslator->trClasses(), 
-                                                                theTranslator->trCompoundList(), "annotated" },
-        { "hierarchy",        LayoutNavEntry::ClassHierarchy,   vhdlOpt    ? VhdlDocGen::trDesignUnitHierarchy() :
-                                                                theTranslator->trClassHierarchy(), QCString(), "hierarchy" },
-        { "classmembers",     LayoutNavEntry::ClassMembers,     fortranOpt ? theTranslator->trCompoundMembersFortran() :
-                                                                vhdlOpt    ? VhdlDocGen::trDesignUnitMembers() :
-                                                                theTranslator->trCompoundMembers(), QCString(), "functions" },
-        { "files",            LayoutNavEntry::Files,            theTranslator->trFile(TRUE,FALSE), 
-                                                                theTranslator->trFileList(), "files" },
-        { "globals",          LayoutNavEntry::FileGlobals,      theTranslator->trFileMembers(), QCString(), "globals" },
-        { "dirs",             LayoutNavEntry::Dirs,             theTranslator->trDirectories(), QCString(), "dirs" },
-        { "examples",         LayoutNavEntry::Examples,         theTranslator->trExamples(), QCString(), "examples" },
-        { 0,                 (LayoutNavEntry::Kind)0,           QCString(), QCString(), QCString() }
+        { "mainpage",
+          LayoutNavEntry::MainPage,
+          theTranslator->trMainPage(),
+          QCString(),
+          QCString(),
+          "index"
+        },
+        { "pages",
+          LayoutNavEntry::Pages,
+          theTranslator->trRelatedPages(),
+          QCString(),
+          theTranslator->trRelatedPagesDescription(),
+          "pages"
+        },
+        { "modules",
+          LayoutNavEntry::Modules,
+          theTranslator->trModules(),
+          QCString(),
+          theTranslator->trModulesDescription(),
+          "modules"
+        },
+        { "namespaces",
+          LayoutNavEntry::Namespaces,
+          javaOpt    ? theTranslator->trPackages() : fortranOpt ? theTranslator->trModules() : theTranslator->trNamespaces(),
+          javaOpt    ? theTranslator->trPackages() : fortranOpt ? theTranslator->trModulesList() : theTranslator->trNamespaceList(),
+          javaOpt    ? theTranslator->trPackageListDescription() : fortranOpt ? theTranslator->trModulesListDescription(extractAll) : theTranslator->trNamespaceListDescription(extractAll),
+          "namespaces"
+        },
+        { "namespacemembers",
+          LayoutNavEntry::NamespaceMembers,
+          javaOpt    ? theTranslator->trPackageMembers() : fortranOpt ? theTranslator->trModulesMembers() : theTranslator->trNamespaceMembers(),
+          QCString(),
+          fortranOpt ? theTranslator->trModulesMemberDescription(extractAll) : theTranslator->trNamespaceMemberDescription(extractAll),
+          "namespacemembers"
+        },
+        { "classindex",
+          LayoutNavEntry::Classes,
+          fortranOpt ? theTranslator->trDataTypes() : vhdlOpt ? VhdlDocGen::trDesignUnits() : theTranslator->trCompoundIndex(),
+          QCString(),
+          QCString(),
+          "classes"
+        },
+        { "classes",
+          LayoutNavEntry::ClassAnnotated,
+          fortranOpt ? theTranslator->trCompoundListFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitList() : theTranslator->trClasses(),
+          theTranslator->trCompoundList(),
+          fortranOpt ? theTranslator->trCompoundListDescriptionFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitListDescription() : theTranslator->trCompoundListDescription(),
+          "annotated"
+        },
+        { "hierarchy",
+          LayoutNavEntry::ClassHierarchy,
+          vhdlOpt    ? VhdlDocGen::trDesignUnitHierarchy() : theTranslator->trClassHierarchy(),
+          QCString(),
+          theTranslator->trClassHierarchyDescription(),
+          hasGraphicalHierarchy ? "inherits" : "hierarchy"
+        },
+        { "classmembers",
+          LayoutNavEntry::ClassMembers,
+          fortranOpt ? theTranslator->trCompoundMembersFortran() : vhdlOpt ? VhdlDocGen::trDesignUnitMembers() : theTranslator->trCompoundMembers(),
+          QCString(),
+          fortranOpt ? theTranslator->trCompoundMembersDescriptionFortran(extractAll) : theTranslator->trCompoundMembersDescription(extractAll),
+          "functions"
+        },
+        { "files",
+          LayoutNavEntry::Files,
+          theTranslator->trFile(TRUE,FALSE),
+          theTranslator->trFileList(),
+          theTranslator->trFileListDescription(extractAll),
+          "files"
+        },
+        { "globals",
+          LayoutNavEntry::FileGlobals,
+          theTranslator->trFileMembers(),
+          QCString(),
+          theTranslator->trFileMembersDescription(extractAll),
+          "globals"
+        },
+        { "dirs",
+          LayoutNavEntry::Dirs,
+          theTranslator->trDirectories(),
+          QCString(),
+          theTranslator->trDirDescription(),
+          "dirs"
+        },
+        { "examples",
+          LayoutNavEntry::Examples,
+          theTranslator->trExamples(),
+          QCString(),
+          theTranslator->trExamplesDescription(),
+          "examples"
+        },
+        { 0, // end of list
+          (LayoutNavEntry::Kind)0,
+          QCString(),
+          QCString(),
+          QCString(),
+          QCString()
+        }
       };
       LayoutNavEntry::Kind kind;
       // find type in the table
@@ -821,11 +920,11 @@ class LayoutParser : public QXmlDefaultHandler
       {
         if (type.isEmpty())
         {
-          err("Warning: an entry tag within a navindex has no type attribute! Check your layout file!\n");
+          err("error: an entry tag within a navindex has no type attribute! Check your layout file!\n");
         }
         else
         {
-          err("Warning: the type '%s' is not supported for the entry tag within a navindex! Check your layout file!\n");
+          err("error: the type '%s' is not supported for the entry tag within a navindex! Check your layout file!\n");
         }
         return;
       }
@@ -841,8 +940,13 @@ class LayoutParser : public QXmlDefaultHandler
                                       // this is mainly done to get compatible naming with older versions.
         }
       }
+      QCString intro = convertToQCString(attrib.value("intro"));
+      if (intro.isEmpty()) // use default intro text
+      {
+        intro = mapping[i].intro;
+      }
       // create new item and make it the new root
-      m_rootNav = new LayoutNavEntry(m_rootNav,kind,kind==LayoutNavEntry::MainPage?TRUE:isVisible,baseFile,title);
+      m_rootNav = new LayoutNavEntry(m_rootNav,kind,kind==LayoutNavEntry::MainPage?TRUE:isVisible,baseFile,title,intro);
     }
 
     void endNavEntry()
@@ -976,7 +1080,7 @@ class LayoutParser : public QXmlDefaultHandler
       }
       else
       {
-        err("Warning: Unexpected start tag `%s' found in scope='%s'!\n",
+        err("error: Unexpected start tag `%s' found in scope='%s'!\n",
             name.data(),m_scope.data());
       }
       return TRUE;
@@ -1019,24 +1123,25 @@ class LayoutParser : public QXmlDefaultHandler
 class LayoutErrorHandler : public QXmlErrorHandler
 {
   public:
+    LayoutErrorHandler(const char *fn) : fileName(fn) {}
     bool warning( const QXmlParseException &exception )
     {
-      err("Warning at line %d column %d: %s\n",
-          exception.lineNumber(),exception.columnNumber(),
+      err("warning: at line %d column %d of %s: %s\n",
+          exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
     bool error( const QXmlParseException &exception )
     {
-      err("Error at line %d column %d: %s\n",
-          exception.lineNumber(),exception.columnNumber(),
+      err("error: at line %d column %d of %s: %s\n",
+          exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
     bool fatalError( const QXmlParseException &exception )
     {
-      err("Fatal error at line %d column %d: %s\n",
-          exception.lineNumber(),exception.columnNumber(),
+      err("fatal error: at line %d column %d of %s: %s\n",
+          exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
@@ -1044,6 +1149,7 @@ class LayoutErrorHandler : public QXmlErrorHandler
 
   private:
     QString errorMsg;
+    QString fileName;
 };
 
 //---------------------------------------------------------------------------------
@@ -1071,7 +1177,7 @@ LayoutDocManager::LayoutDocManager()
 void LayoutDocManager::init()
 {
   // parse the default layout
-  LayoutErrorHandler errorHandler;
+  LayoutErrorHandler errorHandler( "layout_default.xml" );
   QXmlInputSource source;
   source.setData( layout_default );
   QXmlSimpleReader reader;
@@ -1112,9 +1218,9 @@ void LayoutDocManager::clear(LayoutDocManager::LayoutPart p)
   d->docEntries[(int)p].clear();
 }
 
-void LayoutDocManager::parse(QTextStream &t)
+void LayoutDocManager::parse(QTextStream &t,const char *fileName)
 {
-  LayoutErrorHandler errorHandler;
+  LayoutErrorHandler errorHandler(fileName);
   QXmlInputSource source( t );
   QXmlSimpleReader reader;
   reader.setContentHandler( &LayoutParser::instance() );
