@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -82,6 +82,7 @@ void ManDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon: m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "(C)"; break;
     case DocSymbol::Tm:      m_t << "(TM)"; break;
@@ -280,6 +281,22 @@ void ManDocVisitor::visit(DocInclude *inc)
       m_t << ".PP" << endl;
       m_firstCol=TRUE;
       break;
+    case DocInclude::Snippet:
+      if (!m_firstCol) m_t << endl;
+      m_t << ".PP" << endl;
+      m_t << ".nf" << endl;
+      Doxygen::parserManager->getParser(inc->extension())
+                            ->parseCode(m_ci,
+                                        inc->context(),
+                                        extractBlock(inc->text(),inc->blockId()),
+                                        inc->isExample(),
+                                        inc->exampleFile()
+                                       );
+      if (!m_firstCol) m_t << endl;
+      m_t << ".fi" << endl;
+      m_t << ".PP" << endl;
+      m_firstCol=TRUE;
+      break;
   }
 }
 
@@ -341,6 +358,17 @@ void ManDocVisitor::visit(DocSimpleSectSep *)
 {
 }
 
+void ManDocVisitor::visit(DocCite *cite)
+{
+  if (m_hide) return;
+  m_t << "\\fB";
+  if (cite->file().isEmpty()) m_t << "[";
+  filter(cite->text());
+  if (cite->file().isEmpty()) m_t << "]";
+  m_t << "\\fP";
+}
+
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -444,6 +472,8 @@ void ManDocVisitor::visitPre(DocSimpleSect *s)
       m_t << theTranslator->trPrecondition(); break;
     case DocSimpleSect::Post:
       m_t << theTranslator->trPostcondition(); break;
+    case DocSimpleSect::Copyright:
+      m_t << theTranslator->trCopyright(); break;
     case DocSimpleSect::Invar:
       m_t << theTranslator->trInvariant(); break;
     case DocSimpleSect::Remark:
@@ -660,19 +690,19 @@ void ManDocVisitor::visitPost(DocHtmlCell *)
 void ManDocVisitor::visitPre(DocInternal *)
 {
   if (m_hide) return;
-  if (!m_firstCol) m_t << endl;
-  m_t << ".PP" << endl;
-  m_t << "\\fB" << theTranslator->trForInternalUseOnly() << "\\fP" << endl;
-  m_t << ".RS 4" << endl;
+  //if (!m_firstCol) m_t << endl;
+  //m_t << ".PP" << endl;
+  //m_t << "\\fB" << theTranslator->trForInternalUseOnly() << "\\fP" << endl;
+  //m_t << ".RS 4" << endl;
 }
 
 void ManDocVisitor::visitPost(DocInternal *) 
 {
   if (m_hide) return;
-  if (!m_firstCol) m_t << endl;
-  m_t << ".RE" << endl;
-  m_t << ".PP" << endl;
-  m_firstCol=TRUE;
+  //if (!m_firstCol) m_t << endl;
+  //m_t << ".RE" << endl;
+  //m_t << ".PP" << endl;
+  //m_firstCol=TRUE;
 }
 
 void ManDocVisitor::visitPre(DocHRef *)
@@ -935,6 +965,7 @@ void ManDocVisitor::filter(const char *str)
     {
       switch(c)
       {
+        case '.':  m_t << "'\\&."; break; // see  bug652277
         case '\\': m_t << "\\\\"; break;
         case '"':  c = '\''; // fall through
         default: m_t << c; break;
