@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.h,v 1.15 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,9 +34,9 @@ class ManGenerator : public OutputGenerator
     void enable() 
     { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
-    void enableIf(OutputType o)  { if (o==Man) active=TRUE;  }
-    void disableIf(OutputType o) { if (o==Man) active=FALSE; }
-    void disableIfNot(OutputType o) { if (o!=Man) active=FALSE; }
+    void enableIf(OutputType o)  { if (o==Man) enable(); }
+    void disableIf(OutputType o) { if (o==Man) disable(); }
+    void disableIfNot(OutputType o) { if (o!=Man) disable(); }
     bool isEnabled(OutputType o) { return (o==Man && active); } 
     OutputGenerator *get(OutputType o) { return (o==Man) ? this : 0; }
 
@@ -50,6 +50,7 @@ class ManGenerator : public OutputGenerator
 
     void startIndexSection(IndexSections) {}
     void endIndexSection(IndexSections) {}
+    void writePageLink(const char *,bool) {}
     void startProjectNumber() {}
     void endProjectNumber() {}
     void writeStyleInfo(int) {}
@@ -62,6 +63,8 @@ class ManGenerator : public OutputGenerator
     void startParagraph();
     void endParagraph();
     void writeString(const char *text);
+    void startIndexListItem() {}
+    void endIndexListItem() {}
     void startIndexList() {}
     void endIndexList()   { newParagraph(); } 
     void startIndexKey() {}
@@ -85,20 +88,26 @@ class ManGenerator : public OutputGenerator
     void endHtmlLink();
     void startTypewriter() { t << "\\fC"; firstCol=FALSE; }
     void endTypewriter()   { t << "\\fP"; firstCol=FALSE; }
-    void startGroupHeader();
-    void endGroupHeader();
+    void startGroupHeader(int);
+    void endGroupHeader(int);
     void startMemberSections() {}
     void endMemberSections() {}
-    void startMemberHeader();
+    void startHeaderSection() {}
+    void endHeaderSection() {}
+    void startMemberHeader(const char *);
     void endMemberHeader();
     void insertMemberAlign(bool) {}
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
-    void writeListItem();
+    //void writeListItem();
+    void startItemListItem();
+    void endItemListItem();
     void startMemberDocList() {}
     void endMemberDocList() {}
     void startMemberList();
     void endMemberList();
+    void startInlineHeader();
+    void endInlineHeader();
     void startAnonTypeScope(int);
     void endAnonTypeScope(int);
     void startMemberItem(int);
@@ -128,9 +137,9 @@ class ManGenerator : public OutputGenerator
     void endDescription()   {}
     void startDescItem();
     void endDescItem();
-    void lineBreak() { t << "\n.br" << endl; }
+    void lineBreak(const char *) { t << "\n.br" << endl; }
     void writeChar(char c);
-    void startMemberDoc(const char *,const char *,const char *,const char *);
+    void startMemberDoc(const char *,const char *,const char *,const char *,bool);
     void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *) {}
@@ -156,7 +165,9 @@ class ManGenerator : public OutputGenerator
     void endSimpleSect();
     void startParamList(ParamListTypes,const char *title);
     void endParamList();
-    void writeDescItem();
+    //void writeDescItem();
+    void startDescForItem();
+    void endDescForItem();
     void startSection(const char *,const char *,SectionInfo::SectionType);
     void endSection(const char *,SectionInfo::SectionType);
     void addIndexItem(const char *,const char *) {}
@@ -167,12 +178,18 @@ class ManGenerator : public OutputGenerator
     void endClassDiagram(const ClassDiagram &,const char *,const char *) {}
     void startPageRef() {}
     void endPageRef(const char *,const char *) {}
+    void startQuickIndices() {}
+    void endQuickIndices() {}
+    void writeSplitBar(const char *) {}
+    void writeLogo() {}
     void writeQuickLinks(bool,HighlightedItem) {}
+    void startContents() {}
+    void endContents() {}
     void writeNonBreakableSpace(int n) { int i; for (i=0;i<n;i++) t << " "; }
     
     void startDescTable() {}
     void endDescTable() {}
-    void startDescTableTitle() { writeListItem(); startBold(); startEmphasis(); }
+    void startDescTableTitle() { startItemListItem(); startBold(); startEmphasis(); endItemListItem(); }
     void endDescTableTitle() { endEmphasis(); endBold(); }
     void startDescTableData() { t << endl; firstCol=TRUE; }
     void endDescTableData() {}
@@ -216,6 +233,16 @@ class ManGenerator : public OutputGenerator
     void endConstraintDocs();
     void endConstraintList();
 
+    void startMemberDocSimple();
+    void endMemberDocSimple();
+    void startInlineMemberType();
+    void endInlineMemberType();
+    void startInlineMemberName();
+    void endInlineMemberName();
+    void startInlineMemberDoc();
+    void endInlineMemberDoc();
+
+
     void writeCodeAnchor(const char *) {}
     void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
