@@ -395,7 +395,7 @@ void marshalEntry(StorageIntf *s,Entry *e)
   marshalInt(s,e->inbodyLine);
   marshalQCString(s,e->inbodyFile);
   marshalQCString(s,e->relates);
-  marshalBool(s,e->relatesDup);
+  marshalInt(s,e->relatesType);
   marshalQCString(s,e->read);
   marshalQCString(s,e->write);
   marshalQCString(s,e->inside);
@@ -410,8 +410,9 @@ void marshalEntry(StorageIntf *s,Entry *e)
   marshalQCString(s,e->fileName);
   marshalInt(s,e->startLine);
   marshalItemInfoList(s,e->sli);
-  marshalBool(s,e->objc);
+  marshalInt(s,(int)e->lang);
   marshalBool(s,e->hidden);
+  marshalBool(s,e->artificial);
   marshalInt(s,(int)e->groupDocType);
 }
 
@@ -643,8 +644,9 @@ MemberSDict *unmarshalMemberSDict(StorageIntf *s)
     //printf("  unmarshaling key %s\n",key.data());
     MemberDef *md = (MemberDef *)unmarshalObjPointer(s);
     //printf("  unmarshalMemberSDict i=%d key=%s md=%p\n",i,key.data(),md);
-    result->inSort(key,md); // note: this can lead to unmarshalling another object!
+    result->append(key,md); // note: this can lead to unmarshalling another object!
   }
+  result->sort();
   //printf("--- end unmarshalMemberSDict\n");
   return result;
 }
@@ -725,9 +727,9 @@ ExampleSDict *unmarshalExampleSDict(StorageIntf *s)
   {
     QCString key = unmarshalQCString(s);
     Example *e = new Example;
-    marshalQCString(s,e->anchor);
-    marshalQCString(s,e->name);
-    marshalQCString(s,e->file);
+    e->anchor = unmarshalQCString(s);
+    e->name   = unmarshalQCString(s);
+    e->file   = unmarshalQCString(s);
     result->inSort(key,e);
   }
   return result;
@@ -787,7 +789,7 @@ Entry * unmarshalEntry(StorageIntf *s)
   e->inbodyLine       = unmarshalInt(s);
   e->inbodyFile       = unmarshalQCString(s);
   e->relates          = unmarshalQCString(s);
-  e->relatesDup       = unmarshalBool(s);
+  e->relatesType      = (RelatesType)unmarshalInt(s);
   e->read             = unmarshalQCString(s);
   e->write            = unmarshalQCString(s);
   e->inside           = unmarshalQCString(s);
@@ -805,8 +807,9 @@ Entry * unmarshalEntry(StorageIntf *s)
   e->fileName         = unmarshalQCString(s);
   e->startLine        = unmarshalInt(s);
   e->sli              = unmarshalItemInfoList(s);
-  e->objc             = unmarshalBool(s);
+  e->lang             = (SrcLangExt)unmarshalInt(s);
   e->hidden           = unmarshalBool(s);
+  e->artificial       = unmarshalBool(s);
   e->groupDocType     = (Entry::GroupDocType)unmarshalInt(s);
   return e;
 }
