@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.cpp,v 1.27 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,6 +27,10 @@
 #include "message.h"
 #include "docparser.h"
 #include "searchindex.h"
+#include "vhdldocgen.h"
+#include "layout.h"
+
+//------------------------------------------------------------------
 
 NamespaceDef::NamespaceDef(const char *df,int dl,
                            const char *name,const char *lref,
@@ -47,6 +51,7 @@ NamespaceDef::NamespaceDef(const char *df,int dl,
   m_innerCompounds = new SDict<Definition>(17);
   usingDirList = 0;
   usingDeclList = 0;
+  m_allMembersDict = 0;
   setReference(lref);
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
@@ -179,6 +184,12 @@ void NamespaceDef::insertMember(MemberDef *md)
     m_memberLists.append(allMemberList);
   }
   allMemberList->append(md); 
+  if (m_allMembersDict==0)
+  {
+    m_allMembersDict = new MemberSDict;
+  }
+  //printf("%s::m_allMembersDict->append(%s)\n",name().data(),md->localName().data());
+  m_allMembersDict->append(md->localName(),md); 
   //::addNamespaceMemberNameToIndex(md);
   //static bool sortBriefDocs=Config_getBool("SORT_BRIEF_DOCS");
   switch(md->memberType())
@@ -201,10 +212,6 @@ void NamespaceDef::insertMember(MemberDef *md)
       break;
     case MemberDef::EnumValue:    
       break;
-    case MemberDef::Prototype:    
-      addMemberToList(MemberList::decProtoMembers,md);
-      addMemberToList(MemberList::docProtoMembers,md);
-      break;
     case MemberDef::Define:       
       addMemberToList(MemberList::decDefineMembers,md);
       addMemberToList(MemberList::docDefineMembers,md);
@@ -224,22 +231,21 @@ void NamespaceDef::computeAnchors()
   if (allMemberList) setAnchors(0,'a',allMemberList);
 }
 
-void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
+void NamespaceDef::writeDetailedDescription(OutputList &ol,const QCString &title)
 {
   if ((!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF")) || 
-      !documentation().isEmpty())
+      !documentation().isEmpty()
+     )
   {
     ol.writeRuler();
     ol.pushGeneratorState();
     ol.disableAllBut(OutputGenerator::Html);
-    //bool latexOn = ol.isEnabled(OutputGenerator::Latex);
-    //if (latexOn) ol.disable(OutputGenerator::Latex);
-    ol.writeAnchor(0,"_details"); 
-    //if (latexOn) ol.enable(OutputGenerator::Latex);
+      ol.writeAnchor(0,"details"); 
     ol.popGeneratorState();
     ol.startGroupHeader();
-    ol.parseText(theTranslator->trDetailedDescription());
+    ol.parseText(title);
     ol.endGroupHeader();
+
     ol.startTextBlock();
     if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF"))
     {
@@ -250,7 +256,8 @@ void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
     {
       ol.pushGeneratorState();
         ol.disable(OutputGenerator::Man);
-        ol.newParagraph();
+        ol.disable(OutputGenerator::RTF);
+        //ol.newParagraph(); // FIXME:PARA
         ol.enableAll();
         ol.disableAllBut(OutputGenerator::Man);
         ol.writeString("\n\n");
@@ -259,84 +266,93 @@ void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
     if (!documentation().isEmpty())
     {
       ol.parseDoc(docFile(),docLine(),this,0,documentation()+"\n",TRUE,FALSE);
-      //ol.newParagraph();
     }
     ol.endTextBlock();
   }
 }
-  
-void NamespaceDef::writeDocumentation(OutputList &ol)
+
+void NamespaceDef::writeBriefDescription(OutputList &ol)
 {
-  QCString pageTitle;
-  if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+  if (!briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
   {
-    pageTitle = theTranslator->trPackage(displayName());
-  }
-  else
-  {
-    pageTitle = theTranslator->trNamespaceReference(displayName());
-  }
-  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_NamespaceVisible);
-  if (getOuterScope()!=Doxygen::globalScope)
-  {
-    writeNavigationPath(ol);
-  }
-  startTitle(ol,getOutputFileBase());
-  ol.parseText(pageTitle);
-  addGroupListToTitle(ol,this);
-  endTitle(ol,getOutputFileBase(),displayName());
-  
-  if (Config_getBool("SEARCHENGINE"))
-  {
-    Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName(),TRUE);
-  }
-
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty())
-  {
-    Doxygen::tagFile << "  <compound kind=\"namespace\">" << endl;
-    Doxygen::tagFile << "    <name>" << convertToXML(name()) << "</name>" << endl;
-    Doxygen::tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>" << endl;
-  }
-  
-  ol.startTextBlock();
-    
-  if (Config_getBool("DETAILS_AT_TOP"))
-  {
-    writeDetailedDocumentation(ol);
-    ol.newParagraph();
-  }
-  else if (!briefDescription().isEmpty()) 
-  {
-    ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
-    ol.writeString(" \n");
+    ol.startParagraph();
+    ol.parseDoc(briefFile(),briefLine(),this,0,
+                briefDescription(),TRUE,FALSE,0,TRUE,FALSE);
     ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::Html);
-    ol.startTextLink(0,"_details");
-    ol.parseText(theTranslator->trMore());
-    ol.endTextLink();
-    ol.enableAll();
-    ol.disableAllBut(OutputGenerator::Man);
-    ol.newParagraph();
+    ol.disable(OutputGenerator::RTF);
+    ol.writeString(" \n");
+    ol.enable(OutputGenerator::RTF);
+
+    if (Config_getBool("REPEAT_BRIEF") ||
+        !documentation().isEmpty()
+       )
+    {
+      ol.disableAllBut(OutputGenerator::Html);
+      ol.startTextLink(0,"details");
+      ol.parseText(theTranslator->trMore());
+      ol.endTextLink();
+    }
     ol.popGeneratorState();
+    ol.endParagraph();
+
+    // FIXME:PARA
+    //ol.pushGeneratorState();
+    //ol.disable(OutputGenerator::RTF);
+    //ol.newParagraph();
+    //ol.popGeneratorState();
   }
-  ol.disable(OutputGenerator::Man);
-  ol.disable(OutputGenerator::RTF);
-  ol.newParagraph();
-  ol.enable(OutputGenerator::Man);
-  ol.enable(OutputGenerator::RTF);
   ol.writeSynopsis();
+}
 
-  ol.endTextBlock();
-  
+void NamespaceDef::startMemberDeclarations(OutputList &ol)
+{
   ol.startMemberSections();
-  classSDict->writeDeclaration(ol,0,0,TRUE);
+}
 
-  namespaceSDict->writeDeclaration(ol,TRUE);
+void NamespaceDef::endMemberDeclarations(OutputList &ol)
+{
+  ol.endMemberSections();
+}
 
+void NamespaceDef::startMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.disable(OutputGenerator::Html);
+    Doxygen::suppressDocWarnings = TRUE;
+  }
+}
+
+void NamespaceDef::endMemberDocumentation(OutputList &ol)
+{
+  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  {
+    ol.enable(OutputGenerator::Html);
+    Doxygen::suppressDocWarnings = FALSE;
+  }
+}
+
+void NamespaceDef::writeClassDeclarations(OutputList &ol,const QCString &title)
+{
+  if (classSDict) classSDict->writeDeclaration(ol,0,title,TRUE);
+}
+
+void NamespaceDef::writeInlineClasses(OutputList &ol)
+{
+  if (classSDict) classSDict->writeDocumentation(ol,this);
+}
+
+void NamespaceDef::writeNamespaceDeclarations(OutputList &ol,const QCString &title)
+{
+  if (namespaceSDict) namespaceSDict->writeDeclaration(ol,title,TRUE);
+}
+
+void NamespaceDef::writeMemberGroups(OutputList &ol)
+{
   /* write user defined member groups */
   if (memberGroupSDict)
   {
+    memberGroupSDict->sort();
     MemberGroupSDict::Iterator mgli(*memberGroupSDict);
     MemberGroup *mg;
     for (;(mg=mgli.current());++mgli)
@@ -348,22 +364,10 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
       }
     }
   }
-
-  writeMemberDeclarations(ol,MemberList::decDefineMembers,theTranslator->trDefines());
-  writeMemberDeclarations(ol,MemberList::decProtoMembers,theTranslator->trFuncProtos());
-  writeMemberDeclarations(ol,MemberList::decTypedefMembers,theTranslator->trTypedefs());
-  writeMemberDeclarations(ol,MemberList::decEnumMembers,theTranslator->trEnumerations());
-  writeMemberDeclarations(ol,MemberList::decFuncMembers,theTranslator->trFunctions());
-  writeMemberDeclarations(ol,MemberList::decVarMembers,theTranslator->trVariables());
-  ol.endMemberSections();
+}
   
-  if (!Config_getBool("DETAILS_AT_TOP"))
-  {
-    writeDetailedDocumentation(ol);
-  }
-
-  writeMemberDocumentation(ol);
-
+void NamespaceDef::writeAuthorSection(OutputList &ol)
+{
   // write Author section (Man only)
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Man);
@@ -371,16 +375,208 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
   ol.endGroupHeader();
   ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
+  ol.popGeneratorState();
+}
 
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+void NamespaceDef::writeSummaryLinks(OutputList &ol)
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::Namespace));
+  LayoutDocEntry *lde;
+  bool first=TRUE;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    if ((lde->kind()==LayoutDocEntry::NamespaceClasses && classSDict && classSDict->declVisible()) || 
+        (lde->kind()==LayoutDocEntry::NamespaceNestedNamespaces && namespaceSDict && namespaceSDict->declVisible())
+       )
+    {
+      LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+      QCString label = lde->kind()==LayoutDocEntry::NamespaceClasses ? "nested-classes" : "namespaces";
+      writeSummaryLink(ol,label,ls->title,first);
+    }
+    else if (lde->kind()== LayoutDocEntry::MemberDecl)
+    {
+      LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+      MemberList * ml = getMemberList(lmd->type);
+      if (ml && ml->declVisible())
+      {
+        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+      }
+    }
+  }
+  if (!first)
+  {
+    ol.writeString("  </div>\n");
+  }
+  ol.popGeneratorState();
+}
+
+void NamespaceDef::writeDocumentation(OutputList &ol)
+{
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
+  //static bool outputJava = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+  //static bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  SrcLangExt lang = getLanguage();
+
+  QCString pageTitle;
+  if (lang==SrcLangExt_Java || lang==SrcLangExt_CSharp)
+  {
+    pageTitle = theTranslator->trPackage(displayName());
+  }
+  else if (lang==SrcLangExt_Fortran)
+  {
+    pageTitle = theTranslator->trModuleReference(displayName());
+  }
+  else
+  {
+    pageTitle = theTranslator->trNamespaceReference(displayName());
+  }
+  startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_NamespaceVisible,!generateTreeView);
+
+  if (!generateTreeView)
+  {
+    if (getOuterScope()!=Doxygen::globalScope)
+    {
+      writeNavigationPath(ol);
+    }
+    ol.endQuickIndices();
+  }
+
+  startTitle(ol,getOutputFileBase(),this);
+  ol.parseText(pageTitle);
+  addGroupListToTitle(ol,this);
+  endTitle(ol,getOutputFileBase(),displayName());
+  ol.startContents();
+  
+  if (Doxygen::searchIndex)
+  {
+    Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
+  }
+
+  bool generateTagFile = !Config_getString("GENERATE_TAGFILE").isEmpty();
+  if (generateTagFile)
+  {
+    Doxygen::tagFile << "  <compound kind=\"namespace\">" << endl;
+    Doxygen::tagFile << "    <name>" << convertToXML(name()) << "</name>" << endl;
+    Doxygen::tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>" << endl;
+  }
+
+  Doxygen::indexList.addIndexItem(this,0);
+
+  //---------------------------------------- start flexible part -------------------------------
+
+  QListIterator<LayoutDocEntry> eli(
+      LayoutDocManager::instance().docEntries(LayoutDocManager::Namespace));
+  LayoutDocEntry *lde;
+  for (eli.toFirst();(lde=eli.current());++eli)
+  {
+    switch (lde->kind())
+    {
+      case LayoutDocEntry::BriefDesc: 
+        writeBriefDescription(ol);
+        break; 
+      case LayoutDocEntry::MemberDeclStart: 
+        startMemberDeclarations(ol);
+        break; 
+      case LayoutDocEntry::NamespaceClasses: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeClassDeclarations(ol,ls->title);
+        }
+        break; 
+      case LayoutDocEntry::NamespaceNestedNamespaces: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeNamespaceDeclarations(ol,ls->title);
+        }
+        break; 
+      case LayoutDocEntry::MemberGroups: 
+        writeMemberGroups(ol);
+        break; 
+      case LayoutDocEntry::MemberDecl: 
+        {
+          LayoutDocEntryMemberDecl *lmd = (LayoutDocEntryMemberDecl*)lde;
+          writeMemberDeclarations(ol,lmd->type,lmd->title);
+        }
+        break; 
+      case LayoutDocEntry::MemberDeclEnd: 
+        endMemberDeclarations(ol);
+        break;
+      case LayoutDocEntry::DetailedDesc: 
+        {
+          LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
+          writeDetailedDescription(ol,ls->title);
+        }
+        break;
+      case LayoutDocEntry::MemberDefStart: 
+        startMemberDocumentation(ol);
+        break; 
+      case LayoutDocEntry::NamespaceInlineClasses:
+        writeInlineClasses(ol);
+        break;
+      case LayoutDocEntry::MemberDef: 
+        {
+          LayoutDocEntryMemberDef *lmd = (LayoutDocEntryMemberDef*)lde;
+          writeMemberDocumentation(ol,lmd->type,lmd->title);
+        }
+        break;
+      case LayoutDocEntry::MemberDefEnd: 
+        endMemberDocumentation(ol);
+        break;
+      case LayoutDocEntry::AuthorSection: 
+        writeAuthorSection(ol);
+        break;
+      case LayoutDocEntry::ClassIncludes:
+      case LayoutDocEntry::ClassInheritanceGraph:
+      case LayoutDocEntry::ClassNestedClasses:
+      case LayoutDocEntry::ClassCollaborationGraph:
+      case LayoutDocEntry::ClassAllMembersLink:
+      case LayoutDocEntry::ClassUsedFiles:
+      case LayoutDocEntry::ClassInlineClasses:
+      case LayoutDocEntry::FileClasses:
+      case LayoutDocEntry::FileNamespaces:
+      case LayoutDocEntry::FileIncludes:
+      case LayoutDocEntry::FileIncludeGraph:
+      case LayoutDocEntry::FileIncludedByGraph: 
+      case LayoutDocEntry::FileSourceLink:
+      case LayoutDocEntry::FileInlineClasses:
+      case LayoutDocEntry::GroupClasses: 
+      case LayoutDocEntry::GroupInlineClasses: 
+      case LayoutDocEntry::GroupNamespaces:
+      case LayoutDocEntry::GroupDirs: 
+      case LayoutDocEntry::GroupNestedGroups: 
+      case LayoutDocEntry::GroupFiles:
+      case LayoutDocEntry::GroupGraph: 
+      case LayoutDocEntry::GroupPageDocs:
+      case LayoutDocEntry::DirSubDirs:
+      case LayoutDocEntry::DirFiles:
+      case LayoutDocEntry::DirGraph:
+        err("Internal inconsistency: member %d should not be part of "
+            "LayoutDocManager::Namespace entry list\n",lde->kind());
+        break;
+    }
+  }
+
+  //---------------------------------------- end flexible part -------------------------------
+
+  ol.endContents();
+
+  if (generateTreeView)
+  {
+    writeNavigationPath(ol);
+  }
+
+  endFile(ol,TRUE);
+
+  if (generateTagFile)
   {
     writeDocAnchorsToTagFile();
     Doxygen::tagFile << "  </compound>" << endl;
   }
 
-  ol.popGeneratorState();
-  endFile(ol);
-
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
     MemberList *allMemberList = getMemberList(MemberList::allMembersList);
@@ -389,26 +585,6 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   }
 }
 
-void NamespaceDef::writeMemberDocumentation(OutputList &ol)
-{
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
-  {
-    ol.disable(OutputGenerator::Html);
-  }
-  
-  writeMemberDocumentation(ol,MemberList::docDefineMembers,theTranslator->trDefineDocumentation());
-  writeMemberDocumentation(ol,MemberList::docProtoMembers,theTranslator->trFunctionPrototypeDocumentation());
-  writeMemberDocumentation(ol,MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation());
-  writeMemberDocumentation(ol,MemberList::docEnumMembers,theTranslator->trEnumerationTypeDocumentation());
-  writeMemberDocumentation(ol,MemberList::docFuncMembers,theTranslator->trFunctionDocumentation());
-  writeMemberDocumentation(ol,MemberList::docVarMembers,theTranslator->trVariableDocumentation());
-
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
-  {
-    ol.enable(OutputGenerator::Html);
-  }
-}
-
 void NamespaceDef::writeMemberPages(OutputList &ol)
 {
   ol.pushGeneratorState();
@@ -539,11 +715,16 @@ Definition *NamespaceDef::findInnerCompound(const char *n)
 
 void NamespaceDef::addListReferences()
 {
+  //bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
   {
     LockingPtr< QList<ListItemInfo> > xrefItems = xrefListItems();
     addRefItem(xrefItems.pointer(),
-        theTranslator->trNamespace(TRUE,TRUE),
-        getOutputFileBase(),displayName()
+        qualifiedName(),
+        getLanguage()==SrcLangExt_Fortran ? 
+          theTranslator->trModule(TRUE,TRUE) : 
+          theTranslator->trNamespace(TRUE,TRUE),
+        getOutputFileBase(),displayName(),
+        0
         );
   }
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -566,10 +747,13 @@ void NamespaceDef::addListReferences()
 QCString NamespaceDef::displayName() const
 {
   QCString result=name();
-  if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+  SrcLangExt lang = getLanguage();
+  QCString sep = getLanguageSpecificSeparator(lang);
+  if (sep!="::")
   {
-    result = substitute(result,"::",".");
+    result = substitute(result,"::",sep);
   }
+  //printf("NamespaceDef::displayName() %s->%s lang=%d\n",name().data(),result.data(),lang);
   return result; 
 }
 
@@ -613,7 +797,21 @@ void NamespaceDef::combineUsingRelations()
   }
 }
 
-void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
+bool NamespaceSDict::declVisible() const
+{
+  SDict<NamespaceDef>::Iterator ni(*this);
+  NamespaceDef *nd;
+  for (ni.toFirst();(nd=ni.current());++ni)
+  {
+    if (nd->isLinkable())
+    {
+      return TRUE;
+    }
+  }
+  return FALSE;
+}
+
+void NamespaceSDict::writeDeclaration(OutputList &ol,const char *title,bool localName)
 {
   if (count()==0) return; // no namespaces in the list
 
@@ -627,27 +825,26 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
   if (!found) return; // no linkable namespaces in the list
 
   // write list of namespaces
-  ol.startMemberHeader();
-  bool javaOpt = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
-  if (javaOpt)
-  {
-    ol.parseText(theTranslator->trPackages());
-  }
-  else
-  {
-    ol.parseText(theTranslator->trNamespaces());
-  }
+  ol.startMemberHeader("namespaces");
+  //bool javaOpt    = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+  //bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  ol.parseText(title);
   ol.endMemberHeader();
   ol.startMemberList();
   for (ni.toFirst();(nd=ni.current());++ni)
   {
     if (nd->isLinkable())
     {
+      SrcLangExt lang = nd->getLanguage();
       ol.startMemberItem(0);
-      if (javaOpt)
+      if (lang==SrcLangExt_Java || lang==SrcLangExt_CSharp)
       {
         ol.docify("package ");
       }
+      else if (lang==SrcLangExt_Fortran)
+      {
+        ol.docify("module ");
+      }
       else
       {
         ol.docify("namespace ");
@@ -673,7 +870,6 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
         ol.startMemberDescription();
         ol.parseDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE);
         ol.endMemberDescription();
-        ol.newParagraph();
       }
     }
   }
@@ -703,15 +899,33 @@ void NamespaceDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
   static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
   static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
   MemberList *ml = createMemberList(lt);
-  if (((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
-      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs)
-     )
+  ml->setNeedsSorting(
+      ((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
+      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs));
+  ml->append(md);
+
+#if 0
+  if (ml->needsSorting())
     ml->inSort(md);
   else
     ml->append(md);
+#endif
+
   if (ml->listType()&MemberList::declarationLists) md->setSectionList(this,ml);
 }
 
+void NamespaceDef::sortMemberLists()
+{
+  MemberList *ml = m_memberLists.first();
+  while (ml)
+  {
+    if (ml->needsSorting()) { ml->sort(); ml->setNeedsSorting(FALSE); }
+    ml = m_memberLists.next();
+  }
+}
+
+
+
 MemberList *NamespaceDef::getMemberList(MemberList::ListType lt) const
 {
   NamespaceDef *that = (NamespaceDef*)this;
@@ -744,11 +958,35 @@ bool NamespaceDef::isLinkableInProject() const
 {
   int i = name().findRev("::");
   if (i==-1) i=0; else i+=2;
-  return !name().isEmpty() && name().at(i)!='@' &&
-    hasDocumentation() && !isReference() && !isHidden();
+  static bool extractAnonNs = Config_getBool("EXTRACT_ANON_NSPACES");
+  static bool showNamespaces = Config_getBool("SHOW_NAMESPACES");
+  if (extractAnonNs &&                             // extract anonymous ns
+      name().mid(i,20)=="anonymous_namespace{" &&  // correct prefix
+      showNamespaces)                              // not disabled by config
+  {
+    return TRUE;
+  }
+  return !name().isEmpty() && name().at(i)!='@' && // not anonymous
+    (hasDocumentation() || getLanguage()==SrcLangExt_CSharp) &&  // documented
+    !isReference() &&      // not an external reference
+    !isHidden() &&         // not hidden
+    !isArtificial() &&     // or artificial
+    showNamespaces;        // not disabled by config
 }
 
 bool NamespaceDef::isLinkable() const
 {
   return isLinkableInProject() || isReference();
 }
+
+MemberDef * NamespaceDef::getMemberByName(const QCString &n) const
+{
+  MemberDef *md = 0;
+  if (m_allMembersDict && !n.isEmpty())
+  {
+    md = m_allMembersDict->find(n);
+    //printf("%s::m_allMembersDict->find(%s)=%p\n",name().data(),n.data(),md);
+  }
+  return md;
+}
+
