@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -75,6 +75,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startIndexSection,is); }
     void endIndexSection(IndexSections is)
     { forall(&OutputGenerator::endIndexSection,is); }
+    void writePageLink(const char *name,bool first)
+    { forall(&OutputGenerator::writePageLink,name,first); }
     void startProjectNumber()
     { forall(&OutputGenerator::startProjectNumber); }
     void endProjectNumber()
@@ -95,14 +97,18 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startTitle); }
     void endTitle() 
     { forall(&OutputGenerator::endTitle); }
-    void newParagraph() 
-    { forall(&OutputGenerator::newParagraph); }
+    //void newParagraph() 
+    //{ forall(&OutputGenerator::newParagraph); }
     void startParagraph() 
     { forall(&OutputGenerator::startParagraph); }
     void endParagraph() 
     { forall(&OutputGenerator::endParagraph); }
     void writeString(const char *text) 
     { forall(&OutputGenerator::writeString,text); }
+    void startIndexListItem() 
+    { forall(&OutputGenerator::startIndexListItem); }
+    void endIndexListItem() 
+    { forall(&OutputGenerator::endIndexListItem); }
     void startIndexList() 
     { forall(&OutputGenerator::startIndexList); }
     void endIndexList() 
@@ -151,18 +157,26 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startTypewriter); }
     void endTypewriter() 
     { forall(&OutputGenerator::endTypewriter); }
-    void startGroupHeader()
-    { forall(&OutputGenerator::startGroupHeader); }
-    void endGroupHeader()
-    { forall(&OutputGenerator::endGroupHeader); }
-    void writeListItem() 
-    { forall(&OutputGenerator::writeListItem); }
+    void startGroupHeader(int extraLevels=0)
+    { forall(&OutputGenerator::startGroupHeader,extraLevels); }
+    void endGroupHeader(int extraLevels=0)
+    { forall(&OutputGenerator::endGroupHeader,extraLevels); }
+    //void writeListItem() 
+    //{ forall(&OutputGenerator::writeListItem); }
+    void startItemListItem() 
+    { forall(&OutputGenerator::startItemListItem); }
+    void endItemListItem() 
+    { forall(&OutputGenerator::endItemListItem); }
     void startMemberSections()
     { forall(&OutputGenerator::startMemberSections); }
     void endMemberSections()
     { forall(&OutputGenerator::endMemberSections); }
-    void startMemberHeader()
-    { forall(&OutputGenerator::startMemberHeader); }
+    void startHeaderSection()
+    { forall(&OutputGenerator::startHeaderSection); }
+    void endHeaderSection()
+    { forall(&OutputGenerator::endHeaderSection); }
+    void startMemberHeader(const char *anchor)
+    { forall(&OutputGenerator::startMemberHeader,anchor); }
     void endMemberHeader()
     { forall(&OutputGenerator::endMemberHeader); }
     void startMemberSubtitle()
@@ -177,6 +191,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberList); }
     void endMemberList() 
     { forall(&OutputGenerator::endMemberList); }
+    void startInlineHeader()
+    { forall(&OutputGenerator::startInlineHeader); }
+    void endInlineHeader()
+    { forall(&OutputGenerator::endInlineHeader); }
     void startAnonTypeScope(int i1) 
     { forall(&OutputGenerator::startAnonTypeScope,i1); }
     void endAnonTypeScope(int i1) 
@@ -225,8 +243,8 @@ class OutputList : public OutputDocInterface
     void writeChar(char c)
     { forall(&OutputGenerator::writeChar,c); }
     void startMemberDoc(const char *clName,const char *memName,
-                        const char *anchor,const char *title)
-    { forall(&OutputGenerator::startMemberDoc,clName,memName,anchor,title); }
+                        const char *anchor,const char *title,bool showInline)
+    { forall(&OutputGenerator::startMemberDoc,clName,memName,anchor,title,showInline); }
     void endMemberDoc(bool hasArgs) 
     { forall(&OutputGenerator::endMemberDoc,hasArgs); }
     void startDoxyAnchor(const char *fName,const char *manName,
@@ -249,6 +267,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startDescItem); }
     void endDescItem() 
     { forall(&OutputGenerator::endDescItem); }
+    void startDescForItem() 
+    { forall(&OutputGenerator::startDescForItem); }
+    void endDescForItem() 
+    { forall(&OutputGenerator::endDescForItem); }
     void startSubsection() 
     { forall(&OutputGenerator::startSubsection); }
     void endSubsection() 
@@ -265,8 +287,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startSmall); }
     void endSmall() 
     { forall(&OutputGenerator::endSmall); }
-    void lineBreak() 
-    { forall(&OutputGenerator::lineBreak); }
+    void lineBreak(const char *style=0) 
+    { forall(&OutputGenerator::lineBreak,style); }
     void startBold() 
     { forall(&OutputGenerator::startBold); }
     void endBold() 
@@ -284,8 +306,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startParamList,t,title); }
     void endParamList() 
     { forall(&OutputGenerator::endParamList); }
-    void writeDescItem() 
-    { forall(&OutputGenerator::writeDescItem); }
+    //void writeDescItem() 
+    //{ forall(&OutputGenerator::writeDescItem); }
     void startIndent() 
     { forall(&OutputGenerator::startIndent); }
     void endIndent() 
@@ -306,8 +328,20 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startPageRef); }
     void endPageRef(const char *c,const char *a)
     { forall(&OutputGenerator::endPageRef,c,a); }
+    void startQuickIndices()
+    { forall(&OutputGenerator::startQuickIndices); }
+    void endQuickIndices()
+    { forall(&OutputGenerator::endQuickIndices); }
+    void writeSplitBar(const char *name)
+    { forall(&OutputGenerator::writeSplitBar,name); }
+    void writeLogo()
+    { forall(&OutputGenerator::writeLogo); }
     void writeQuickLinks(bool compact,HighlightedItem hli)
     { forall(&OutputGenerator::writeQuickLinks,compact,hli); }
+    void startContents()
+    { forall(&OutputGenerator::startContents); }
+    void endContents()
+    { forall(&OutputGenerator::endContents); }
     void writeNonBreakableSpace(int num)
     { forall(&OutputGenerator::writeNonBreakableSpace,num); }
     void startDescTable()
@@ -387,6 +421,24 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endConstraintDocs); }
     void endConstraintList()
     { forall(&OutputGenerator::endConstraintList); }
+
+    void startMemberDocSimple()
+    { forall(&OutputGenerator::startMemberDocSimple); }
+    void endMemberDocSimple()
+    { forall(&OutputGenerator::endMemberDocSimple); }
+    void startInlineMemberType()
+    { forall(&OutputGenerator::startInlineMemberType); }
+    void endInlineMemberType()
+    { forall(&OutputGenerator::endInlineMemberType); }
+    void startInlineMemberName()
+    { forall(&OutputGenerator::startInlineMemberName); }
+    void endInlineMemberName()
+    { forall(&OutputGenerator::endInlineMemberName); }
+    void startInlineMemberDoc()
+    { forall(&OutputGenerator::startInlineMemberDoc); }
+    void endInlineMemberDoc()
+    { forall(&OutputGenerator::endInlineMemberDoc); }
+
     void startFontClass(const char *c)
     { forall(&OutputGenerator::startFontClass,c); }
     void endFontClass()
@@ -454,6 +506,7 @@ class OutputList : public OutputDocInterface
     FORALLPROTO4(const char *,const char *,const char *,const char *);
     FORALLPROTO4(const char *,const char *,const char *,bool);
     FORALLPROTO5(const char *,const char *,const char *,const char *,const char *);
+    FORALLPROTO5(const char *,const char *,const char *,const char *,bool);
   
     OutputList(const OutputList &ol);
     QList<OutputGenerator> *outputs;
