@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -110,6 +110,7 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Amp:     m_t << "&"; break;
     case DocSymbol::Dollar:  m_t << "$"; break;
     case DocSymbol::Hash:    m_t << "#"; break;
+    case DocSymbol::DoubleColon:  m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
     case DocSymbol::Copy:    m_t << "(C)"; break;
     case DocSymbol::Tm:      m_t << "(TM)"; break;
@@ -433,7 +434,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
   DBG_RTF("{\\comment RTFDocVisitor::visit(DocInclude)}\n");
   switch(inc->type())
   {
-   case DocInclude::IncWithLines:
+     case DocInclude::IncWithLines:
       { 
          m_t << "{" << endl;
          m_t << "\\par" << endl;
@@ -449,7 +450,7 @@ void RTFDocVisitor::visit(DocInclude *inc)
          m_t << "}" << endl;
       }
       break;
-   case DocInclude::Include: 
+    case DocInclude::Include: 
       m_t << "{" << endl;
       m_t << "\\par" << endl;
       m_t << rtf_Style_Reset << getStyle("CodeExample");
@@ -472,6 +473,19 @@ void RTFDocVisitor::visit(DocInclude *inc)
       m_t << "\\par";
       m_t << "}" << endl;
       break;
+    case DocInclude::Snippet:
+      m_t << "{" << endl;
+      if (!m_lastIsPara) m_t << "\\par" << endl;
+      m_t << rtf_Style_Reset << getStyle("CodeExample");
+      Doxygen::parserManager->getParser(inc->extension())
+                            ->parseCode(m_ci,
+                                        inc->context(),
+                                        extractBlock(inc->text(),inc->blockId()),
+                                        inc->isExample(),
+                                        inc->exampleFile()
+                                       );
+      m_t << "}";
+      break;
   }
   m_lastIsPara=TRUE;
 }
@@ -542,6 +556,30 @@ void RTFDocVisitor::visit(DocSimpleSectSep *)
 {
 }
 
+void RTFDocVisitor::visit(DocCite *cite)
+{
+  if (m_hide) return;
+  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocCite)}\n");
+  if (!cite->file().isEmpty()) 
+  {
+    startLink(cite->ref(),cite->file(),cite->anchor());
+  }
+  else
+  {
+    m_t << "{\\b ";
+  }
+  filter(cite->text());
+  if (!cite->file().isEmpty()) 
+  {
+    endLink(cite->ref());
+  }
+  else
+  {
+    m_t << "}";
+  }
+}
+
+
 //--------------------------------------
 // visitor functions for compound nodes
 //--------------------------------------
@@ -662,6 +700,8 @@ void RTFDocVisitor::visitPre(DocSimpleSect *s)
       m_t << theTranslator->trPrecondition(); break;
     case DocSimpleSect::Post:
       m_t << theTranslator->trPostcondition(); break;
+    case DocSimpleSect::Copyright:
+      m_t << theTranslator->trCopyright(); break;
     case DocSimpleSect::Invar:
       m_t << theTranslator->trInvariant(); break;
     case DocSimpleSect::Remark:
@@ -749,6 +789,8 @@ void RTFDocVisitor::visitPre(DocSection *s)
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocSection)}\n");
   if (!m_lastIsPara) m_t << "\\par" << endl;
+  m_t << "{\\bkmkstart " << rtfFormatBmkStr(s->file()+"_"+s->anchor()) << "}" << endl;
+  m_t << "{\\bkmkend " << rtfFormatBmkStr(s->file()+"_"+s->anchor()) << "}" << endl;
   m_t << "{{" // start section
       << rtf_Style_Reset;
   QCString heading;
@@ -952,25 +994,25 @@ void RTFDocVisitor::visitPost(DocHtmlCell *)
 void RTFDocVisitor::visitPre(DocInternal *)
 {
   if (m_hide) return;
-  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocInternal)}\n");
-  m_t << "{"; // start desc
-  m_t << "{\\b "; // start bold
-  m_t << theTranslator->trForInternalUseOnly();
-  m_t << "}"; // end bold
-  m_t << "\\par" << endl;
-  incIndentLevel();
-  m_t << rtf_Style_Reset << getStyle("DescContinue");
-  m_lastIsPara=FALSE;
+  //DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocInternal)}\n");
+  //m_t << "{"; // start desc
+  //m_t << "{\\b "; // start bold
+  //m_t << theTranslator->trForInternalUseOnly();
+  //m_t << "}"; // end bold
+  //m_t << "\\par" << endl;
+  //incIndentLevel();
+  //m_t << rtf_Style_Reset << getStyle("DescContinue");
+  //m_lastIsPara=FALSE;
 }
 
 void RTFDocVisitor::visitPost(DocInternal *) 
 {
   if (m_hide) return;
-  DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocInternal)}\n");
-  m_t << "\\par";
-  decIndentLevel();
-  m_t << "}"; // end desc
-  m_lastIsPara=TRUE;
+  //DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocInternal)}\n");
+  //m_t << "\\par";
+  //decIndentLevel();
+  //m_t << "}"; // end desc
+  //m_lastIsPara=TRUE;
 }
 
 void RTFDocVisitor::visitPre(DocHRef *href)
@@ -1083,7 +1125,7 @@ void RTFDocVisitor::visitPost(DocDotFile *)
 }
 void RTFDocVisitor::visitPre(DocMscFile *df)
 {
-  DBG_RTF("{\\comment RTFDocVisitor::visitPre(MscDotFile)}\n");
+  DBG_RTF("{\\comment RTFDocVisitor::visitPre(DocMscFile)}\n");
   writeMscFile(df->file());
 
   // hide caption since it is not supported at the moment
@@ -1093,7 +1135,7 @@ void RTFDocVisitor::visitPre(DocMscFile *df)
 
 void RTFDocVisitor::visitPost(DocMscFile *) 
 {
-  DBG_RTF("{\\comment RTFDocVisitor::visitPost(MscDotFile)}\n");
+  DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocMscFile)}\n");
   popEnabled();
 }
 
@@ -1124,7 +1166,7 @@ void RTFDocVisitor::visitPost(DocRef *ref)
   if (m_hide) return;
   DBG_RTF("{\\comment RTFDocVisitor::visitPost(DocRef)}\n");
   if (!ref->file().isEmpty()) endLink(ref->ref());
-  m_t << " ";
+  //m_t << " ";
 }
 
 
@@ -1241,7 +1283,7 @@ void RTFDocVisitor::visitPre(DocParamList *pl)
   { { 2, 25, 100, 100, 100 }, // no inout, no type
     { 3, 14,  35, 100, 100 }, // inout, no type
     { 3, 25,  50, 100, 100 }, // no inout, type
-    { 4, 14,  35, 55,  100 }, // no inout, type
+    { 4, 14,  35, 55,  100 }, // inout, type
   };
   int config=0;
   if (m_hide) return;
