@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2007 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,9 +34,9 @@ class RTFGenerator : public OutputGenerator
     void enable() 
     { if (genStack->top()) active=*genStack->top(); else active=TRUE; }
     void disable() { active=FALSE; }
-    void enableIf(OutputType o)  { if (o==RTF) active=TRUE;  }
-    void disableIf(OutputType o) { if (o==RTF) active=FALSE; }
-    void disableIfNot(OutputType o) { if (o!=RTF) active=FALSE; }
+    void enableIf(OutputType o)  { if (o==RTF) enable();  }
+    void disableIf(OutputType o) { if (o==RTF) disable(); }
+    void disableIfNot(OutputType o) { if (o!=RTF) disable(); }
     bool isEnabled(OutputType o) { return (o==RTF && active); } 
     OutputGenerator *get(OutputType o) { return (o==RTF) ? this : 0; }
 
@@ -46,10 +46,11 @@ class RTFGenerator : public OutputGenerator
     void writeFooter() {}
     void endFile();
     void clearBuffer();
-    void postProcess(QByteArray &);
+    //void postProcess(QByteArray &);
     
     void startIndexSection(IndexSections);
     void endIndexSection(IndexSections);
+    void writePageLink(const char *,bool);
     void startProjectNumber();
     void endProjectNumber();
     void writeStyleInfo(int part);
@@ -62,6 +63,8 @@ class RTFGenerator : public OutputGenerator
     void startParagraph();
     void endParagraph();
     void writeString(const char *text);
+    void startIndexListItem();
+    void endIndexListItem();
     void startIndexList();
     void endIndexList();
     void startIndexKey();
@@ -85,20 +88,26 @@ class RTFGenerator : public OutputGenerator
     void endHtmlLink();
     void startTypewriter() { t << "{\\f2 "; }
     void endTypewriter()   { t << "}";      }
-    void startGroupHeader();
-    void endGroupHeader();
-    void writeListItem();
+    void startGroupHeader(int);
+    void endGroupHeader(int);
+    //void writeListItem();
+    void startItemListItem();
+    void endItemListItem();
 
     void startMemberSections() {}
     void endMemberSections() {} 
-    void startMemberHeader() { startGroupHeader(); }
-    void endMemberHeader() { endGroupHeader(); }
+    void startHeaderSection() {}
+    void endHeaderSection() {}
+    void startMemberHeader(const char *) { startGroupHeader(FALSE); }
+    void endMemberHeader() { endGroupHeader(FALSE); }
     void startMemberSubtitle(); 
     void endMemberSubtitle(); 
     void startMemberDocList() {}
     void endMemberDocList() {}
     void startMemberList();
     void endMemberList();
+    void startInlineHeader();
+    void endInlineHeader();
     void startAnonTypeScope(int) {}
     void endAnonTypeScope(int) {}
     void startMemberItem(int);
@@ -123,8 +132,8 @@ class RTFGenerator : public OutputGenerator
     void endDescription();
     void startDescItem();
     void endDescItem();
-    void lineBreak();
-    void startMemberDoc(const char *,const char *,const char *,const char *);
+    void lineBreak(const char *style=0);
+    void startMemberDoc(const char *,const char *,const char *,const char *,bool);
     void endMemberDoc(bool);
     void startDoxyAnchor(const char *,const char *,const char *,const char *,const char *);
     void endDoxyAnchor(const char *,const char *);
@@ -151,7 +160,9 @@ class RTFGenerator : public OutputGenerator
     void endSimpleSect();
     void startParamList(ParamListTypes,const char *);
     void endParamList();
-    void writeDescItem();
+    //void writeDescItem();
+    void startDescForItem();
+    void endDescForItem();
     void startSection(const char *,const char *,SectionInfo::SectionType);
     void endSection(const char *,SectionInfo::SectionType);
     void addIndexItem(const char *,const char *);
@@ -162,7 +173,13 @@ class RTFGenerator : public OutputGenerator
     void endClassDiagram(const ClassDiagram &,const char *filename,const char *name);
     void startPageRef();
     void endPageRef(const char *,const char *);
+    void startQuickIndices() {}
+    void endQuickIndices() {}
+    void writeSplitBar(const char *) {}
+    void writeLogo() {}
     void writeQuickLinks(bool,HighlightedItem) {}
+    void startContents() {}
+    void endContents() {}
     void writeNonBreakableSpace(int);
 	
     void startDescTable();
@@ -199,8 +216,8 @@ class RTFGenerator : public OutputGenerator
     void endMemberDocPrefixItem() {}
     void startMemberDocName(bool) {}
     void endMemberDocName() {}
-    void startParameterType(bool,const char *) {}
-    void endParameterType() {}
+    void startParameterType(bool,const char *);
+    void endParameterType();
     void startParameterName(bool) {}
     void endParameterName(bool,bool,bool) {}
     void startParameterList(bool) {}
@@ -215,6 +232,14 @@ class RTFGenerator : public OutputGenerator
     void endConstraintDocs();
     void endConstraintList();
 
+    void startMemberDocSimple();
+    void endMemberDocSimple();
+    void startInlineMemberType();
+    void endInlineMemberType();
+    void startInlineMemberName();
+    void endInlineMemberName();
+    void startInlineMemberDoc();
+    void endInlineMemberDoc();
 
     void startFontClass(const char *) {}
     void endFontClass() {}
