@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,18 @@
  *
  * Revision history
  *
+ *  2010/08: updated translation of new items used since version 1.6.0 and 1.6.3
+ *           completely reviewed the translation in the trLegendDocs() function
+ *           corrected some typos all around
+ *           reviewed some translations all around
+ *  2007/11: updated translation of new items used since version 1.5.4
+ *  2007/10: Included corrections provided by Arialdo Martini <arialdomartini@bebox.it>, updated some strings marked with 'translate me' comment
+ *  2006/10: made class to derive directly from Translator class (reported in Petr Prikryl October 9 translator report)
+ *  2006/06: updated translation of new items used since version 1.4.6
+ *  2006/05: translated new items used since version 1.4.6
+ *           corrected typo in trPackageMembers method
+ *  2005/03: translated new items used since version 1.4.1
+ *           removed unused methods listed in Petr Prikryl February 28 translator report
  *  2004/09: translated new items used since version 1.3.9
  *  2004/06: translated new items used since version 1.3.8
  *  2003/11: translated new items used since version 1.3.3
@@ -28,7 +40,7 @@
  *  2002/08: translated new items used since version 1.2.17
  *  2002/07: translated new items used since version 1.2.16
  *  2002/06: modified trRelatedPagesDescription() method
- *           correct typo in trInclByDepGraph() method
+ *           corrected typo in trInclByDepGraph() method
  *  2002/01: translated new items used since version 1.2.13
  *           updated e-mail address
  *  2001/11: corrected the translation fixing the issues reported by the translator.pl script
@@ -50,7 +62,7 @@
  *           commented translator.h for the english language
  *  1999/09: corrected some small typos in the "new since 0.49-990425" section
  *           added the "new since 0.49-990728" section
- *  1999/06: revised and completed by Alessandro Falappa (actual mantainer)
+ *  1999/06: revised and completed by Alessandro Falappa (current mantainer)
  *  1999/??: initial italian translation by Ahmed Aldo Faisal
  */
 
@@ -61,7 +73,7 @@
  * Nella traduzione non si sono tradotti alcuni termini inglesi ormai entrati
  * a far parte del "gergo" informatico (per es. file o namespace)
  *
- * Il plurale dei termini inglesi non tradotti  stato reso con il singolare
+ * Il plurale dei termini inglesi non tradotti è stato reso con il singolare
  * della parola inglese secondo una convenzione spesso ritrovata nella documentazione
  * tecnica (ad es. "lista dei file" e non "lista dei files")
  *
@@ -72,7 +84,7 @@
 #ifndef TRANSLATOR_IT_H
 #define TRANSLATOR_IT_H
 
-class TranslatorItalian : public Translator
+class TranslatorItalian : public TranslatorAdapter_1_7_5
 {
   public:
 
@@ -98,7 +110,7 @@ class TranslatorItalian : public Translator
     /*! return the language charset. This will be used for the HTML output */
     virtual QCString idLanguageCharset()
     {
-      return "iso-8859-1";
+      return "UTF-8";
     }
 
     // --- Language translation methods -------------------
@@ -113,7 +125,7 @@ class TranslatorItalian : public Translator
 
     /*! header that is put before the detailed description of files, classes and namespaces. */
     QCString trDetailedDescription()
-    { return "Descrizione Dettagliata"; }
+    { return "Descrizione dettagliata"; }
 
     /*! header that is put before the list of typedefs. */
     QCString trMemberTypedefDocumentation()
@@ -136,7 +148,7 @@ class TranslatorItalian : public Translator
       }
       else
       {
-        return "Documentazione dei dati membri";
+        return "Documentazione dei membri dato";
       }
     }
 
@@ -146,15 +158,15 @@ class TranslatorItalian : public Translator
 
     /*! put in the class documentation */
     QCString trListOfAllMembers()
-    { return "Lista di tutti i membri."; }
+    { return "Elenco di tutti i membri."; }
 
     /*! used as the title of the "list of all members" page of a class */
     QCString trMemberList()
-    { return "Lista dei membri"; }
+    { return "Elenco dei membri"; }
 
     /*! this is the first part of a sentence that is followed by a class name */
     QCString trThisIsTheListOfAllMembers()
-    { return "Questa  la lista completa di tutti i membri di "; }
+    { return "Questo è l'elenco completo di tutti i membri di "; }
 
     /*! this is the remainder of the sentence after the class name */
     QCString trIncludingInheritedMembers()
@@ -204,17 +216,13 @@ class TranslatorItalian : public Translator
       }
       else
       {
-        return "Lista dei composti";
+        return "Elenco dei tipi composti";
       }
     }
 
     /*! This is put above each page as a link to the list of documented files */
     QCString trFileList()
-    { return "Lista dei file"; }
-
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    QCString trHeaderFiles()
-    { return "Lista dei file header"; }
+    { return "Elenco dei file"; }
 
     /*! This is put above each page as a link to all members of compounds. */
     QCString trCompoundMembers()
@@ -238,7 +246,7 @@ class TranslatorItalian : public Translator
       }
       else
       {
-        return "Membri dei file";
+        return "Elementi dei file";
       }
     }
 
@@ -257,14 +265,14 @@ class TranslatorItalian : public Translator
     /*! This is an introduction to the class hierarchy. */
     QCString trClassHierarchyDescription()
     {
-        return "Questa lista di ereditariet  ordinata "
+        return "Questo elenco di ereditarietà è ordinato "
         "approssimativamente, ma non completamente, in ordine alfabetico:";
     }
 
     /*! This is an introduction to the list with all files. */
     QCString trFileListDescription(bool extractAll)
     {
-      QCString result="Questa  una lista ";
+      QCString result="Questo è un elenco ";
       if (!extractAll) result+="dei file documentati ";
       else result+="di tutti i file ";
       result+="con una loro breve descrizione:";
@@ -281,14 +289,14 @@ class TranslatorItalian : public Translator
       }
       else
       {
-        return "Queste sono le classi, structs, unions e interfacce con una loro breve descrizione:";
+        return "Queste sono le classi, le struct, le union e le interfacce con una loro breve descrizione:";
       }
     }
 
     /*! This is an introduction to the page with all class members. */
     QCString trCompoundMembersDescription(bool extractAll)
     {
-      QCString result="Questa  una lista ";
+      QCString result="Questo è un elenco ";
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
         if (!extractAll) result+="delle struct e delle union documentate ";
@@ -307,7 +315,7 @@ class TranslatorItalian : public Translator
       }
       else
       {
-          if (extractAll) result+="della classe di ciascun membro:";
+          if (extractAll) result+="della classe a cui appartengono:";
           else result+="delle classi a cui appartengono:";
       }
       return result;
@@ -316,16 +324,16 @@ class TranslatorItalian : public Translator
     /*! This is an introduction to the page with all file members. */
     QCString trFileMembersDescription(bool extractAll)
     {
-      QCString result="Questa  una lista ";
+      QCString result="Questo è un elenco ";
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-          if (!extractAll) result+="delle funczioni, variabili, define, tipi enumerati, e typedefs documentati ";
-          else result+="di tutte le funczioni, variabili, define, tipi enumerati, e typedefs ";
+          if (!extractAll) result+="delle funzioni, delle variabili, delle define, dei tipi enumerati e delle ridefinizioni dei tipi (typedef) documentate ";
+          else result+="di tutte le funzioni, variabili, define, tipi enumerati, e ridefinizioni dei tipi (typedef) ";
       }
       else
       {
-          if (!extractAll) result+="dei membri dei file documentati ";
-          else result+="di tutti i membri dei file ";
+          if (!extractAll) result+="degli elementi documentati dei file ";
+          else result+="di tutti gli elementi dei file ";
       }
       result+="con collegamenti alla documentazione";
       if (extractAll) result+=" del file a cui appartengono:";
@@ -333,31 +341,20 @@ class TranslatorItalian : public Translator
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    QCString trHeaderFilesDescription()
-    { return "Questi sono gli header file che compongono l'API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     QCString trExamplesDescription()
-    { return "Questa  la lista di tutti gli esempi:"; }
+    { return "Questo è l'elenco di tutti gli esempi:"; }
 
     /*! This is an introduction to the page with the list of related pages */
     QCString trRelatedPagesDescription()
-    { return "Questa  la lista di tutte le pagine di documentazione generale:"; }
+    { return "Questo è l'elenco di tutte le pagine di documentazione collegate:"; }
 
     /*! This is an introduction to the page with the list of class/file groups */
     QCString trModulesDescription()
-    { return "Questa  la lista di tutti i moduli:"; }
-
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    QCString trNoDescriptionAvailable()
-    { return "Descrizione non disponibile"; }
+    { return "Questo è l'elenco di tutti i moduli:"; }
 
     // index titles (the project name is prepended for these)
 
-
     /*! This is used in HTML as the title of index.html. */
     QCString trDocumentation()
     { return "Documentazione"; }
@@ -385,7 +382,7 @@ class TranslatorItalian : public Translator
       }
       else
       {
-        return "Indice dei composti";
+        return "Indice dei tipi composti";
       }
     }
 
@@ -423,7 +420,7 @@ class TranslatorItalian : public Translator
      *  the documentation of all related pages.
      */
     QCString trPageDocumentation()
-    { return "Documentazione delle pagine collegate fra loro"; }
+    { return "Documentazione delle pagine tra loro collegate "; }
 
     /*! This is used in LaTeX as the title of the document */
     QCString trReferenceManual()
@@ -445,7 +442,7 @@ class TranslatorItalian : public Translator
      *  list of typedefs
      */
     QCString trTypedefs()
-    { return "Ridefinizioni di tipo (typedefs)"; }
+    { return "Ridefinizioni di tipo (typedef)"; }
 
     /*! This is used in the documentation of a file as a header before the
      *  list of enumerations
@@ -469,7 +466,7 @@ class TranslatorItalian : public Translator
      *  list of (global) variables
      */
     QCString trEnumerationValues()
-    { return "Valori dei tipi enumerati"; }
+    { return "Valori del tipo enumerato"; }
 
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
@@ -487,7 +484,7 @@ class TranslatorItalian : public Translator
      *  of documentation blocks for typedefs
      */
     QCString trTypedefDocumentation()
-    { return "Documentazione delle ridefinizioni di tipo (typedefs)"; }
+    { return "Documentazione delle ridefinizioni di tipo (typedef)"; }
 
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for enumeration types
@@ -495,12 +492,6 @@ class TranslatorItalian : public Translator
     QCString trEnumerationTypeDocumentation()
     { return "Documentazione dei tipi enumerati"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for enumeration values
-     */
-    QCString trEnumerationValueDocumentation()
-    { return "Documentazione dei valori dei tipi enumerati"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
@@ -533,7 +524,7 @@ class TranslatorItalian : public Translator
      */
     QCString trGeneratedAt(const char *date,const char *projName)
     {
-      QCString result=(QCString)"Generato il "+date;
+      QCString result=(QCString)"Generato "+date;
       if (projName) result+=(QCString)" per "+projName;
       result+=(QCString)" da";
       return result;
@@ -555,18 +546,10 @@ class TranslatorItalian : public Translator
     QCString trForInternalUseOnly()
     { return "Solo per uso interno."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    QCString trReimplementedForInternalReasons()
-    { return "Reimplementato per motivi interni; l'API non  stata modificata.";}
-
     /*! this text is generated when the \\warning command is used. */
     QCString trWarning()
     { return "Avvertimento"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    QCString trBugsAndLimitations()
-    { return "Bug e limitazioni"; }
-
     /*! this text is generated when the \\version command is used. */
     QCString trVersion()
     { return "Versione"; }
@@ -581,7 +564,7 @@ class TranslatorItalian : public Translator
 
     /*! this text is generated when the \\sa command is used. */
     QCString trSeeAlso()
-    { return "Vedi anche"; }
+    { return "Si veda anche"; }
 
     /*! this text is generated when the \\param command is used. */
     QCString trParameters()
@@ -606,7 +589,7 @@ class TranslatorItalian : public Translator
     /*! used as an introduction to the namespace list */
     QCString trNamespaceListDescription(bool extractAll)
     {
-      QCString result="Questa  la lista ";
+      QCString result="Questa è l'elenco ";
       if (!extractAll) result+="dei namespace documentati, ";
       else result+="di tutti i namespace ";
       result+="con una loro breve descrizione:";
@@ -646,9 +629,9 @@ class TranslatorItalian : public Translator
         case ClassDef::Struct: result+="la struct "; break;
         case ClassDef::Union:  result+="la union "; break;
         case ClassDef::Interface:  result+="l'interfaccia "; break;
-        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
-        case ClassDef::Category:   result+="category "; break; // translate me!
-        case ClassDef::Exception:  result+="exception "; break;
+        case ClassDef::Protocol:   result+="il protocollo "; break;
+        case ClassDef::Category:   result+="la categoria "; break;
+        case ClassDef::Exception:  result+="l'eccezione "; break;
       }
       result+=(QCString)clName;
       return result;
@@ -757,9 +740,9 @@ class TranslatorItalian : public Translator
     /*! This is an introduction to the page with all namespace members */
     QCString trNamespaceMemberDescription(bool extractAll)
     {
-      QCString result="Questa  la lista ";
-      if (!extractAll) result+="dei membri dei namespace documentati, ";
-       else result+="di tutti i membri dei namespace ";
+      QCString result="Questa è la lista ";
+      if (!extractAll) result+="dei membri documentati del namespace, ";
+       else result+="di tutti i membri del namespace ";
       result+="con collegamenti ";
       if (extractAll)
         result+="alla documentazione del namespace per ciascun membro:";
@@ -800,18 +783,18 @@ class TranslatorItalian : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"La documentazione per questa ";
+      QCString result=(QCString)"La documentazione per quest";
       switch(compType)
       {
-        case ClassDef::Class:      result+="classe"; break;
-        case ClassDef::Struct:     result+="struct"; break;
-        case ClassDef::Union:      result+="union"; break;
-        case ClassDef::Interface:  result+="interfaccia"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
-        case ClassDef::Exception:  result+="exception"; break;
+        case ClassDef::Class:      result+="a classe"; break;
+        case ClassDef::Struct:     result+="a struct"; break;
+        case ClassDef::Union:      result+="a union"; break;
+        case ClassDef::Interface:  result+="a interfaccia"; break;
+        case ClassDef::Protocol:   result+="o protocollo"; break;
+        case ClassDef::Category:   result+="a categoria"; break;
+        case ClassDef::Exception:  result+="a eccezione"; break;
       }
-      result+="  stata generata a partire ";
+      result+=" è stata generata a partire ";
       if (single) result+="dal seguente file:";
       else result+="dai seguenti file:";
       return result;
@@ -846,10 +829,6 @@ class TranslatorItalian : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Sorgenti";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "Definizione alla linea @0 del file @1.";
@@ -1004,7 +983,7 @@ class TranslatorItalian : public Translator
     /*! Used as the header of the todo list */
     virtual QCString trTodoList()
     {
-      return "Lista di cose da fare";
+      return "Elenco delle cose da fare";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1046,19 +1025,21 @@ class TranslatorItalian : public Translator
     {
       return
         "Questa pagina spiega come interpretare i grafi generati da doxygen.<p>\n"
-        "Considerate l'esempio seguente:\n"
+        "Si consideri l'esempio seguente:\n"
         "\\code\n"
         "/*! Classe invisibile per troncamento */\n"
         "class Invisible { };\n\n"
-        "/*! Classe troncata, la relazione di ereditariet e nascosta */\n"
+        "/*! Classe tronca, la relazione di ereditarietà è nascosta */\n"
         "class Truncated : public Invisible { };\n\n"
         "/* Classe non documentata con i commenti speciali di doxygen*/\n"
         "class Undocumented { };\n\n"
-        "/*! Classe che utilizza una ereditariet pubblica */\n"
+        "/*! Classe estesa mediante ereditarietà pubblica */\n"
         "class PublicBase : public Truncated { };\n\n"
-        "/*! Classe che utilizza una ereditariet protetta*/\n"
+        "/*! Classe templatizzata */\n"
+        "template<class T> class Templ { };\n\n"
+        "/*! Classe estesa mediante ereditarietà protetta*/\n"
         "class ProtectedBase { };\n\n"
-        "/*! Classe che utilizza una ereditariet  privata*/\n"
+        "/*! Classe estesa mediante ereditarietà privata*/\n"
         "class PrivateBase { };\n\n"
         "/*! Classe utilizzata dalla classe Inherited */\n"
         "class Used { };\n\n"
@@ -1066,30 +1047,35 @@ class TranslatorItalian : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
         "};\n"
         "\\endcode\n"
-        "Se il tag \\c MAX_DOT_GRAPH_HEIGHT nel file di configurazione "
-        " impostato a 200 verr prodotto il grafo seguente:"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "Verrà prodotto il grafo seguente:"
+        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center></p>\n"
         "<p>\n"
         "I riquadri nel grafo qui sopra hanno il seguente significato:\n"
+        "</p>\n"
         "<ul>\n"
-        "<li>Il riquadro nero pieno rappresenta la struct o la classe per la quale il grafo  stato generato.\n"
-        "<li>Un riquadro con un bordo nero denota una struct o una classe documentata.\n"
-        "<li>Un riquadro con un bordo grigio indica una struct o una classe non documentata.\n"
-        "<li>Un riquadro con un bordo rosso indica una struct o una classe per la quale non sono mostrate tutte le relazioni di ereditariet/contenimento (un grafo viene troncato se non rientra nei limiti prestabiliti)."
+        "<li>Il riquadro grigio pieno rappresenta la struct o la classe per la quale il grafo è stato generato.</li>\n"
+        "<li>Un riquadro con un bordo nero denota una struct o una classe documentata.</li>\n"
+        "<li>Un riquadro con un bordo grigio indica una struct o una classe non documentata.</li>\n"
+        "<li>Un riquadro con un bordo rosso indica una struct o una classe per la quale non sono mostrate tutte le relazioni di ereditarietà/contenimento (un grafo viene troncato se non rientra nei limiti prestabiliti).</li>\n"
         "</ul>\n"
+        "<p>\n"
         "Le frecce hanno il seguente significato:\n"
+        "</p>\n"
         "<ul>\n"
-        "<li>Una freccia blu scuro indica una relazione di ereditariet pubblica tra due classi.\n"
-        "<li>Una freccia verde indica un'ereditariet protetta.\n"
-        "<li>Una freccia rossa indica un'ereditariet privata.\n"
-        "<li>Una freccia viola tratteggiata indica che una classe  contenuta o usata da un'altra classe."
-        " La freccia viene etichettata con la o le variabili attraverso cui la struct o la classe puntata dalla freccia  accessibile.\n"
+        "<li>Una freccia blu scuro indica una relazione di ereditarietà pubblica tra due classi.</li>\n"
+        "<li>Una freccia verde indica un'ereditarietà protetta.</li>\n"
+        "<li>Una freccia rossa indica un'ereditarietà privata.</li>\n"
+        "<li>Una freccia viola tratteggiata indica che una classe è contenuta o usata da un'altra classe."
+        " La freccia viene etichettata con la o le variabili attraverso cui la struct o la classe puntata dalla freccia è accessibile.</li>\n"
+        "<li>Una freccia gialla tratteggiata indica la relazione tra una istanza di un template e la classe templatizzata da cui è stata istanziata."
+        " La freccia viene etichettata con i parametri di template dell'istanza.</li>\n"
         "</ul>\n";
     }
     /*! text for the link to the legend page */
@@ -1130,23 +1116,18 @@ class TranslatorItalian : public Translator
     /*! Used as a section header for IDL properties */
     virtual QCString trProperties()
     {
-      return "Propriet";
+      return "Proprietà";
     }
     /*! Used as a section header for IDL property documentation */
     virtual QCString trPropertyDocumentation()
     {
-      return "Documentazione delle propriet";
+      return "Documentazione delle proprietà";
     }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfacce";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1179,11 +1160,6 @@ class TranslatorItalian : public Translator
     {
       return "Package";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Documentazione dei package";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1291,17 +1267,6 @@ class TranslatorItalian : public Translator
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "Camp" : "camp"));
-      result+=(singular ? "o" : "i");
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1334,7 +1299,7 @@ class TranslatorItalian : public Translator
      */
     virtual QCString trReferences()
     {
-      return "Riferimenti";
+      return "Referenzia";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1407,35 +1372,35 @@ class TranslatorItalian : public Translator
      */
     virtual QCString trPackageTypes()
     {
-      return "Tipi con visibilit di package";
+      return "Tipi con visibilità di package";
     }
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
     virtual QCString trPackageMembers()
     {
-      return "Funczioni con visibilit di package";
+      return "Funzioni con visibilità di package";
     }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
     {
-      return "Funzioni statiche con visibilit di package";
+      return "Funzioni statiche con visibilità di package";
     }
     /*! Used as a heading for a list of Java class variables with package
      * scope.
      */
     virtual QCString trPackageAttribs()
     {
-      return "Attributi con visibilit di package";
+      return "Attributi con visibilità di package";
     }
     /*! Used as a heading for a list of static Java class variables with
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
     {
-      return "Attributi statici con visibilit di package";
+      return "Attributi statici con visibilità di package";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1452,7 +1417,7 @@ class TranslatorItalian : public Translator
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-      return "Questo  il grafo delle chiamate per questa funzione:";
+      return "Questo è il grafo delle chiamate per questa funzione:";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1490,11 +1455,11 @@ class TranslatorItalian : public Translator
       }
       else if (numDocuments==1)
       {
-        return "Trovato <b>1</b> documento rispondente alla tua richiesta.";
+        return "Trovato <b>1</b> documento che soddisfa la tua richiesta.";
       }
       else
       {
-        return "Trovati <b>$num</b> documenti rispondenti alla tua richiesta. "
+        return "Trovati <b>$num</b> documenti che soddisfano la tua richiesta. "
                "Le corrispondenze migliori sono in testa.";
       }
     }
@@ -1543,8 +1508,8 @@ class TranslatorItalian : public Translator
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
-    { return "Questa gerarchia di directory  ordinata "
-        "approssimativamente, ma non completamente, in ordine alfabetico:";
+    { return "Questa gerarchia di directory è approssimativamente, "
+        "ma non completamente, ordinata in ordine alfabetico:";
     }
 
     /*! This returns the title of a directory page. The name of the
@@ -1562,6 +1527,327 @@ class TranslatorItalian : public Translator
       return result;
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Questa è una funzione membro sovraccaricata (overloaded), "
+              "fornita per comodità. Differisce dalla funzione di cui sopra "
+              "unicamente per gli argomenti passati.";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Questo è il grafo dei chiamanti di questa funzione:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Documentazione dei tipi enumerati"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.5.4 (mainly for Fortran)
+//////////////////////////////////////////////////////////////////////////
+    
+    /*! header that is put before the list of member subprograms (Fortran). */
+    virtual QCString trMemberFunctionDocumentationFortran()
+    { return "Documentazione delle funzioni membro/subroutine"; }
+
+    /*! This is put above each page as a link to the list of annotated data types (Fortran). */    
+    virtual QCString trCompoundListFortran()
+    { return "Elenco dei tipi di dato"; }
+
+    /*! This is put above each page as a link to all members of compounds (Fortran). */
+    virtual QCString trCompoundMembersFortran()
+    { return "Membri dei tipi di dato"; }
+
+    /*! This is an introduction to the annotated compound list (Fortran). */
+    virtual QCString trCompoundListDescriptionFortran()
+    { return "Questi sono i tipi dato con una loro breve descrizione:"; }
+
+    /*! This is an introduction to the page with all data types (Fortran). */
+    virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
+    {
+      QCString result="Questa è una lista di tutti i membri ";
+      if (!extractAll)
+      {
+        result+="documentati ";
+      }
+      result+="dei tipi di dato con collegamenti ";
+      if (!extractAll) 
+      {
+         result+="alla documentazione della struttura dati per ciascun membro:";
+      }
+      else 
+      {
+         result+="ai tipi dato a cui appartengono:";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     * annotated compound index (Fortran).
+     */
+    virtual QCString trCompoundIndexFortran()
+    { return "Indice dei tipi dati"; }
+
+    /*! This is used in LaTeX as the title of the chapter containing
+     *  the documentation of all data types (Fortran).
+     */
+    virtual QCString trTypeDocumentation()
+    { return "Documentazione dei tipi dato"; }
+
+    /*! This is used in the documentation of a file as a header before the 
+     *  list of (global) subprograms (Fortran).
+     */
+    virtual QCString trSubprograms()
+    { return "Funzioni/Subroutine"; }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for subprograms (Fortran)
+     */
+    virtual QCString trSubprogramDocumentation()
+    { return "Documentazione funzioni/subroutine"; }
+
+    /*! This is used in the documentation of a file/namespace/group before 
+     *  the list of links to documented compounds (Fortran)
+     */
+     virtual QCString trDataTypes()
+    { return "Tipi di dato"; }
+    
+    /*! used as the title of page containing all the index of all modules (Fortran). */
+    virtual QCString trModulesList()
+    { return "Elenco dei moduli"; }
+
+    /*! used as an introduction to the modules list (Fortran) */
+    virtual QCString trModulesListDescription(bool extractAll)
+    {
+      QCString result="Questa è una lista di tutti i moduli ";
+      if (!extractAll) result+="documentati ";
+      result+="con una loro breve descrizione:";
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module/type (Fortran) */
+    virtual QCString trCompoundReferenceFortran(const char *clName,
+                                    ClassDef::CompoundType compType,
+                                    bool isTemplate)
+    {
+      QCString result="Riferimenti per ";
+      if (isTemplate) result="Template per ";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+=" il modulo"; break;
+        case ClassDef::Struct:     result+=" il tipo dato"; break;
+        case ClassDef::Union:      result+=" l'union"; break;
+        case ClassDef::Interface:  result+=" l'nterfaccia"; break;
+        case ClassDef::Protocol:   result+=" il protocollo"; break;
+        case ClassDef::Category:   result+=" la categoria"; break;
+        case ClassDef::Exception:  result+=" l'eccezione"; break;
+      }
+      result+=(QCString)clName;
+      return result;
+    }
+
+    /*! used as the title of the HTML page of a module (Fortran) */
+    virtual QCString trModuleReference(const char *namespaceName)
+    {
+      QCString result="Riferimenti per il modulo ";
+      result+=namespaceName;        
+      return result;
+    }
+    
+    /*! This is put above each page as a link to all members of modules. (Fortran) */
+    virtual QCString trModulesMembers()
+    { return "Membri del modulo"; }
+
+    /*! This is an introduction to the page with all modules members (Fortran) */
+    virtual QCString trModulesMemberDescription(bool extractAll)
+    { 
+      QCString result="Questo è un elenco di tutti i membri dei moduli ";
+      if (!extractAll) result+="documentati ";
+      result+="con collegamenti ";
+      if (extractAll) 
+      {
+        result+="alla documentazione del modulo per ciascun membro:";
+      }
+      else 
+      {
+        result+="al modulo a cui appartengono:";
+      }
+      return result;
+    }
+
+    /*! This is used in LaTeX as the title of the chapter with the 
+     *  index of all modules (Fortran).
+     */
+    virtual QCString trModulesIndex()
+    { return "Indice dei moduli"; }
+    
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trModule(bool first_capital, bool singular)
+    {       
+      QCString result((first_capital ? "Modul" : "modul"));
+      if (singular) result+="o";
+      else result+="i";
+      return result; 
+    }
+    /*! This is put at the bottom of a module documentation page and is
+     *  followed by a list of files that were used to generate the page.
+     */
+    virtual QCString trGeneratedFromFilesFortran(ClassDef::CompoundType compType,
+        bool single)
+    { // here s is one of " Module", " Struct" or " Union"
+      // single is true implies a single file
+      QCString result=(QCString)"La documentazione per quest";
+      switch(compType)
+      {
+        case ClassDef::Class:      result+="o modulo"; break;
+        case ClassDef::Struct:     result+="o tipo"; break;
+        case ClassDef::Union:      result+="a union"; break;
+        case ClassDef::Interface:  result+="a interfaccia"; break;
+        case ClassDef::Protocol:   result+="o protocollo"; break;
+        case ClassDef::Category:   result+="a categoria"; break;
+        case ClassDef::Exception:  result+="a eccezione"; break;
+      }
+      result+=" è stata generata a partire ";
+      if (single) result+="dal seguente file:"; else result+="dai seguenti file:";
+      return result;
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trType(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Tip" : "tip"));
+      if (singular) result+="o";
+      else result+="i";
+      return result; 
+    }
+    /*! This is used for translation of the word that will possibly
+     *  be followed by a single name or by a list of names 
+     *  of the category.
+     */
+    virtual QCString trSubprogram(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Sottoprogramm" : "sottoprogramm"));
+      if (singular) result+="a";
+      else result+="i";
+      return result; 
+    }
+
+    /*! C# Type Contraint list */
+    virtual QCString trTypeConstraints()
+    {
+      return "Vincoli dei tipi";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.0 (mainly for the new search engine)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! directory relation for \a name */
+    virtual QCString trDirRelation(const char *name)
+    {
+      return "Relazione per "+QCString(name);
+    }
+
+    /*! Loading message shown when loading search results */
+    virtual QCString trLoading()
+    {
+      return "Caricamento in corso...";
+    }
+
+    /*! Label used for search results in the global namespace */
+    virtual QCString trGlobalNamespace()
+    {
+      return "Namespace globale";
+    }
+
+    /*! Message shown while searching */
+    virtual QCString trSearching()
+    {
+      return "Ricerca in corso...";
+    }
+
+    /*! Text shown when no search results are found */
+    virtual QCString trNoMatches()
+    {
+      return "Nessun risultato";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.3 (missing items for the directory pages)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! introduction text for the directory dependency graph */
+    virtual QCString trDirDependency(const char *name)
+    {
+      return (QCString)"Grafo di dipendenza delle directory per "+name;
+    }
+
+    /*! when clicking a directory dependency label, a page with a
+     *  table is shown. The heading for the first column mentions the
+     *  source file that has a relation to another file.
+     */
+    virtual QCString trFileIn(const char *name)
+    {
+      return (QCString)"File in "+name;
+    }
+
+    /*! when clicking a directory dependency label, a page with a
+     *  table is shown. The heading for the second column mentions the
+     *  destination file that is included.
+     */
+    virtual QCString trIncludesFileIn(const char *name)
+    {
+      return (QCString)"Include il file in "+name;
+    }
+
+    /** Compiles a date string.
+     *  @param year Year in 4 digits
+     *  @param month Month of the year: 1=January
+     *  @param day Day of the Month: 1..31
+     *  @param dayOfWeek Day of the week: 1=Monday..7=Sunday
+     *  @param hour Hour of the day: 0..23
+     *  @param minutes Minutes in the hour: 0..59
+     *  @param seconds Seconds within the minute: 0..59
+     *  @param includeTime Include time in the result string?
+     */
+    virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
+                                int hour,int minutes,int seconds,
+                                bool includeTime)
+    {
+      static const char *days[]   = { "Lun","Mar","Mer","Gio","Ven","Sab","Dom" };
+      static const char *months[] = { "Gen","Feb","Mar","Apr","Mag","Giu","Lug","Ago","Set","Ott","Nov","Dic" };
+      QCString sdate;
+      sdate.sprintf("%s %d %s %d",days[dayOfWeek-1],day,months[month-1],year);
+      if (includeTime)
+      {
+        QCString stime;
+        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        sdate+=stime;
+      }
+      return sdate;
+    }
+
 };
 
 #endif
+
