@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2010 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -65,7 +65,7 @@ class TextGeneratorIntf
   public:
     virtual ~TextGeneratorIntf() {}
     virtual void writeString(const char *,bool) const = 0;
-    virtual void writeBreak() const = 0;
+    virtual void writeBreak(int indent) const = 0;
     virtual void writeLink(const char *extRef,const char *file,
                       const char *anchor,const char *text
                      ) const = 0; 
@@ -77,7 +77,7 @@ class TextGeneratorOLImpl : public TextGeneratorIntf
     virtual ~TextGeneratorOLImpl() {}
     TextGeneratorOLImpl(OutputDocInterface &od);
     void writeString(const char *s,bool keepSpaces) const;
-    void writeBreak() const;
+    void writeBreak(int indent) const;
     void writeLink(const char *extRef,const char *file,
                    const char *anchor,const char *text
                   ) const;
@@ -99,11 +99,15 @@ enum SrcLangExt
   SrcLangExt_Cpp     = 0x0200,
   SrcLangExt_JS      = 0x0400,
   SrcLangExt_Python  = 0x0800,
-  SrcLangExt_F90     = 0x1000,
+  SrcLangExt_Fortran = 0x1000,
   SrcLangExt_VHDL    = 0x2000,
-  SrcLangExt_XML     = 0x4000
+  SrcLangExt_XML     = 0x4000,
+  SrcLangExt_Tcl     = 0x8000
 };
 
+QCString langToString(SrcLangExt lang);
+QCString getLanguageSpecificSeparator(SrcLangExt lang);
+
 //--------------------------------------------------------------------
 
 void linkifyText(const TextGeneratorIntf &ol,
@@ -113,12 +117,13 @@ void linkifyText(const TextGeneratorIntf &ol,
                  const char *text,
                  bool autoBreak=FALSE,
                  bool external=TRUE,
-                 bool keepSpaces=FALSE
+                 bool keepSpaces=FALSE,
+                 int indentLevel=0
                 );
 
 void setAnchors(ClassDef *cd,char id,MemberList *ml,int groupId=-1);
 
-QCString fileToString(const char *name,bool filter=FALSE);
+QCString fileToString(const char *name,bool filter=FALSE,bool isSourceCode=FALSE);
 
 QCString dateToString(bool);
 
@@ -135,7 +140,7 @@ bool getDefs(const QCString &scopeName,
                     bool checkCV=FALSE
                    );
 
-QCString getFileFilter(const char* name);
+QCString getFileFilter(const char* name,bool isSourceCode);
 
 bool resolveRef(/* in */  const char *scName,
                 /* in */  const char *name,
@@ -154,8 +159,8 @@ bool resolveLink(/* in */  const char *scName,
                  /* out */ QCString &resAnchor
                 );
 
-bool generateRef(OutputDocInterface &od,const char *,
-                        const char *,bool inSeeBlock,const char * =0);
+//bool generateRef(OutputDocInterface &od,const char *,
+//                        const char *,bool inSeeBlock,const char * =0);
 
 bool generateLink(OutputDocInterface &od,const char *,
                          const char *,bool inSeeBlock,const char *);
@@ -178,6 +183,10 @@ QCString substituteClassNames(const QCString &s);
 
 QCString substitute(const char *s,const char *src,const char *dst);
 
+QCString clearBlock(const char *s,const char *begin,const char *end);
+
+QCString selectBlock(const QCString& s,const QCString &name,bool which);
+
 QCString resolveDefines(const char *n);
 
 ClassDef *getClass(const char *key);
@@ -207,7 +216,7 @@ inline bool isId(int c)
 
 QCString removeRedundantWhiteSpace(const QCString &s);
 
-QCString argListToString(ArgumentList *al,bool useCanonicalType=FALSE);
+QCString argListToString(ArgumentList *al,bool useCanonicalType=FALSE,bool showDefVals=TRUE);
 
 QCString tempArgListToString(ArgumentList *al);
 
@@ -225,7 +234,7 @@ bool rightScopeMatch(const QCString &scope, const QCString &name);
 
 bool leftScopeMatch(const QCString &scope, const QCString &name);
 
-QCString substituteKeywords(const QCString &s,const char *title,const QCString &relPath="");
+QCString substituteKeywords(const QCString &s,const char *title);
 
 int getPrefixIndex(const QCString &name);
 
@@ -253,6 +262,8 @@ QCString convertToHtml(const char *s,bool keepEntities=TRUE);
 
 QCString convertToXML(const char *s);
 
+QCString convertToJSString(const char *s);
+
 QCString getOverloadDocs();
 
 void addMembersToMemberGroup(/* in */     MemberList *ml,
@@ -260,7 +271,7 @@ void addMembersToMemberGroup(/* in */     MemberList *ml,
                              /* in */     Definition *context);
 
 int extractClassNameFromType(const QCString &type,int &pos,
-                              QCString &name,QCString &templSpec);
+                              QCString &name,QCString &templSpec,SrcLangExt=SrcLangExt_Unknown);
 
 QCString substituteTemplateArgumentsInString(
        const QCString &name,
@@ -301,12 +312,13 @@ QCString escapeCharsInString(const char *name,bool allowDots,bool allowUnderscor
 void addGroupListToTitle(OutputList &ol,Definition *d);
 
 void filterLatexString(FTextStream &t,const char *str,
-                       bool insideTabbing=FALSE,bool insidePre=FALSE,
+                       bool insideTabbing=FALSE,
+                       bool insidePre=FALSE,
                        bool insideItem=FALSE);
 
 QCString rtfFormatBmkStr(const char *name);
 
-QCString linkToText(const char *link,bool isFileName);
+QCString linkToText(SrcLangExt lang,const char *link,bool isFileName);
 
 QCString stripExtension(const char *fName);
 
@@ -358,7 +370,7 @@ QCString extractAliasArgs(const QCString &args,int pos);
 
 int countAliasArguments(const QCString argList);
 
-QCString replaceAliasArguments(const QCString &aliasValue,const QCString &argList);
+//QCString replaceAliasArguments(const QCString &aliasValue,const QCString &argList);
 
 QCString resolveAliasCmd(const QCString aliasCmd);
 QCString expandAlias(const QCString &aliasName,const QCString &aliasValue);
@@ -382,5 +394,20 @@ QCString externalLinkTarget();
 QCString externalRef(const QCString &relPath,const QCString &ref,bool href);
 int nextUtf8CharPosition(const QCString &utf8Str,int len,int startPos);
 
+struct ColoredImgDataItem
+{
+  const char *name;
+  unsigned short width;
+  unsigned short height;
+  unsigned char *content;
+  unsigned char *alpha;
+};
+
+void writeColoredImgData(const char *dir,ColoredImgDataItem data[]);
+QCString replaceColorMarkers(const char *str);
+
+bool copyFile(const QCString &src,const QCString &dest);
+QCString extractBlock(const QCString text,const QCString marker);
+
 #endif
 
