@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2011 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -42,7 +42,7 @@
 #include "definition.h"
 #include "searchindex.h"
 #include "outputlist.h"
-
+#include "parserintf.h"
 /* --------------------------------------------------------------- */
 
 //#define theTranslator_vhdlType theTranslator->trVhdlType
@@ -204,52 +204,37 @@ ClassDef *VhdlDocGen::getClass(const char *name)
 }
 
 /*!
- * adds components to their entities
+ * adds architectures to their entity
  */
-void VhdlDocGen::computeVhdlComponentRelations(const QDict<EntryNav>& classEntries,FileStorage* g_storage)
+void VhdlDocGen::computeVhdlComponentRelations()
 {
   ClassSDict::Iterator cli(*Doxygen::classSDict);
-  for (cli.toFirst();cli.current();++cli) cli.current()->visited=FALSE;
-  QDictIterator<EntryNav> edi(classEntries);
-  EntryNav *rootNav;
-  for (;(rootNav=edi.current());++edi)
+  ClassDef *cd;
+  for (cli.toFirst();(cd=cli.current());++cli)
   {
-    ClassDef *cd;
-    rootNav->loadEntry(g_storage);
-    Entry *root = rootNav->entry();
-    QCString bName=stripAnonymousNamespaceScope(rootNav->name());
-    if ((cd=getClass(bName)))
+    if (cd->getLanguage()==SrcLangExt_VHDL &&
+        ((VhdlDocGen::VhdlClasses)cd->protection()==VhdlDocGen::ARCHITECTURECLASS || 
+         (VhdlDocGen::VhdlClasses)cd->protection()==VhdlDocGen::PACKBODYCLASS
+        )
+       )
     {
-      QListIterator<BaseInfo> bii(*root->extends);
-      BaseInfo *bi=0;
-      for (bii.toFirst();(bi=bii.current());++bii)
+      QCString bName=cd->name();
+      int i=bName.find("::");
+      if (i>0)
       {
-	ClassDef* baseDef=getClass(bi->name);
-
-	if (baseDef && baseDef != cd)
-	{
-	  QCString cc=VhdlDocGen::getClassName(cd);
-	  ClassDef *ccdef=getClass(cc);
-	  if (ccdef==0) break;
-
-	  int ii=ccdef->protection();
-	  int jj=baseDef->protection();
-
-	  if (ii==VhdlDocGen::ENTITYCLASS && jj==VhdlDocGen::ENTITYCLASS && (ccdef !=baseDef))
-	  {
-	    ccdef->insertBaseClass(baseDef,bi->name,Public,Normal,0);
-	    baseDef->insertSubClass(ccdef,Public,bi->virt,0);
-	  }        
-	}
-	else 
-	{
-	  if (Config_getBool("WARNINGS"))
-	    warn(rootNav->fileDef()->fileName().data(),root->startLine, "found component without entity: [%s]",bi->name.data());
-	}
-      }//for 
-    }//if
-    rootNav->releaseEntry();
-  }// for
+        QCString entityName=bName.left(i);
+        entityName.stripPrefix("_");
+        ClassDef *classEntity=Doxygen::classSDict->find(entityName);
+        // entity for architecutre ?
+        if (classEntity)
+        {
+          // printf("\n entity %s  arch %s",entityName.data(),bName.data());
+          classEntity->insertBaseClass(cd,bName,Public,Normal,0);
+          cd->insertSubClass(classEntity,Public,Normal,0);
+        }
+      }
+    }
+  }
 } // computeVhdlComponentRelations
 
 
@@ -311,7 +296,7 @@ MemberDef* VhdlDocGen::findMember(const QCString& className, const QCString& mem
       tt=tt.upper();
       ecd =getClass(tt);
     }
-    else if (!ecd)
+    if (!ecd)
     {
       tt=tt.lower();
       ecd =getClass(tt);  
@@ -639,7 +624,7 @@ void VhdlDocGen::addFuncDoc(EntryNav* rootNav)
     if (!func && Config_getBool("WARNINGS"))
     {
       warn(root->fileName,root->docLine,
-      "Warning: documentation for unknown function %s found.\n",
+      "warning: documentation for unknown function %s found.\n",
       root->name.data()
       );
     }
@@ -699,15 +684,13 @@ void VhdlDocGen::writeInlineClassLink(const ClassDef* cd ,OutputList& ol)
 
   QCString type;
   if (ii==VhdlDocGen::ENTITY)
-    type+=theTranslator_vhdlType(VhdlDocGen::ARCHITECTURE,TRUE);
+    type=theTranslator_vhdlType(VhdlDocGen::ARCHITECTURE,TRUE);
   else if (ii==VhdlDocGen::ARCHITECTURE)
-    type+=theTranslator_vhdlType(VhdlDocGen::ENTITY,TRUE);
+    type=theTranslator_vhdlType(VhdlDocGen::ENTITY,TRUE);
   else if (ii==VhdlDocGen::PACKAGE_BODY)
-    type+=theTranslator_vhdlType(VhdlDocGen::PACKAGE,TRUE);
+    type=theTranslator_vhdlType(VhdlDocGen::PACKAGE,TRUE);
   else if (ii==VhdlDocGen::PACKAGE)
-    type+=theTranslator_vhdlType(VhdlDocGen::PACKAGE_BODY,TRUE);
-  else 
-    type+="";
+    type=theTranslator_vhdlType(VhdlDocGen::PACKAGE_BODY,TRUE);
 
   //type=type.lower(); 
   type+=" >> ";
@@ -798,7 +781,7 @@ void VhdlDocGen::writeVhdlLink(const ClassDef* ccd ,OutputList& ol,QCString& typ
   ol.docify(type.data());
   ol.endBold();
   nn.stripPrefix("_");
-  ol.writeObjectLink(ccd->getReference(),ccd->getOutputFileBase(),0,nn.data());
+  ol.writeObjectLink(ccd->getReference(),ccd->getOutputFileBase(),ccd->anchor(),nn.data());
 
   if (!behav.isEmpty()) 
   {
@@ -833,12 +816,13 @@ bool VhdlDocGen::compareString(const QCString& s1,const QCString& s2)
 
 bool VhdlDocGen::getSigTypeName(QList<QCString>& ql, const char* str,QCString& buffer)
 {
-  QCString temp(str);
-  QStringList qlist=QStringList::split(" is ",temp,FALSE);
-  if (qlist.count()!=2) return FALSE;
-  temp.resize(0);
-  temp+=(QCString)qlist[0]+":"+(QCString)qlist[1];
-  return VhdlDocGen::getSigName(ql,temp.data(),buffer);  
+  //QCString temp(str);
+  //QStringList qlist=QStringList::split(" is ",temp,FALSE);
+  //if (qlist.count()!=2) return FALSE;
+  //temp.resize(0);
+  //temp+=(QCString)qlist[0]+":"+(QCString)qlist[1];
+  //return VhdlDocGen::getSigName(ql,temp.data(),buffer);  
+  return VhdlDocGen::getSigName(ql,str,buffer);  
 }
 
 /*!
@@ -853,7 +837,7 @@ bool VhdlDocGen::getSigName(QList<QCString>& ql,
                             const char* str,QCString& buffer)
 {
   int j,ll,index;
-  char *signal = "signal ";
+  const char *signal = "signal ";
   QCString qmem;
   QCString temp(str);
   QCString st(str);
@@ -1122,7 +1106,9 @@ void VhdlDocGen::getFuncParams(QList<Argument>& ql, const char* str)
 
     uint zui=ttype.contains('(',FALSE);
     if (zui == 0)
-      tt=QStringList::split(" ",ttype,FALSE);
+    {
+      tt=QStringList::split(QRegExp("[\\s]"),ttype,FALSE);
+    }
     else
     {
       if (ttype.stripPrefix("in"))
@@ -1164,7 +1150,7 @@ void VhdlDocGen::getFuncParams(QList<Argument>& ql, const char* str)
       QCString name=(QCString)tempList[j];
       name=name.stripWhiteSpace();
 
-      tt=QStringList::split(" ",name,FALSE);
+      tt=QStringList::split(QRegExp("[\\s]"),name,FALSE);
       if (tt.count() > 1)
 	ttype=(tt.first()).stripWhiteSpace();
 
@@ -1180,6 +1166,19 @@ void VhdlDocGen::getFuncParams(QList<Argument>& ql, const char* str)
   }//while
 } // getFuncName
 
+QCString VhdlDocGen::getProtectionName(int prot)
+{
+  if (prot==VhdlDocGen::ENTITYCLASS)
+    return "entity";
+  else if (prot==VhdlDocGen::ARCHITECTURECLASS)
+    return "architecture";
+  else if (prot==VhdlDocGen::PACKAGECLASS)
+    return "package";
+  else if (prot==VhdlDocGen::PACKBODYCLASS)
+    return "package body";
+
+  return "";
+}
 
 QCString VhdlDocGen::trTypeString(int type)
 {
@@ -1212,6 +1211,7 @@ QCString VhdlDocGen::trTypeString(int type)
     case VhdlDocGen::COMPONENT_INST: return "Component Instantiation"; 
     case VhdlDocGen::ALIAS:          return "Alias";
     case VhdlDocGen::CONFIG:         return "Configuration";                                     
+    case VhdlDocGen::MISCELLANEOUS:  return "Miscellaneous";                                 
     default:                         return "";
   }
 } // convertType
@@ -1301,7 +1301,9 @@ void VhdlDocGen::writeFormatString(QCString& qcs,OutputList&ol,const MemberDef*
       bool k=VhdlDocGen::isNumber(find); // is this a number
       if (k)
       {
-	VhdlDocGen::startFonts(find,"vhdldigit",ol);
+        ol.docify(" ");
+        VhdlDocGen::startFonts(find,"vhdldigit",ol);
+        ol.docify(" ");
       }
       else if (j != 0 && ss)
       {
@@ -1335,14 +1337,13 @@ void VhdlDocGen::writeFormatString(QCString& qcs,OutputList&ol,const MemberDef*
 
 bool VhdlDocGen::isNumber(const QCString& s)
 {
- // static bool veriOpt=Config_getBool("OPTIMIZE_OUTPUT_VERILOG");
   static QRegExp regg("[0-9][0-9eEfFbBcCdDaA_.#-]*");
  
-  if (s.isEmpty()) return false;
+  if (s.isEmpty()) return FALSE;
   int j,len;
   j = regg.match(s.data(),0,&len);
-  if ((j==0) && (len==(int)s.length())) return true; 
-  return false;
+  if ((j==0) && (len==(int)s.length())) return TRUE; 
+  return FALSE;
  
   #if 0
   int len=s.length();
@@ -1356,7 +1357,7 @@ bool VhdlDocGen::isNumber(const QCString& s)
   #endif 
 }// isNumber
 
-void VhdlDocGen::startFonts(const QCString& q, char *keyword,OutputList& ol)
+void VhdlDocGen::startFonts(const QCString& q, const char *keyword,OutputList& ol)
 {
   ol.startFontClass(keyword);
   ol.docify(q.data());
@@ -1591,51 +1592,55 @@ void VhdlDocGen::writeFuncProcDocu(
     ol.docify(" ( ) ");
     return;
   }
-  ol.startParameterList(FALSE); 
+  ol.startParameterList(TRUE); 
   Argument *arg;
   bool first=TRUE;
   for (;(arg=ali.current());++ali)
   { 
     ol.startParameterType(first,"");  
-    if (first) ol.writeChar('(');
-    if (!VhdlDocGen::isProcess(md))
+    //if (first) ol.writeChar('(');
+    if (VhdlDocGen::isProcedure(md))
     {
-      if (TRUE) //VhdlDocGen::isProcedure(md))
-      {
-	startFonts(arg->defval,"keywordtype",ol);
-	ol.docify(" ");
-      } 
-      // linkifyText(TextGeneratorOLImpl(ol),md->getClassDef(),md->getBodyDef(),md->name(),arg->type);
-      VhdlDocGen::writeFormatString(arg->name,ol,md);
+      startFonts(arg->defval,"keywordtype",ol);
       ol.docify(" ");
+    } 
+    ol.endParameterType();
+
+    ol.startParameterName(TRUE);
+    VhdlDocGen::writeFormatString(arg->name,ol,md);
+    ol.docify(" ");
+
+    if (VhdlDocGen::isProcedure(md))
+      startFonts(arg->attrib,"stringliteral",ol);
+    else if (VhdlDocGen::isVhdlFunction(md))
+      startFonts(QCString("in"),"stringliteral",ol);
+
 
-      if (VhdlDocGen::isProcedure(md))
-	startFonts(arg->attrib,"stringliteral",ol);
-      else
-	startFonts(QCString("in"),"stringliteral",ol);
-    }
     ol.docify(" ");
     ol.disable(OutputGenerator::Man);
     ol.startEmphasis();
     ol.enable(OutputGenerator::Man);
     if (!VhdlDocGen::isProcess(md))
       startFonts(arg->type,"vhdlkeyword",ol);
-    else
-      startFonts(arg->name,"vhdlkeyword",ol);
     ol.disable(OutputGenerator::Man);
     ol.endEmphasis();
     ol.enable(OutputGenerator::Man);
 
     if (--index) 
+    {
       ol.docify(" , ");    
+      ol.endParameterName(FALSE,FALSE,FALSE);
+    }
     else
-      ol.docify(" ) ");
-
-    ol.endParameterName(FALSE,FALSE,FALSE); 
+    {
+      //ol.docify(" ) ");
+      ol.endParameterName(TRUE,FALSE,TRUE);
+    }
 
     sem=TRUE;        
     first=FALSE;
   }
+  //ol.endParameterList(); 
 
 } // writeDocFunProc
 
@@ -1650,10 +1655,12 @@ bool VhdlDocGen::isFunctionProto(QCString& ss)
   QCString proc("procedure");
   QCString func("function");
   name=name.stripWhiteSpace();
-  QStringList ql=QStringList::split(" ",name,FALSE);
+  QStringList ql=QStringList::split(QRegExp("[\\s]"),name,FALSE);
   int j=ql.count();
   if (j<2) return FALSE;
-  QCString tt=(QCString)ql[0];
+  QCString tt=(QCString)ql[0].lower();
+
+  if (tt=="impure" || tt=="pure") tt=ql[1];
 
   if (VhdlDocGen::compareString(tt,proc)!=0 && VhdlDocGen::compareString(tt,func)!=0) 
     return FALSE;
@@ -1737,22 +1744,35 @@ void VhdlDocGen::writeVhdlDeclarations(MemberList* ml,
   VhdlDocGen::writeVHDLDeclarations(ml,ol,cd,0,0,gd,theTranslator_vhdlType(VhdlDocGen::GROUP,FALSE),0,FALSE,VhdlDocGen::GROUP);
   VhdlDocGen::writeVHDLDeclarations(ml,ol,cd,0,0,gd,theTranslator_vhdlType(VhdlDocGen::COMPONENT_INST,FALSE),0,FALSE,VhdlDocGen::COMPONENT_INST);
   VhdlDocGen::writeVHDLDeclarations(ml,ol,cd,0,0,gd,theTranslator_vhdlType(VhdlDocGen::ALIAS,FALSE),0,FALSE,VhdlDocGen::ALIAS);
+  VhdlDocGen::writeVHDLDeclarations(ml,ol,cd,0,0,gd,theTranslator_vhdlType(VhdlDocGen::MISCELLANEOUS),0,FALSE,VhdlDocGen::MISCELLANEOUS);
   
   // configurations must be added to global file definitions.  
   VhdlDocGen::writeVHDLDeclarations(ml,ol,cd,0,fd,gd,theTranslator_vhdlType(VhdlDocGen::CONFIG,FALSE),0,FALSE,VhdlDocGen::CONFIG);
 }
 
-static void setConfigurationType(MemberList *ml)
+static void setGlobalType(MemberList *ml)
 {
   if (ml==0) return;
   MemberDef *mdd=0;
   MemberListIterator mmli(*ml);
   for ( ; (mdd=mmli.current()); ++mmli )
   {
-    if (strcmp(mdd->argsString(),"configuration")==0)
+    if (stricmp(mdd->argsString(),"configuration")==0)
     {
       mdd->setMemberSpecifiers(VhdlDocGen::CONFIG);        
     }
+    else if (stricmp(mdd->typeString(),"library")==0)
+    {
+      mdd->setMemberSpecifiers(VhdlDocGen::LIBRARY);        
+    }
+    else if (stricmp(mdd->typeString(),"package")==0)
+    {
+      mdd->setMemberSpecifiers(VhdlDocGen::USE);        
+    } 
+    else if (stricmp(mdd->typeString(),"misc")==0)
+    {
+      mdd->setMemberSpecifiers(VhdlDocGen::MISCELLANEOUS);        
+    } 
   }
 }
 
@@ -1769,25 +1789,33 @@ void VhdlDocGen::writeVHDLTypeDocumentation(const MemberDef* mdef, const Definit
     MemberDef* memdef=VhdlDocGen::findMember(na,nn);
     if (memdef && memdef->isLinkable()) 
     { 
+      ol.docify(" ");
       ol.startBold();
       //ol.writeObjectLink(cd->getReference(),cd->getOutputFileBase(),0,mdef->typeString());                
-       writeLink(memdef,ol);
+      writeLink(memdef,ol);
       ol.endBold();
       ol.docify(" ");
     }
     else
     {
+      ol.docify(" ");
       QCString ttype=mdef->typeString();
       VhdlDocGen::formatString(ttype,ol,mdef);
+      ol.docify(" "); 
     }
     ol.docify(mdef->name());
     VhdlDocGen::writeFuncProcDocu(mdef,ol, mdef->argumentList().pointer());
   }
 
+  if(VhdlDocGen::isMisc(mdef))
+  {
+    writeLink(mdef,ol);
+    return;
+  }
   if (mdef->isVariable())
   { 
     //ol.docify(mdef->name().data());
-     writeLink(mdef,ol);
+    writeLink(mdef,ol);
     ol.docify(" ");
     QCString ttype=mdef->typeString();
     VhdlDocGen::formatString(ttype,ol,mdef);
@@ -1811,8 +1839,28 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
   LockingPtr<MemberDef> lock(mdef,mdef);
 
   Definition *d=0;
-  ASSERT (cd!=0 || nd!=0 || fd!=0 || gd!=0); // member should belong to something
-  if (cd) d=cd; else if (nd) d=nd; else if (fd) d=fd; else d=gd;
+
+  /* some vhdl files contain only a configuration  description
+
+     library work;
+     configuration cfg_tb_jtag_gotoBackup of tb_jtag_gotoBackup is
+     for RTL
+     end for;
+     end cfg_tb_jtag_gotoBackup;
+
+     in this case library work does not belong to an entity, package ...
+
+   */
+
+  ASSERT(cd!=0 || nd!=0 || fd!=0 || gd!=0 || 
+         mdef->getMemberSpecifiers()==VhdlDocGen::LIBRARY || 
+         mdef->getMemberSpecifiers()==VhdlDocGen::USE   
+        ); // member should belong to something
+  if (cd) d=cd; 
+  else if (nd) d=nd; 
+  else if (fd) d=fd; 
+  else if (gd) d=gd; 
+  else d=(Definition*)mdef;
 
   // write tag file information of this member
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
@@ -1859,7 +1907,7 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
   }
 
   // write search index info
-  if (Config_getBool("SEARCHENGINE"))
+  if (Doxygen::searchIndex)
   {
     Doxygen::searchIndex->setCurrentDoc(mdef->qualifiedName(),mdef->getOutputFileBase(),mdef->anchor());
     Doxygen::searchIndex->addWord(mdef->localName(),TRUE);
@@ -1912,12 +1960,17 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
   if (gd) gd=0;
   switch(mm)
   {
+    case VhdlDocGen::MISCELLANEOUS:
+      VhdlDocGen::writeCodeFragment(mdef,ol);
+      break;
     case VhdlDocGen::PROCEDURE:
     case VhdlDocGen::FUNCTION: 
       ol.startBold();
       VhdlDocGen::formatString(ltype,ol,mdef);
       ol.endBold();
       ol.insertMemberAlign();
+      ol.docify(" ");
+	
       writeLink(mdef,ol);
       if (alp!=0 && mm==VhdlDocGen::FUNCTION)
 	VhdlDocGen::writeFunctionProto(ol,alp.pointer(),mdef);
@@ -1957,11 +2010,11 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
     case VhdlDocGen::GENERIC:
     case VhdlDocGen::PORT:
       writeLink(mdef,ol);
+      ol.docify(" ");
       ol.insertMemberAlign();
       if (mm==VhdlDocGen::GENERIC)
       {
 	ol.startBold();
-	ol.docify(" ");
 	VhdlDocGen::formatString(ltype,ol,mdef);
 	ol.endBold();
       }
@@ -1987,6 +2040,8 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
     case VhdlDocGen::CONFIG:
       writeLink(mdef,ol);
       ol.insertMemberAlign();
+      ol.docify("  ");
+       
       ol.startBold();
       ol.docify(ltype);
       ol.endBold();
@@ -2041,6 +2096,7 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
       break;
     case VhdlDocGen::RECORD:    
       writeLink(mdef,ol);
+      ol.docify(" ");
       ol.startBold();
       if (ltype.isEmpty()) ol.docify("     : record");    
       ol.insertMemberAlign();
@@ -2051,6 +2107,7 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
     case VhdlDocGen::UNITS:
       ol.startBold();
       writeLink(mdef,ol);
+      ol.docify(" ");
       if (ltype.isEmpty()) ol.docify("     : unit");    
       ol.insertMemberAlign();
       if (!ltype.isEmpty())
@@ -2083,7 +2140,9 @@ void VhdlDocGen::writeVHDLDeclaration(MemberDef* mdef,OutputList &ol,
   if (!mdef->briefDescription().isEmpty() &&   Config_getBool("BRIEF_MEMBER_DESC") /* && !annMemb */)
   {
     ol.startMemberDescription();
-    ol.parseDoc(mdef->briefFile(),mdef->briefLine(),mdef->getOuterScope()?mdef->getOuterScope():d,mdef,mdef->briefDescription(),TRUE,FALSE);
+    ol.parseDoc(mdef->briefFile(),mdef->briefLine(),
+                mdef->getOuterScope()?mdef->getOuterScope():d,
+                mdef,mdef->briefDescription(),TRUE,FALSE,0,TRUE,FALSE);
     if (detailsVisible) 
     {
       ol.pushGeneratorState();
@@ -2184,12 +2243,12 @@ void VhdlDocGen::writeVHDLDeclarations(MemberList* ml,OutputList &ol,
     ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
     const char *title,const char *subtitle,bool /*showEnumValues*/,int type) 
 {
-  setConfigurationType(ml);
+  setGlobalType(ml);
   if (!membersHaveSpecificType(ml,type)) return;
 
   if (title) 
   {
-    ol.startMemberHeader();
+    ol.startMemberHeader(title);
     ol.parseText(title);
     ol.endMemberHeader();
     ol.docify(" ");
@@ -2197,7 +2256,7 @@ void VhdlDocGen::writeVHDLDeclarations(MemberList* ml,OutputList &ol,
   if (subtitle && subtitle[0]!=0) 
   {
     ol.startMemberSubtitle();
-    ol.parseDoc("[generated]",-1,0,0,subtitle,FALSE,FALSE);
+    ol.parseDoc("[generated]",-1,0,0,subtitle,FALSE,FALSE,0,TRUE,FALSE);
     ol.endMemberSubtitle();
   } //printf("memberGroupList=%p\n",memberGroupList);
 
@@ -2251,13 +2310,9 @@ void VhdlDocGen::adjustRecordMember(MemberDef *mdef)
 
 /* strips the prefix for package and package body */
 
-bool VhdlDocGen::writeClassType( ClassDef *& cd,
+bool VhdlDocGen::writeClassType( ClassDef * cd,
                                  OutputList &ol ,QCString & cname)
 {
-  //static ClassDef *prev = 0;
-  //if (prev == cd)  return TRUE;
-  //if (cd != prev) prev=cd;
-
   int id=cd->protection();
   QCString qcs = VhdlDocGen::trTypeString(id+2);
   cname=VhdlDocGen::getClassName(cd);
@@ -2265,7 +2320,6 @@ bool VhdlDocGen::writeClassType( ClassDef *& cd,
   ol.writeString(qcs.data());
   ol.writeString(" ");
   ol.endBold();
-  //ol.insertMemberAlign();
   return FALSE;
 }// writeClassLink
 
@@ -2348,7 +2402,8 @@ QCString VhdlDocGen::trVhdlType(int type,bool sing)
     case VhdlDocGen::CONFIG:        
       if (sing) return "Configuration";       
       return "Configurations";
-      
+     case VhdlDocGen::MISCELLANEOUS:
+      return "Miscellaneous";  
     default:                       
       return "Class";
   }
@@ -2447,3 +2502,70 @@ void VhdlDocGen::writeStringLink(const MemberDef *mdef,QCString mem, OutputList&
   VhdlDocGen::startFonts(mem,"vhdlchar",ol);    
 }// found component
 
+void VhdlDocGen::writeCodeFragment( MemberDef *mdef,OutputList& ol)
+{
+  //  Definition d=(Definition)mdef;
+  //	QCString fdd=mdef->getDefFileExtension();
+  //	QCString scope=mdef->getScopeString();
+  QCString codeFragment=mdef->documentation();
+  //FileDef *fd=mdef->getFileDef();
+
+  //int start=mdef->getStartBodyLine();
+  //int end=mdef->getEndBodyLine();
+  QStringList qsl=QStringList::split("\n",codeFragment);
+
+  writeLink(mdef,ol);
+  ol.docify(" ");
+  ol.insertMemberAlign();
+  int len = qsl.count();	
+  int j;
+  for (j=0;j<len;j++)
+  {
+    QCString q=(QCString)qsl[j];
+    VhdlDocGen::writeFormatString(q,ol,mdef);
+    ol.lineBreak(); 
+    if (j==2) // only the first three lines are shown
+    {
+      q="...";
+      VhdlDocGen::writeFormatString(q,ol,mdef);
+      break;
+    }
+  }
+}
+
+void VhdlDocGen::writeSource(MemberDef *mdef,OutputList& ol,QCString & cname)
+{
+  //  Definition d=(Definition)mdef;
+  QCString fdd=mdef->getDefFileExtension();
+  QCString scope=mdef->getScopeString();
+  QCString codeFragment=mdef->documentation();
+  FileDef *fd=mdef->getFileDef();
+  int start=mdef->getStartBodyLine();
+  int end=mdef->getEndBodyLine();
+  QStringList qsl=QStringList::split("\n",codeFragment);
+
+  ParserInterface *pIntf = Doxygen::parserManager->getParser(fdd.data());
+  pIntf->resetCodeParserState();
+
+  ol.startParagraph();
+  ol.startCodeFragment();
+  pIntf->parseCode(ol,               // codeOutIntf
+                   scope,            // scope
+                   codeFragment,     // input
+                   FALSE,            // isExample
+                   0,                // exampleName
+                   fd,               // fileDef
+                   start,            // startLine
+                   end,              // endLine
+                   TRUE,             // inlineFragment
+                   mdef,             // memberDef
+                   FALSE             // show line numbers
+                   );
+  ol.endCodeFragment();
+  ol.endParagraph();
+
+  mdef->writeSourceDef(ol,cname);
+  mdef->writeSourceRefs(ol,cname);
+  mdef->writeSourceReffedBy(ol,cname);
+}
+
